@@ -20,38 +20,38 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "accueil.h"
-#include "./classement_echeances.h"
-#include "./dialog.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_partial_balance.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_dates.h"
-#include "./gsb_form.h"
-#include "./gsb_form_scheduler.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_scheduler.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_select_icon.h"
-#include "./gsb_transactions_list.h"
-#include "./main.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./fenetre_principale.h"
-#include "./gsb_data_account.h"
-#include "./gsb_select_icon.h"
-#include "./gsb_form_scheduler.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
+#include "classement_echeances.h"
+#include "dialog.h"
+#include "fenetre_principale.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_partial_balance.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form.h"
+#include "gsb_form_scheduler.h"
+#include "gsb_real.h"
+#include "gsb_scheduler.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_select_icon.h"
+#include "gsb_transactions_list.h"
+#include "main.h"
+#include "navigation.h"
+#include "structures.h"
+#include "utils.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -68,6 +68,7 @@ static gint affiche_soldes_partiels ( GtkWidget *table,
                         GSList *liste,
                         gint currency_number,
                         gint type_compte );
+static gboolean gsb_config_scheduler_switch_balances_with_scheduled ( void );
 static void gsb_main_page_affiche_ligne_du_compte ( GtkWidget *pTable,
                         gint account_number,
                         gint i );
@@ -86,7 +87,6 @@ static void update_soldes_minimaux ( gboolean force );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gboolean balances_with_scheduled;
 extern GdkColor couleur_bleue;
 extern GdkColor couleur_jaune;
 extern GdkColor couleur_nom_compte_normal;
@@ -101,7 +101,6 @@ extern GtkWidget *form_transaction_part;
 extern gsb_real null_real;
 extern GSList *scheduled_transactions_taken;
 extern GSList *scheduled_transactions_to_take;
-extern gchar *titre_fichier;
 extern GtkWidget *window;
 /*END_EXTERN*/
 
@@ -133,10 +132,17 @@ gint mise_a_jour_fin_comptes_passifs;
 GtkSizeGroup * size_group_accueil;
 gchar *chaine_espace = "                         ";
 
-/* ************************************************************************* */
+/**
+ * Create the home page of Grisbi
+ *
+ *
+ *
+ * */
 GtkWidget *creation_onglet_accueil ( void )
 {
     GtkWidget *paddingbox, *base, *base_scroll;
+    GtkWidget * eb;
+    GtkStyle * style;
 
     devel_debug ( NULL );
 
@@ -155,44 +161,29 @@ GtkWidget *creation_onglet_accueil ( void )
     gtk_widget_show ( base_scroll );
     gtk_widget_show ( base );
 
-    /* en dessous, on met le titre du fichier s'il existe */
-    if ( titre_fichier )
+    /* en dessous, on met le titre du fichier */
+    hbox_title = gtk_hbox_new ( FALSE, 0 );
+
+    eb = gtk_event_box_new ();
+    style = gtk_widget_get_style ( eb );
+    gtk_widget_modify_bg ( eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
+
+    label_titre_fichier = gtk_label_new ( NULL );
+
+    if ( etat.utilise_logo )
     {
-        GtkWidget * eb;
-        GtkStyle * style;
+        logo_accueil =  gtk_image_new_from_pixbuf ( gsb_select_icon_get_logo_pixbuf ( ) );
 
-        hbox_title = gtk_hbox_new ( FALSE, 0 );
-
-        eb = gtk_event_box_new ();
-        style = gtk_widget_get_style ( eb );
-        gtk_widget_modify_bg ( eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
-
-        label_titre_fichier = gtk_label_new ( titre_fichier );
-        gsb_main_page_update_homepage_title ( titre_fichier );
-
-        if ( etat.utilise_logo )
-        {
-            logo_accueil =  gtk_image_new_from_pixbuf ( 
-                        gsb_select_icon_get_logo_pixbuf ( ) );
-            if ( ! logo_accueil )
-                logo_accueil =  gtk_image_new_from_pixbuf ( 
-                        gsb_select_icon_get_default_logo_pixbuf ( ) );
-            gtk_box_pack_start ( GTK_BOX ( hbox_title ), logo_accueil, FALSE, FALSE, 20 );
-            gtk_widget_set_size_request ( hbox_title, -1, LOGO_HEIGHT + 20 );
-        }
-
-        gtk_box_pack_end ( GTK_BOX ( hbox_title ), label_titre_fichier, TRUE, TRUE, 20 );
-        gtk_container_set_border_width ( GTK_CONTAINER ( hbox_title ), 6 );
-        gtk_container_add ( GTK_CONTAINER(eb), hbox_title );
-        gtk_box_pack_start ( GTK_BOX ( base ), eb, FALSE, FALSE, 0 );
-        gtk_widget_show_all ( eb );
-    }
-    else
-    {
-        label_titre_fichier = gtk_label_new ( NULL );
-        gtk_box_pack_start ( GTK_BOX ( base ), label_titre_fichier, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox_title ), logo_accueil, FALSE, FALSE, 20 );
+        gtk_widget_set_size_request ( hbox_title, -1, LOGO_HEIGHT + 20 );
     }
 
+    gtk_box_pack_end ( GTK_BOX ( hbox_title ), label_titre_fichier, TRUE, TRUE, 20 );
+    gtk_container_set_border_width ( GTK_CONTAINER ( hbox_title ), 6 );
+    gtk_container_add ( GTK_CONTAINER ( eb ), hbox_title );
+    gtk_box_pack_start ( GTK_BOX ( base ), eb, FALSE, FALSE, 0 );
+    gtk_widget_show_all ( eb );
+
     /* on crée le size_group pour l'alignement des tableaux */
     size_group_accueil = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
 
@@ -282,7 +273,6 @@ GtkWidget *creation_onglet_accueil ( void )
 
     return ( base_scroll );
 }
-/* ************************************************************************* */
 
 
 /**
@@ -335,6 +325,7 @@ gboolean saisie_echeance_accueil ( GtkWidget *event_box,
 	gtk_box_pack_start ( GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 0 );
 	gtk_container_set_border_width ( GTK_CONTAINER(hbox), 12 );
 	gtk_widget_reparent ( form_transaction_part, hbox );
+    gtk_widget_show_all ( hbox );
 
     /* next we fill the form,
      * don't use gsb_form_show because we are neither on transactions list, neither scheduled list */
@@ -344,6 +335,7 @@ gboolean saisie_echeance_accueil ( GtkWidget *event_box,
                         NULL );
 
     gsb_form_fill_from_account (gsb_data_scheduled_get_account_number (scheduled_number));
+
     /* fill the form with the scheduled transaction */
     gsb_scheduler_list_execute_transaction(scheduled_number);
 
@@ -351,7 +343,6 @@ gboolean saisie_echeance_accueil ( GtkWidget *event_box,
                         G_CALLBACK (gsb_form_scheduler_change_account),
                         NULL );
 
-	gtk_widget_show_all ( hbox );
 	result = gtk_dialog_run ( GTK_DIALOG ( dialog ));
 
     if ( result == GTK_RESPONSE_OK )
@@ -384,7 +375,7 @@ void update_liste_comptes_accueil ( gboolean force )
     gint nb_comptes_bancaires=0, nb_comptes_passif=0, nb_comptes_actif=0;
     gint new_comptes_bancaires=0, new_comptes_passif=0, new_comptes_actif=0;
     gint soldes_mixtes = 0;
-    
+
     if ( !force
 	 &&
 	 !( mise_a_jour_liste_comptes_accueil
@@ -478,7 +469,7 @@ void update_liste_comptes_accueil ( gboolean force )
         /* Creating the table which will store accounts with their balances. */
         tmpstr = g_strdup_printf ( _("Account balances in %s"),
                         gsb_data_currency_get_name ( currency_number ) );
-        if ( balances_with_scheduled == FALSE )
+        if ( conf.balances_with_scheduled == FALSE )
             tmpstr = g_strconcat ( tmpstr, _(" at "), gsb_date_today (), NULL );
 
         paddingbox = new_paddingbox_with_title ( vbox, FALSE, tmpstr );
@@ -556,7 +547,7 @@ void update_liste_comptes_accueil ( gboolean force )
         /* Creating the table which will store accounts with their balances   */
 		tmpstr = g_strdup_printf (_("Liabilities accounts balances in %s"),
                          gsb_data_currency_get_name (currency_number) );
-        if ( balances_with_scheduled == FALSE )
+        if ( conf.balances_with_scheduled == FALSE )
             tmpstr = g_strconcat ( tmpstr, _(" at "), gsb_date_today (), NULL );
 
         paddingbox = new_paddingbox_with_title ( vbox, FALSE, tmpstr );
@@ -633,7 +624,7 @@ void update_liste_comptes_accueil ( gboolean force )
         /* Creating the table which will store accounts with their balances    */
         tmpstr = g_strdup_printf (_("Assets accounts balances in %s"),
                          gsb_data_currency_get_name (currency_number));
-        if ( balances_with_scheduled == FALSE )
+        if ( conf.balances_with_scheduled == FALSE )
             tmpstr = g_strconcat ( tmpstr, _(" at "), gsb_date_today (), NULL );
 
         paddingbox = new_paddingbox_with_title ( vbox, FALSE, tmpstr );
@@ -702,7 +693,7 @@ void update_liste_comptes_accueil ( gboolean force )
             tmpstr = g_strdup ( _("Additional balance") );
         else
             tmpstr = g_strdup ( _("Additional balances") );
-        if ( balances_with_scheduled == FALSE )
+        if ( conf.balances_with_scheduled == FALSE )
             tmpstr = g_strconcat ( tmpstr, _(" at "), gsb_date_today (), NULL );
 
         paddingbox = new_paddingbox_with_title ( vbox, FALSE, tmpstr );
@@ -1006,9 +997,9 @@ gint affiche_soldes_partiels ( GtkWidget *table,
 
                 /* On met les titres du sous ensemble solde(s) partiel(s) */
                 if ( nb_comptes == 1 )
-                    label = gtk_label_new ( COLON(_("Partial balance")));
+                    label = gtk_label_new ( _("Partial balance: ") );
                 else
-                    label = gtk_label_new ( COLON(_("Partial balances")));
+                    label = gtk_label_new ( _("Partial balances: ") );
                 gtk_misc_set_alignment ( GTK_MISC ( label ), MISC_LEFT, MISC_VERT_CENTER );
                 gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group_accueil ), label );
                 gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, i, i+1 );
@@ -1087,11 +1078,11 @@ void affiche_solde_des_comptes ( GtkWidget *table,
 
 	/* Première colonne */
     if ( nb_comptes == 1 )
-        label = gtk_label_new ( COLON ( _("Global balance") ) );
+        label = gtk_label_new ( _("Global balance: ") );
     else if ( conf.pluriel_final )
-        label = gtk_label_new ( COLON ("Soldes finaux") );
+        label = gtk_label_new ( ("Soldes finaux: ") );
     else
-        label = gtk_label_new ( COLON ( _("Global balances") ) );
+        label = gtk_label_new ( _("Global balances: ") );
 	gtk_misc_set_alignment ( GTK_MISC ( label ), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group_accueil ), label );
 	gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, i, i+1 );
@@ -1185,8 +1176,6 @@ gint affiche_soldes_additionnels ( GtkWidget *table, gint i, GSList *liste )
 
     return nbre_lignes;
 }
-/* ************************************************************************* */
-
 
 /**
  * called by a click on an account name or balance of accounts on the main page
@@ -1206,10 +1195,12 @@ gboolean gsb_main_page_click_on_account ( gint *account_number )
 }
 
 
-
-
-
-/* ************************************************************************* */
+/**
+ * 
+ *
+ *
+ *
+ * */
 void update_liste_echeances_manuelles_accueil ( gboolean force )
 {
     devel_debug_int (force);
@@ -1346,9 +1337,8 @@ void update_liste_echeances_manuelles_accueil ( gboolean force )
 	hide_paddingbox ( frame_etat_echeances_manuelles_accueil );
     }
 }
-/* ************************************************************************* */
 
-/* ************************************************************************* */
+
 void update_liste_echeances_auto_accueil ( gboolean force )
 {
     if ( !force
@@ -1471,14 +1461,16 @@ void update_liste_echeances_auto_accueil ( gboolean force )
 	hide_paddingbox ( frame_etat_echeances_auto_accueil );
     }
 }
-/* ************************************************************************* */
 
-/* ************************************************************************* */
-/* Fonction update_soldes_minimaux */
-/* vérifie les soldes de tous les comptes, affiche un message d'alerte si nécessaire */
-/* et ajoute dans l'accueil les comptes sous les soldes minimaux */
-/* ************************************************************************* */
 
+/**
+ * Fonction update_soldes_minimaux
+ * vérifie les soldes de tous les comptes, affiche un message d'alerte si nécessaire
+ * 
+ *
+ *
+ *
+ * */
 void update_soldes_minimaux ( gboolean force )
 {
     GtkWidget *vbox_1;
@@ -1971,6 +1963,22 @@ GtkWidget *onglet_accueil (void)
                         G_CALLBACK (gsb_gui_navigation_update_home_page), NULL ),
                         FALSE, FALSE, 0 );
     }
+
+    /* Take into account the planned operations in the calculation of balances */
+    paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Calculation of balances") );
+
+    hbox = gtk_hbox_new ( FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+
+    button = gsb_automem_checkbutton_new (
+                        _("Take into account the scheduled operations "
+                          "in the calculation of balances"),
+                        &conf.balances_with_scheduled,
+                        G_CALLBACK ( gsb_config_scheduler_switch_balances_with_scheduled ),
+                        NULL );
+
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
+
     /* Data partial balance settings */
     paddingbox = new_paddingbox_with_title (vbox, FALSE, 
                         _("Balances partials of the list of accounts") );
@@ -2136,24 +2144,50 @@ GtkWidget *onglet_accueil (void)
 /**
  * update the title of the main page
  *
+ * \param title
+ *
+ *
  * */
-void gsb_main_page_update_homepage_title ( gchar *title )
+void gsb_main_page_update_homepage_title ( const gchar *title )
 {
-    gchar * tmpstr;
+    gchar * tmp_str;
 
     /* at the first use of grisbi,label_titre_fichier doesn't still exist */
     if ( !label_titre_fichier || !GTK_IS_LABEL ( label_titre_fichier ) )
         return;
 
-    if ( title && strlen ( title ) > 0 )
-        tmpstr = g_markup_printf_escaped ("<span size=\"x-large\">%s</span>", title );
-    else
-        tmpstr = g_strconcat ("<span size=\"x-large\">", _("My accounts"), "</span>", NULL );
+    tmp_str = g_markup_printf_escaped ("<span size=\"x-large\">%s</span>", title );
 
-    gtk_label_set_markup ( GTK_LABEL ( label_titre_fichier ), tmpstr );
-    g_free ( tmpstr );
+    gtk_label_set_markup ( GTK_LABEL ( label_titre_fichier ), tmp_str );
 
+    g_free ( tmp_str );
 }
+
+
+gboolean gsb_config_scheduler_switch_balances_with_scheduled ( void )
+{
+    GSList *list_tmp;
+
+    devel_debug ( NULL );
+
+    list_tmp = gsb_data_account_get_list_accounts ();
+
+    while ( list_tmp )
+    {
+        gint account_number;
+
+        account_number = gsb_data_account_get_no_account ( list_tmp -> data );
+        gsb_data_account_set_balances_are_dirty ( account_number );
+
+        /* MAJ HOME_PAGE */
+        gsb_gui_navigation_update_home_page ( );
+
+        list_tmp = list_tmp -> next;
+    }
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
