@@ -21,34 +21,35 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "affichage.h"
-#include "./utils_file_selection.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_account.h"
-#include "./gsb_file.h"
-#include "./navigation.h"
-#include "./fenetre_principale.h"
-#include "./barre_outils.h"
-#include "./accueil.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_select_icon.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./parametres.h"
-#include "./transaction_list.h"
-#include "./utils_font.h"
-#include "./structures.h"
-#include "./custom_list.h"
-#include "./utils_str.h"
-#include "./utils_buttons.h"
-#include "./gsb_select_icon.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "utils_file_selection.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_file.h"
+#include "navigation.h"
+#include "fenetre_principale.h"
+#include "barre_outils.h"
+#include "accueil.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_select_icon.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "parametres.h"
+#include "transaction_list.h"
+#include "utils_font.h"
+#include "structures.h"
+#include "custom_list.h"
+#include "utils_buttons.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -62,14 +63,14 @@ static gboolean change_toolbar_display_mode ( GtkRadioButton *button );
 static gboolean modification_logo_accueil ( );
 static gboolean preferences_switch_headings_bar ( GtkWidget *toggle_button,
                         gpointer null );
-static  gboolean preferences_view_color_changed ( GtkWidget *color_button,
+static gboolean preferences_view_color_changed ( GtkWidget *color_button,
                         GtkWidget *combobox );
-static  gboolean preferences_view_color_combobox_changed ( GtkWidget *combobox,
+static gboolean preferences_view_color_combobox_changed ( GtkWidget *combobox,
                         GtkWidget *color_button );
-static  gboolean preferences_view_color_default ( GtkWidget *button,
+static gboolean preferences_view_color_default ( GtkWidget *button,
                         GtkWidget *combobox );
-static  GtkWidget *preferences_view_create_color_combobox (void);
-static  gboolean preferences_view_update_preview_logo ( GtkFileChooser *file_chooser,
+static GtkWidget *preferences_view_create_color_combobox (void);
+static gboolean preferences_view_update_preview_logo ( GtkFileChooser *file_chooser,
                         GtkWidget *preview );
 static void update_fonte_listes ( gchar *fontname,
                         gpointer null);
@@ -83,6 +84,8 @@ extern GdkColor archive_background_color;
 extern GdkColor calendar_entry_color;
 extern GdkColor couleur_bet_division;
 extern GdkColor couleur_bet_future;
+extern GdkColor couleur_bet_solde;
+extern GdkColor couleur_bet_transfert;
 extern GdkColor couleur_fond[2];
 extern GdkColor couleur_grise;
 extern GdkColor couleur_jour;
@@ -91,6 +94,8 @@ extern GdkColor default_archive_background_color;
 extern GdkColor default_calendar_entry_color;
 extern GdkColor default_couleur_bet_division;
 extern GdkColor default_couleur_bet_future;
+extern GdkColor default_couleur_bet_solde;
+extern GdkColor default_couleur_bet_transfert;
 extern GdkColor default_couleur_fond[2];
 extern GdkColor default_couleur_grise;
 extern GdkColor default_couleur_jour;
@@ -99,11 +104,8 @@ extern GdkColor default_split_background;
 extern GdkColor default_text_color[2];
 extern GtkWidget *fenetre_preferences;
 extern GtkWidget *hbox_title;
-extern gchar *initial_file_title;
-extern gchar *initial_holder_title;
 extern GtkWidget *label_titre_fichier;
 extern GtkWidget *logo_accueil;
-extern gchar *nom_fichier_comptes;
 extern GdkColor split_background;
 extern GdkColor text_color[2];
 extern gchar *titre_fichier;
@@ -167,8 +169,7 @@ GtkWidget * onglet_display_fonts ( void )
 
     if (!pixbuf)
     {
-        preview = gtk_image_new_from_stock ( GTK_STOCK_MISSING_IMAGE,
-                        GTK_ICON_SIZE_BUTTON );
+        preview = gtk_image_new_from_pixbuf ( gsb_select_icon_get_default_logo_pixbuf ( ) );
     }
     else
     {
@@ -203,7 +204,7 @@ GtkWidget * onglet_display_fonts ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     check_button = gtk_check_button_new_with_label ( 
-                        _("Use a custom font for the transactions"));
+                        _("Use a custom font for the transactions: "));
     gtk_box_pack_start ( GTK_BOX ( hbox ), check_button, FALSE, FALSE, 0 );
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( check_button ),
 				        conf.utilise_fonte_listes );
@@ -291,16 +292,33 @@ gboolean change_choix_utilise_logo ( GtkWidget *check_button,
             gtk_widget_hide ( logo_accueil );
         else
         {
+            GdkPixbuf *pixbuf = NULL;
+
             /* Update homepage logo */
-            logo_accueil =  gtk_image_new_from_pixbuf ( 
-                            gsb_select_icon_get_logo_pixbuf ( ) );
-            gtk_box_pack_start ( GTK_BOX ( hbox_title ), logo_accueil, FALSE, FALSE, 0 );
-            gtk_widget_set_size_request ( hbox_title, -1, LOGO_HEIGHT + 20 );
-            gtk_widget_show ( logo_accueil );
+            pixbuf = gsb_select_icon_get_logo_pixbuf ( );
+            if ( pixbuf == NULL )
+            {
+                pixbuf = gsb_select_icon_get_default_logo_pixbuf ( );
+                etat.is_pixmaps_dir = TRUE;
+            }
+            logo_accueil =  gtk_image_new_from_pixbuf ( pixbuf );
+            if ( logo_accueil )
+            {
+                gtk_box_pack_start ( GTK_BOX ( hbox_title ), logo_accueil, FALSE, FALSE, 0 );
+                gtk_widget_set_size_request ( hbox_title, -1, -1 );
+                gtk_widget_show ( logo_accueil );
+            }
         }
     }
     else
+    {
         gtk_widget_destroy ( logo_accueil );
+        gtk_widget_set_size_request ( hbox_title, -1, -1 );
+        if ( etat.name_logo && strlen ( etat.name_logo ) )
+            g_free ( etat.name_logo );
+        etat.name_logo = NULL;
+        etat.is_pixmaps_dir = 0;
+    }
 
     if ( etat.modification_fichier == 0 )
         modification_fichier ( TRUE );
@@ -372,63 +390,56 @@ GtkWidget *onglet_display_addresses ( void )
     paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Titles") );
 
     /* It first creates the entry of title */
-    entry = gsb_automem_entry_new ( &initial_file_title,
+    entry = gsb_automem_entry_new ( &titre_fichier,
                         ( GCallback ) update_homepage_title, NULL );
 
     /* Choice of title type */
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0);
 
-    radiogroup = radio = gtk_radio_button_new_with_label ( NULL, 
-                        _("Accounts file title") );
-    g_object_set_data ( G_OBJECT(radio), "display", 
-                        GINT_TO_POINTER ( GSB_ACCOUNTS_TITLE ) );
-    gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
-    if ( etat.display_grisbi_title == GSB_ACCOUNTS_TITLE )
-        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (radio), TRUE );
-    g_signal_connect ( G_OBJECT(radio), 
+    radiogroup = gtk_radio_button_new_with_label ( NULL, _("Accounts file title") );
+    g_object_set_data ( G_OBJECT ( radiogroup ), "display", GINT_TO_POINTER ( GSB_ACCOUNTS_TITLE ) );
+    if ( conf.display_grisbi_title == GSB_ACCOUNTS_TITLE )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radiogroup ), TRUE );
+    g_signal_connect ( G_OBJECT ( radiogroup ), 
                         "toggled",
-                        G_CALLBACK(change_grisbi_title_type), 
+                        G_CALLBACK ( change_grisbi_title_type ), 
                         entry );
+    gtk_box_pack_start ( GTK_BOX( hbox ), radiogroup, FALSE, FALSE, 0 );
 
-    if (  initial_holder_title && strlen ( initial_holder_title ) )
-    {
-        radio = gtk_radio_button_new_with_label_from_widget ( 
-                    GTK_RADIO_BUTTON ( radiogroup ),
-                    _("Account owner name") );
-        g_object_set_data ( G_OBJECT ( radio ), "display", 
-                    GINT_TO_POINTER ( GSB_ACCOUNT_HOLDER ) );
-        gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
-        if ( etat.display_grisbi_title == GSB_ACCOUNT_HOLDER )
+    radio = gtk_radio_button_new_with_label_from_widget ( 
+                        GTK_RADIO_BUTTON ( radiogroup ),
+                        _("Account owner name") );
+    g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_ACCOUNT_HOLDER ) );
+    if ( conf.display_grisbi_title == GSB_ACCOUNT_HOLDER )
             gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
-        g_signal_connect ( G_OBJECT ( radio ), 
+    g_signal_connect ( G_OBJECT ( radio ), 
                     "toggled",
                     G_CALLBACK ( change_grisbi_title_type ), 
                     entry );
-    }
+    gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
 
     radio = gtk_radio_button_new_with_label_from_widget ( 
-                        GTK_RADIO_BUTTON(radiogroup),
+                        GTK_RADIO_BUTTON ( radiogroup ),
                         _("Filename") );
-    g_object_set_data ( G_OBJECT(radio), "display", 
-                        GINT_TO_POINTER ( GSB_ACCOUNTS_FILE ) );
-    gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
-    if ( etat.display_grisbi_title == GSB_ACCOUNTS_FILE )
-        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (radio), TRUE );
-    g_signal_connect ( G_OBJECT(radio), 
+    g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_ACCOUNTS_FILE ) );
+    if ( conf.display_grisbi_title == GSB_ACCOUNTS_FILE )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
+    g_signal_connect ( G_OBJECT ( radio ), 
                         "toggled",
-                        G_CALLBACK(change_grisbi_title_type), 
+                        G_CALLBACK ( change_grisbi_title_type ), 
                         entry );
+    gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
 
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			 FALSE, FALSE, 0);
 
-    label = gtk_label_new ( COLON(_("Accounts file title")) );
+    label = gtk_label_new ( _("Accounts file title: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0);
 
-    if ( etat.display_grisbi_title == GSB_ACCOUNTS_TITLE )
+    if ( conf.display_grisbi_title == GSB_ACCOUNTS_TITLE )
         gtk_widget_set_sensitive ( entry, TRUE);
     else
         gtk_widget_set_sensitive ( entry, FALSE);
@@ -440,7 +451,7 @@ GtkWidget *onglet_display_addresses ( void )
 					     _("Addresses") );
 
     /* Common address */
-    label = gtk_label_new ( COLON(_("Common address")) );
+    label = gtk_label_new ( _("Common address: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), label,
@@ -459,7 +470,7 @@ GtkWidget *onglet_display_addresses ( void )
 
     /* Secondary address */
     /** \note This is not implemented yet */
-    label = gtk_label_new ( COLON(_("Secondary address")) );
+    label = gtk_label_new ( _("Secondary address: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), label,
@@ -490,18 +501,18 @@ void change_logo_accueil ( GtkWidget * file_selector )
 
     const gchar *selected_filename;
 
-    selected_filename = file_selection_get_filename (GTK_FILE_CHOOSER (file_selector));
+    selected_filename = file_selection_get_filename ( GTK_FILE_CHOOSER ( file_selector ) );
 
     if ( gsb_data_account_get_accounts_amount () )
     {
         /* on change le logo */
         gchar * chemin_logo;
 
-        gtk_container_remove (GTK_CONTAINER(logo_button), preview);
+        gtk_container_remove ( GTK_CONTAINER ( logo_button ), preview );
         chemin_logo = g_strstrip ( g_strdup ( selected_filename ) );
         if ( !strlen ( chemin_logo ) )
         {
-            if ( logo_accueil && GTK_IS_WIDGET ( logo_accueil ))
+            if ( logo_accueil && GTK_IS_WIDGET ( logo_accueil ) )
                 gtk_widget_hide ( logo_accueil );
             preview = gtk_image_new_from_stock ( GTK_STOCK_MISSING_IMAGE,
                              GTK_ICON_SIZE_BUTTON );
@@ -509,8 +520,7 @@ void change_logo_accueil ( GtkWidget * file_selector )
         else
         {
             /* Update preview */
-            pixbuf = gdk_pixbuf_new_from_file (chemin_logo, NULL);
-			g_free(chemin_logo);
+            pixbuf = gdk_pixbuf_new_from_file ( chemin_logo, NULL );
             if (!pixbuf)
             {
                 if ( logo_accueil && GTK_IS_WIDGET ( logo_accueil ))
@@ -520,6 +530,26 @@ void change_logo_accueil ( GtkWidget * file_selector )
             }
             else
             {
+                if ( g_strcmp0 ( g_path_get_dirname ( chemin_logo ), GRISBI_PIXMAPS_DIR ) == 0 )
+                {
+                    gchar *name_logo;
+
+                    etat.is_pixmaps_dir = TRUE;
+
+                    name_logo = g_path_get_basename ( chemin_logo );
+                    if ( g_strcmp0 ( name_logo, "grisbi-logo.png" ) != 0 )
+                        etat.name_logo = name_logo;
+                    else
+                        etat.name_logo = NULL;
+                }
+                else
+                {
+                    etat.is_pixmaps_dir = FALSE;
+                    if ( etat.name_logo && strlen ( etat.name_logo ) )
+                        g_free ( etat.name_logo );
+                    etat.name_logo = NULL;
+                }
+
                 gsb_select_icon_set_logo_pixbuf ( pixbuf );
                 preview = gtk_image_new_from_pixbuf ( 
                         gdk_pixbuf_scale_simple ( 
@@ -536,9 +566,11 @@ void change_logo_accueil ( GtkWidget * file_selector )
                 gtk_window_set_default_icon ( 
                             gsb_select_icon_get_logo_pixbuf ( ) );
             }
+
+            g_free ( chemin_logo );
         }
         gtk_widget_show ( preview );
-        gtk_container_add ( GTK_CONTAINER(logo_button), preview );
+        gtk_container_add ( GTK_CONTAINER ( logo_button ), preview );
         
         /* Mark file as modified */
         if ( etat.modification_fichier == 0 )
@@ -560,20 +592,29 @@ gboolean modification_logo_accueil ( )
 					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					   NULL);
 
-    gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( file_selector ), gsb_file_get_last_path () );
+    if ( etat.is_pixmaps_dir )
+        gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (
+                        file_selector ), GRISBI_PIXMAPS_DIR );
+    else
+        gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (
+                        file_selector ), gsb_file_get_last_path () );
+        
     gtk_window_set_position ( GTK_WINDOW ( file_selector ), GTK_WIN_POS_CENTER_ON_PARENT );
 
     /* create the preview */
     preview = gtk_image_new ();
-    gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (file_selector), preview);
-    g_signal_connect (G_OBJECT (file_selector), "update-preview",
-    		G_CALLBACK (preferences_view_update_preview_logo), preview);
+    gtk_file_chooser_set_preview_widget ( GTK_FILE_CHOOSER ( file_selector ), preview );
+    g_signal_connect (G_OBJECT (file_selector),
+                        "update-preview",
+                        G_CALLBACK ( preferences_view_update_preview_logo ),
+                        preview );
 
     switch ( gtk_dialog_run ( GTK_DIALOG ( file_selector ) ) )
     {
 	case GTK_RESPONSE_OK:
 	    change_logo_accueil ( file_selector );
-	    gsb_file_update_last_path (file_selection_get_last_directory (GTK_FILE_CHOOSER (file_selector), TRUE));
+	    gsb_file_update_last_path ( file_selection_get_last_directory (
+                        GTK_FILE_CHOOSER ( file_selector ), TRUE ) );
 
 	default:
 	    gtk_widget_destroy ( file_selector );
@@ -629,27 +670,13 @@ static gboolean preferences_view_update_preview_logo ( GtkFileChooser *file_choo
 gboolean update_homepage_title (GtkEntry *entry, gchar *value,
                         gint length, gint * position)
 {
-    if ( initial_file_title && strlen ( initial_file_title ) )
-        g_free ( initial_file_title );
+    if ( titre_fichier && strlen ( titre_fichier ) )
+        g_free ( titre_fichier );
 
-    initial_file_title = my_strdup ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
+    titre_fichier = my_strdup ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
 
-    if ( initial_file_title && strlen ( initial_file_title ) > 0 )
-    {
-        gsb_main_page_update_homepage_title ( initial_file_title );
-
-        if ( etat.display_grisbi_title == GSB_ACCOUNTS_TITLE )
-        {
-            if ( titre_fichier && strlen ( titre_fichier ) )
-                g_free ( titre_fichier );
-            titre_fichier = my_strdup ( initial_file_title );
-        }
-    }
-    else if ( GTK_IS_LABEL ( label_titre_fichier ) )
-        gtk_label_set_text ( GTK_LABEL ( label_titre_fichier ), "" );
-
-    /* Update window title */
-    gsb_file_update_window_title ( );
+    /* set Grisbi title */
+    gsb_main_set_grisbi_title ( -1 );
 
     /* Mark file as modified */
     if ( etat.modification_fichier == 0 )
@@ -797,6 +824,8 @@ static GtkWidget *preferences_view_create_color_combobox (void)
     { N_("Background of invalid date entry"), &calendar_entry_color, &default_calendar_entry_color },
     { N_("Background of bet division"), &couleur_bet_division, &default_couleur_bet_division },
     { N_("Background of bet futur"), &couleur_bet_future, &default_couleur_bet_future },
+    { N_("Background of bet solde"), &couleur_bet_solde, &default_couleur_bet_solde },
+    { N_("Background of bet transfer"), &couleur_bet_transfert, &default_couleur_bet_transfert },
     { NULL, 0, 0},
     };
 
@@ -964,57 +993,34 @@ static gboolean preferences_view_color_default ( GtkWidget *button,
  */
 gboolean change_grisbi_title_type ( GtkRadioButton *button, GtkWidget *entry )
 {
-    gint account_number;
-    gchar *tmpstr = NULL;
-
-    if ( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button)) )
+    if ( gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( button ) ) )
     {
-        etat.display_grisbi_title = GPOINTER_TO_INT (g_object_get_data 
-                        ( G_OBJECT ( button ), "display" ));
+        conf.display_grisbi_title = GPOINTER_TO_INT ( g_object_get_data 
+                        ( G_OBJECT ( button ), "display" ) );
     }
 
-    if (titre_fichier && strlen (titre_fichier) )
-        g_free (titre_fichier);
-
-    switch ( etat.display_grisbi_title )
+    switch ( conf.display_grisbi_title )
     {
         case GSB_ACCOUNTS_TITLE:
-            gtk_widget_set_sensitive ( entry, TRUE);
-            if (initial_file_title && strlen (initial_file_title) )
-            {
-                gtk_entry_set_text ( GTK_ENTRY (entry), initial_file_title );
-                titre_fichier = my_strdup ( initial_file_title );
-            }
+            gtk_widget_set_sensitive ( entry, TRUE );
+            if ( titre_fichier && strlen ( titre_fichier ) )
+                gtk_entry_set_text ( GTK_ENTRY ( entry ), titre_fichier );
             else
             {
-                gtk_entry_set_text ( GTK_ENTRY (entry), _("My accounts") );
-                titre_fichier = g_strdup ( _("My accounts") );
+                gtk_entry_set_text ( GTK_ENTRY ( entry ), "" );
+                titre_fichier = NULL;
             }
         break;
         case GSB_ACCOUNT_HOLDER:
             gtk_widget_set_sensitive ( entry, FALSE);
-            account_number = gsb_gui_navigation_get_current_account ( );
-            if ( account_number == -1 )
-            {
-                account_number = gsb_gui_navigation_get_last_account ( );
-                if ( account_number == -1 )
-                    account_number = 0;
-            }
-            tmpstr = my_strdup ( gsb_data_account_get_holder_name  (account_number) );
-            if (tmpstr && strlen (tmpstr) )
-            {
-                titre_fichier = my_strdup ( tmpstr );
-                g_free ( tmpstr );
-            }
         break;
         case GSB_ACCOUNTS_FILE:
-        gtk_widget_set_sensitive ( entry, FALSE);
-        titre_fichier = g_path_get_basename ( nom_fichier_comptes );
+            gtk_widget_set_sensitive ( entry, FALSE);
         break;
     }
-    gsb_file_update_window_title ( );
 
-    gsb_main_page_update_homepage_title ( titre_fichier );
+    /* set Grisbi title */
+    gsb_main_set_grisbi_title ( gsb_gui_navigation_get_current_account ( ) );
 
     return FALSE;
 }
