@@ -26,24 +26,28 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "barre_outils.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_import_rule.h"
-#include "./navigation.h"
-#include "./menu.h"
-#include "./import.h"
-#include "./gsb_reconcile.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_transactions_list.h"
-#include "./traitement_variables.h"
-#include "./print_transactions_list.h"
-#include "./utils_buttons.h"
-#include "./structures.h"
-#include "./include.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_data_import_rule.h"
+#include "navigation.h"
+#include "menu.h"
+#include "import.h"
+#include "gsb_reconcile.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_transactions_list.h"
+#include "traitement_variables.h"
+#include "print_transactions_list.h"
+#include "utils_buttons.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -51,7 +55,7 @@ static GtkWidget *creation_barre_outils ( void );
 static gboolean popup_scheduled_view_mode_menu ( GtkWidget * button );
 static gboolean popup_transaction_rules_menu ( GtkWidget * button,
 					gpointer null );
-static  gboolean popup_transaction_view_mode_menu ( GtkWidget * button,
+static gboolean popup_transaction_view_mode_menu ( GtkWidget * button,
 						   gpointer null );
 /*END_STATIC*/
 
@@ -93,10 +97,8 @@ GtkWidget *creation_barre_outils ( void )
 					       "new-transaction.png",
 					       G_CALLBACK ( new_transaction ),
 					       GINT_TO_POINTER(-1) );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Blank the form to create a new transaction")));
-#endif
+				  _("Blank the form to create a new transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -104,10 +106,8 @@ GtkWidget *creation_barre_outils ( void )
 					   _("Delete"),
 					   G_CALLBACK ( remove_transaction ),
 					   NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Delete selected transaction")));
-#endif
+				  _("Delete selected transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -115,10 +115,8 @@ GtkWidget *creation_barre_outils ( void )
 					   _("Edit"),
 					   G_CALLBACK ( gsb_transactions_list_edit_current_transaction ),
 					   NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Edit current transaction")));
-#endif
+				  _("Edit current transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
     button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
@@ -126,49 +124,34 @@ GtkWidget *creation_barre_outils ( void )
 					       "reconciliation.png",
 					       G_CALLBACK (gsb_reconcile_run_reconciliation),
 					       GINT_TO_POINTER(-1) );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Start account reconciliation")));
-#endif
+				  _("Start account reconciliation"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
-#if GTK_CHECK_VERSION(2,10,0)
     /* This stuff needs GTK+ 2.10 to work. */
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
 					    GTK_STOCK_PRINT,
 					    _("Print"),
 					    G_CALLBACK (print_transactions_list),
 					    NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Print the transactions list")));
-#endif
+				  _("Print the transactions list"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
-#endif /* GTK_CHECK_VERSION(2,10,0) */
 
     menu = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
 					      GTK_STOCK_SELECT_COLOR, _("View"),
 					      G_CALLBACK(popup_transaction_view_mode_menu),
 					      NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (menu),
-				  SPACIFY(_("Change display mode of the list")));
-#endif
+				  _("Change display mode of the list"));
     gtk_box_pack_start ( GTK_BOX(hbox), menu, FALSE, FALSE, 0 );
 
-    /* set the button to show/hide R transactions */
-/*     if ( bouton_affiche_ope_r && GTK_IS_WIDGET ( bouton_affiche_ope_r ) ) */
-/* 	    gtk_box_pack_start ( GTK_BOX ( hbox ), bouton_affiche_ope_r, FALSE, FALSE, 0 ); */
-
-
     menu_import_rules = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
 							    GTK_STOCK_EXECUTE, _("Import rules"),
 							    G_CALLBACK(popup_transaction_rules_menu),
 							    NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (menu_import_rules),
-				  SPACIFY(_("Quick file import by rules")));
-#endif
+				  _("Quick file import by rules"));
     gtk_box_pack_start ( GTK_BOX(hbox), menu_import_rules, FALSE, FALSE, 0 );
 
     gtk_widget_show_all ( hbox );
@@ -244,17 +227,25 @@ static gboolean popup_transaction_view_mode_menu ( GtkWidget * button,
     menu_item = gtk_check_menu_item_new_with_label ( _("Show reconciled transactions") );
     gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM (menu_item),
 				        gsb_data_account_get_r ( current_account ) );
+    if ( etat.equilibrage == 1 )
+        gtk_widget_set_sensitive ( menu_item, FALSE );
+    else
+        gtk_widget_set_sensitive ( menu_item, TRUE );
+
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
     g_signal_connect ( G_OBJECT ( menu_item ),
                         "activate", 
 			            G_CALLBACK ( gsb_gui_toggle_show_reconciled ),
                         NULL );
 
-    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), gtk_separator_menu_item_new ( ) );
-
     menu_item = gtk_check_menu_item_new_with_label ( _("Show lines archives") );
     gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM (menu_item),
 				        gsb_data_account_get_l ( current_account ) );
+    if ( etat.equilibrage == 1 )
+        gtk_widget_set_sensitive ( menu_item, FALSE );
+    else
+        gtk_widget_set_sensitive ( menu_item, TRUE );
+
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
     g_signal_connect ( G_OBJECT ( menu_item ),
                         "activate", 
@@ -502,10 +493,8 @@ GtkWidget *creation_barre_outils_echeancier ( void )
 					       "new-scheduled.png",
 					       G_CALLBACK (gsb_scheduler_list_edit_transaction),
 					       GINT_TO_POINTER(-1) );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Prepare form to create a new scheduled transaction")));
-#endif
+				  _("Prepare form to create a new scheduled transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
     scheduler_button_delete = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -514,10 +503,8 @@ GtkWidget *creation_barre_outils_echeancier ( void )
 							    G_CALLBACK ( gsb_scheduler_list_delete_scheduled_transaction_by_menu ),
 							    NULL );
     gtk_widget_set_sensitive ( scheduler_button_delete, FALSE );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (scheduler_button_delete),
-				  SPACIFY(_("Delete selected scheduled transaction")));
-#endif
+				  _("Delete selected scheduled transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), scheduler_button_delete, FALSE, FALSE, 0 );
 
     scheduler_button_edit = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -526,10 +513,8 @@ GtkWidget *creation_barre_outils_echeancier ( void )
 							  G_CALLBACK ( gsb_scheduler_list_edit_transaction ),
 							  0 );
     gtk_widget_set_sensitive ( scheduler_button_edit, FALSE );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (scheduler_button_edit),
-				SPACIFY(_("Edit selected transaction")));
-#endif
+				_("Edit selected transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), scheduler_button_edit, FALSE, FALSE, 0 );
 
     /* Display/hide comments */
@@ -538,10 +523,8 @@ GtkWidget *creation_barre_outils_echeancier ( void )
 									"comments.png",
 									G_CALLBACK ( gsb_scheduler_list_show_notes ),
 									0 );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (scheduler_display_hide_comments),
-				  SPACIFY(_("Display scheduled transactions comments")));
-#endif
+				  _("Display scheduled transactions comments"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), scheduler_display_hide_comments, 
 			 FALSE, FALSE, 0 );
 
@@ -552,20 +535,16 @@ GtkWidget *creation_barre_outils_echeancier ( void )
 							     G_CALLBACK ( gsb_scheduler_list_execute_transaction ),
 							     NULL ); 
     gtk_widget_set_sensitive ( scheduler_button_execute, FALSE );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (scheduler_button_execute),
-				  SPACIFY(_("Execute current scheduled transaction")));
-#endif
+				  _("Execute current scheduled transaction"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), scheduler_button_execute, FALSE, FALSE, 0 );
 
     button = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
 						GTK_STOCK_SELECT_COLOR, _("View"),
 						G_CALLBACK(popup_scheduled_view_mode_menu),
 						NULL );
-#if GTK_CHECK_VERSION(2,12,0)
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Change display mode of scheduled transaction list")));
-#endif
+				  _("Change display mode of scheduled transaction list"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
 
     gtk_widget_show_all ( handlebox );
