@@ -2,6 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2008 Benjamin Drieu (bdrieu@april.org)                       */
+/*                      2009-2011 Pierre Biava (grisbi@pierre.biava.name)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -20,36 +21,44 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "categories_onglet.h"
-#include "./metatree.h"
-#include "./dialog.h"
-#include "./utils_file_selection.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_file.h"
-#include "./gsb_file_others.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./utils_buttons.h"
-#include "./transaction_list.h"
-#include "./gsb_transactions_list.h"
-#include "./metatree.h"
-#include "./structures.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "gsb_autofunc.h"
+#include "gsb_automem.h"
+#include "gsb_data_category.h"
+#include "gsb_data_transaction.h"
+#include "gsb_file.h"
+#include "gsb_file_others.h"
+#include "gsb_transactions_list.h"
+#include "main.h"
+#include "metatree.h"
+#include "mouse.h"
+#include "structures.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "utils.h"
+#include "utils_buttons.h"
+#include "utils_file_selection.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static void appui_sur_ajout_category ( GtkTreeModel * model, GtkButton *button );
 static gboolean categ_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * path,
 			       GtkSelectionData * selection_data );
+static gboolean category_list_button_press ( GtkWidget *tree_view,
+                        GdkEventButton *ev,
+                        gpointer null );
+static void category_list_popup_context_menu ( void );
+static void category_list_toggle_edit_category ( GtkCheckMenuItem *menu_item, gpointer data );
 static GtkWidget *creation_barre_outils_categ ( void );
 static gboolean edit_category ( GtkTreeView * view );
 static gboolean exporter_categ ( GtkButton * widget, gpointer data );
@@ -72,6 +81,7 @@ struct metatree_hold_position *category_hold_position;
 
 /*START_EXTERN*/
 extern MetatreeInterface * category_interface;
+extern GdkColor couleur_selection;
 extern GtkWidget *window;
 /*END_EXTERN*/
 
@@ -94,6 +104,10 @@ GtkWidget *onglet_categories ( void )
 
     /* We create the gtktreeview and model early so that they can be referenced. */
     arbre_categ = gtk_tree_view_new();
+
+    /* set the color of selected row */
+    gtk_widget_modify_base ( arbre_categ, GTK_STATE_SELECTED, &couleur_selection );
+
     categ_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
 
     /* We create the main vbox */
@@ -171,10 +185,20 @@ GtkWidget *onglet_categories ( void )
     gtk_widget_show ( arbre_categ );
 
     /* Connect to signals */
-    g_signal_connect ( G_OBJECT(arbre_categ), "row-expanded",
-		       G_CALLBACK(division_column_expanded), NULL );
-    g_signal_connect( G_OBJECT(arbre_categ), "row-activated",
-		      G_CALLBACK(division_activated), NULL);
+    g_signal_connect ( G_OBJECT ( arbre_categ ),
+                        "row-expanded",
+                        G_CALLBACK ( division_column_expanded ),
+                        NULL );
+
+    g_signal_connect( G_OBJECT ( arbre_categ ),
+                        "row-activated",
+                        G_CALLBACK ( division_activated ),
+                        NULL);
+
+    g_signal_connect ( G_OBJECT ( arbre_categ ),
+                        "button-press-event",
+                        G_CALLBACK ( category_list_button_press ),
+                        NULL );
 
     dst_iface = GTK_TREE_DRAG_DEST_GET_IFACE (categ_tree_model);
     if ( dst_iface )
@@ -193,9 +217,10 @@ GtkWidget *onglet_categories ( void )
 	src_iface -> drag_data_get = &categ_drag_data_get;
     }
 
-    g_signal_connect ( gtk_tree_view_get_selection ( GTK_TREE_VIEW(arbre_categ)),
-		       "changed", G_CALLBACK(metatree_selection_changed),
-		       categ_tree_model );
+    g_signal_connect ( gtk_tree_view_get_selection ( GTK_TREE_VIEW ( arbre_categ ) ),
+                        "changed",
+                        G_CALLBACK ( metatree_selection_changed ),
+                        categ_tree_model );
 
     /* création de la structure de sauvegarde de la position */
     category_hold_position = g_malloc0 ( sizeof ( struct metatree_hold_position ) );
@@ -212,7 +237,6 @@ void remplit_arbre_categ ( void )
 {
     GSList *category_list;
     GtkTreeIter iter_categ, iter_sous_categ;
-    GtkTreeSelection *selection;
 
     devel_debug (NULL);
 
@@ -281,6 +305,8 @@ void remplit_arbre_categ ( void )
 
     if ( category_hold_position -> path )
     {
+        GtkTreeSelection *selection;
+
         if ( category_hold_position -> expand )
         {
             GtkTreePath *ancestor;
@@ -299,7 +325,6 @@ void remplit_arbre_categ ( void )
 }
 
 
-
 /**
  * Fill the drag & drop structure with the path of selected column.
  * This is an interface function called from GTK, much like a callback.
@@ -484,7 +509,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 					       G_CALLBACK ( appui_sur_ajout_category ),
 					       categ_tree_model );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Create a new category")));
+				  _("Create a new category"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
     g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (1) );
 
@@ -497,7 +522,7 @@ GtkWidget *creation_barre_outils_categ ( void )
     metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "sub-division" );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Create a new sub-category")));
+				  _("Create a new sub-category"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
     g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (2) );
 
@@ -508,7 +533,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 					   G_CALLBACK (importer_categ),
 					   NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Import a Grisbi category file (.cgsb)")));
+				  _("Import a Grisbi category file (.cgsb)"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
 
     /* Export button */
@@ -518,7 +543,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 					   G_CALLBACK(exporter_categ),
 					   NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Export a Grisbi category file (.cgsb)")));
+				  _("Export a Grisbi category file (.cgsb)"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
 
     /* Delete button */
@@ -527,7 +552,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 					   G_CALLBACK (supprimer_division), arbre_categ );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Delete selected category")));
+				  _("Delete selected category"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
 
     /* Properties button */
@@ -536,7 +561,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 					   G_CALLBACK (edit_category), arbre_categ );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Edit selected category")));
+				  _("Edit selected category"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
 
     /* View button */
@@ -546,7 +571,7 @@ GtkWidget *creation_barre_outils_categ ( void )
 						G_CALLBACK (popup_category_view_mode_menu),
 						NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Change view mode")));
+				  _("Change view mode"));
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
 
     gtk_widget_show_all ( handlebox );
@@ -872,6 +897,16 @@ void selectionne_sub_category ( GtkTreeModel * model )
 }
 
 
+/**
+ * renvoie le chemin de la dernière categorie sélectionnée.
+ *
+ * \return une copie de category_hold_position -> path
+ */
+GtkTreePath *category_hold_position_get_path ( void )
+{
+    return gtk_tree_path_copy ( category_hold_position -> path );
+}
+
 /**
  * sauvegarde le chemin de la dernière categorie sélectionnée.
  *
@@ -883,6 +918,8 @@ gboolean category_hold_position_set_path ( GtkTreePath *path )
 
     return TRUE;
 }
+
+
 /**
  * sauvegarde l'attribut expand.
  *
@@ -895,6 +932,155 @@ gboolean category_hold_position_set_expand ( gboolean expand )
     return TRUE;
 }
 
+
+/**
+ * called when we press a button on the list
+ *
+ * \param tree_view
+ * \param ev
+ *
+ * \return FALSE
+ * */
+gboolean category_list_button_press ( GtkWidget *tree_view,
+                        GdkEventButton *ev,
+                        gpointer null )
+{
+    if ( ev -> button == RIGHT_BUTTON )
+    {
+        category_list_popup_context_menu ( );
+
+        return TRUE;
+    }
+    else if ( ev -> type == GDK_2BUTTON_PRESS )
+    {
+        GtkTreeSelection *selection;
+        GtkTreeModel *model;
+        GtkTreeIter iter;
+        GtkTreePath *path = NULL;
+        enum meta_tree_row_type type_division;
+
+        type_division = metatree_get_row_type_from_tree_view ( tree_view );
+        if ( type_division == META_TREE_TRANSACTION )
+            return FALSE;
+
+        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
+        if ( selection && gtk_tree_selection_get_selected (selection, &model, &iter ) )
+            path = gtk_tree_model_get_path  ( model, &iter);
+
+        if ( conf.metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
+        {
+            if ( gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
+                gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
+            else
+                gtk_tree_view_expand_row ( GTK_TREE_VIEW ( tree_view ), path, FALSE );
+
+            gtk_tree_path_free ( path );
+            return FALSE;
+        }
+        else if ( conf.metatree_action_2button_press == 1 )
+        {
+            edit_category ( GTK_TREE_VIEW ( tree_view ) );
+
+            gtk_tree_path_free ( path );
+            return TRUE;
+        }
+        else
+        {
+            if ( type_division == META_TREE_SUB_DIV || type_division == META_TREE_TRANS_S_S_DIV )
+            {
+                    path = gtk_tree_model_get_path  ( model, &iter);
+                    gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
+
+                    gtk_tree_path_free ( path );
+
+                metatree_manage_sub_divisions ( tree_view );
+                return TRUE;
+            }
+            else
+                return FALSE;
+        }
+    }
+
+    return FALSE;
+}
+
+
+/**
+ * Pop up a menu with several actions to apply to current selection.
+ *
+ * \param
+ *
+ */
+void category_list_popup_context_menu ( void )
+{
+    GtkWidget *menu;
+    GtkWidget *menu_item;
+    gchar *title;
+    enum meta_tree_row_type type_division;
+
+    type_division = metatree_get_row_type_from_tree_view ( arbre_categ );
+
+    if ( type_division == META_TREE_TRANSACTION
+     ||
+     type_division == META_TREE_INVALID )
+        return;
+
+    menu = gtk_menu_new ();
+
+    if ( type_division == META_TREE_DIV || type_division == META_TREE_SUB_DIV )
+    {
+
+        /* Edit transaction */
+        if ( type_division == META_TREE_DIV )
+            title = g_strdup ( _("Edit selected category") );
+        else
+            title = g_strdup ( _("Edit selected sub-category") );
+
+        menu_item = gtk_image_menu_item_new_with_label ( title );
+        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
+                            gtk_image_new_from_stock ( GTK_STOCK_PROPERTIES,
+                            GTK_ICON_SIZE_MENU ) );
+        g_signal_connect_swapped ( G_OBJECT ( menu_item ),
+                            "activate",
+                            G_CALLBACK ( edit_category ),
+                            arbre_categ );
+        gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+
+        g_free ( title );
+    }
+
+    if ( type_division == META_TREE_SUB_DIV || type_division == META_TREE_TRANS_S_S_DIV )
+    {
+        /* Manage sub_divisions */
+        if ( type_division == META_TREE_SUB_DIV )
+        {
+            /* Separator */
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), gtk_separator_menu_item_new ( ) );
+            title = g_strdup ( _("Manage sub-categories") );
+        }
+        else
+            title = g_strdup ( _("Transfer all transactions in another sub-category") );
+
+        menu_item = gtk_image_menu_item_new_with_label ( title );
+        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
+                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
+                        GTK_ICON_SIZE_MENU ) );
+        g_signal_connect_swapped ( G_OBJECT ( menu_item ),
+                        "activate",
+                        G_CALLBACK ( metatree_manage_sub_divisions ),
+                        arbre_categ );
+        gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+
+        g_free ( title );
+    }
+
+    /* Finish all. */
+    gtk_widget_show_all ( menu );
+
+    gtk_menu_popup ( GTK_MENU ( menu ), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time ( ) );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
