@@ -21,16 +21,20 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "csv_parse.h"
-#include "./utils_dates.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_real.h"
-#include "./utils_str.h"
-#include "./gsb_data_transaction.h"
-#include "./import.h"
+#include "utils_dates.h"
+#include "gsb_data_currency.h"
+#include "gsb_real.h"
+#include "utils_str.h"
+#include "gsb_data_transaction.h"
+#include "import.h"
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
@@ -344,7 +348,9 @@ gboolean csv_import_parse_notes ( struct struct_ope_importation * ope, gchar * s
 gboolean csv_import_parse_voucher ( struct struct_ope_importation * ope, gchar * string )
 {
     g_return_val_if_fail ( string, FALSE );
-    ope -> cheque = my_strtod ( string, NULL );
+    if ( ope -> cheque )
+        g_free ( ope -> cheque );
+    ope -> cheque = my_strdup ( string );
     return TRUE;
 }
 
