@@ -21,13 +21,16 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "dialog.h"
-#include "./parametres.h"
-#include "./include.h"
+#include "parametres.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -49,10 +52,6 @@ extern GtkWidget *window;
 /** All messages */
 struct conditional_message messages[] =
 {
-    { "no-tip-available", N_("No tip of the day available"), 
-      N_("Make sure that grisbi was correctly installed and that tips file is readable."),
-      FALSE, FALSE, },
-
     { "ofx-security-not-implemented", N_("Security feature not implemented"),
       N_("This file contains security information, which processing is not implemented at "
       "this moment."),
@@ -67,7 +66,7 @@ struct conditional_message messages[] =
 
     { "account-file-readable",  N_("Account file is world readable."),
       N_("Your account file should not be readable by anybody else, but it is. You should "
-      "change its permissions.\nShould this be fixed now?"),
+      "change its permissions."),
       FALSE, FALSE, },
 
     { "account-already-opened", N_("File \"%s\" is already opened"),
@@ -109,8 +108,8 @@ struct conditional_message messages[] =
 
     { "development-version", N_("You are running Grisbi version %s"), 
       N_("Warning, please be aware that the version you run is a DEVELOPMENT version. "
-     "In any case do not work with this version on your original accounting files. "
-     "(File format may change and render files incompatible with previous versions)."),
+      "Never use your original file grisbi: you could make it unusable.\n"
+      "Make a copy now."),
       FALSE, FALSE },
 
     { "gtk_obsolete", N_("You are running Grisbi with GTK version %s"), 
@@ -169,7 +168,7 @@ G_MODULE_EXPORT void dialogue_error ( gchar *text )
  * \param text Text to display in window
  * \param hint Text to display in window as hint (bold, larger)
  */
-G_MODULE_EXPORT void dialogue_error_hint ( gchar *text, gchar *hint )
+G_MODULE_EXPORT void dialogue_error_hint ( const gchar *text, gchar *hint )
 {
     dialogue_special ( GTK_MESSAGE_ERROR, make_hint (hint, text) );
 }
@@ -580,13 +579,21 @@ gint question_conditional_yes_no_get_no_struct ( struct conditional_message *msg
  *
  * \return a pango formated string with the two arguments concatenated. It returns a newly allocated string which must be freed when no more used.
  */
-gchar *make_hint ( gchar *hint, gchar *text )
+gchar *make_hint ( const gchar *hint, const gchar *text )
 {
-    gchar *tmp_str;
+    gchar *tmp_str = NULL;
+    gchar *tmp_markup_str;
+
+    tmp_markup_str = g_markup_printf_escaped (
+                     "<span size=\"larger\" weight=\"bold\">%s</span>\n\n", hint );
+
+    if ( text && strlen ( text ) )
+        tmp_str = g_strconcat ( tmp_markup_str, text, NULL );
+    else
+        tmp_str = g_strdup ( tmp_markup_str );
+
+    g_free ( tmp_markup_str );
 
-    tmp_str = g_strconcat ( g_markup_printf_escaped (
-                        "<span size=\"larger\" weight=\"bold\">%s</span>\n\n", hint ),
-                        text, NULL );
     return tmp_str;
 }
 
