@@ -21,37 +21,35 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "etats_calculs.h"
-#include "./etats_affiche.h"
-#include "./utils_dates.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_report_amout_comparison.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_report_text_comparison.h"
-#include "./gsb_data_transaction.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_status.h"
-#include "./utils_str.h"
-#include "./print_config.h"
-#include "./gsb_data_account.h"
-#include "./navigation.h"
-#include "./gsb_data_transaction.h"
-#include "./structures.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
-#include "./print_config.h"
-#include "./etats_affiche.h"
+#include "etats_affiche.h"
+#include "utils_dates.h"
+#include "gsb_data_account.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_report_amout_comparison.h"
+#include "gsb_data_report.h"
+#include "gsb_data_report_text_comparison.h"
+#include "gsb_data_transaction.h"
+#include "navigation.h"
+#include "gsb_real.h"
+#include "gsb_status.h"
+#include "utils_str.h"
+#include "print_config.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -724,10 +722,7 @@ GSList *recupere_opes_etat ( gint report_number )
 			GDate *date_jour;
 			GDate *date_tmp;
 
-			date_jour = g_date_new ();
-			g_date_set_time ( date_jour,
-					  time ( NULL ));
-
+			date_jour = gdate_today ( );
 
 			switch ( gsb_data_report_get_date_type (report_number))
 			{
@@ -762,25 +757,25 @@ GSList *recupere_opes_etat ( gint report_number )
 			    case 3:
 				/* mois en cours */
 
-				if ( g_date_month ( date_jour ) != g_date_month ( gsb_data_transaction_get_date (transaction_number_tmp))
+				if ( g_date_get_month ( date_jour ) != g_date_get_month ( gsb_data_transaction_get_date (transaction_number_tmp))
 				     ||
-				     g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
+				     g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
 				    goto operation_refusee;
 				break;
 
 			    case 4:
 				/* année en cours */
 
-				if ( g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
+				if ( g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
 				    goto operation_refusee;
 				break;
 
 			    case 5:
 				/* cumul mensuel */
 
-				if ( g_date_month ( date_jour ) != g_date_month ( gsb_data_transaction_get_date (transaction_number_tmp))
+				if ( g_date_get_month ( date_jour ) != g_date_get_month ( gsb_data_transaction_get_date (transaction_number_tmp))
 				     ||
-				     g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp))
+				     g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp))
 				     ||
 				     g_date_compare ( date_jour,
 						      gsb_data_transaction_get_date (transaction_number_tmp)) < 0 )
@@ -790,7 +785,7 @@ GSList *recupere_opes_etat ( gint report_number )
 			    case 6:
 				/* cumul annuel */
 
-				if ( g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp))
+				if ( g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp))
 				     ||
 				     g_date_compare ( date_jour,
 						      gsb_data_transaction_get_date (transaction_number_tmp)) < 0 )
@@ -803,9 +798,9 @@ GSList *recupere_opes_etat ( gint report_number )
 				g_date_subtract_months ( date_jour,
 							 1 );
 
-				if ( g_date_month ( date_jour ) != g_date_month ( gsb_data_transaction_get_date (transaction_number_tmp))
+				if ( g_date_get_month ( date_jour ) != g_date_get_month ( gsb_data_transaction_get_date (transaction_number_tmp))
 				     ||
-				     g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
+				     g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
 				    goto operation_refusee;
 				break;
 
@@ -815,16 +810,16 @@ GSList *recupere_opes_etat ( gint report_number )
 				g_date_subtract_years ( date_jour,
 							1 );
 
-				if ( g_date_year ( date_jour ) != g_date_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
+				if ( g_date_get_year ( date_jour ) != g_date_get_year ( gsb_data_transaction_get_date (transaction_number_tmp)))
 				    goto operation_refusee;
 				break;
 
 			    case 9:
 				/* 30 derniers jours */
 
-				date_tmp = g_date_new_dmy ( g_date_day ( date_jour ),
-							    g_date_month ( date_jour ),
-							    g_date_year ( date_jour ) );
+				date_tmp = g_date_new_dmy ( g_date_get_day ( date_jour ),
+							    g_date_get_month ( date_jour ),
+							    g_date_get_year ( date_jour ) );
 				g_date_subtract_days ( date_tmp,
 						       30 );
 				if ( g_date_compare ( date_tmp,
@@ -838,9 +833,9 @@ GSList *recupere_opes_etat ( gint report_number )
 			    case 10:
 				/* 3 derniers mois */
 
-				date_tmp = g_date_new_dmy ( g_date_day ( date_jour ),
-							    g_date_month ( date_jour ),
-							    g_date_year ( date_jour ) );
+				date_tmp = g_date_new_dmy ( g_date_get_day ( date_jour ),
+							    g_date_get_month ( date_jour ),
+							    g_date_get_year ( date_jour ) );
 				g_date_subtract_months ( date_tmp,
 							 3 );
 				if ( g_date_compare ( date_tmp,
@@ -854,9 +849,9 @@ GSList *recupere_opes_etat ( gint report_number )
 			    case 11:
 				/* 6 derniers mois */
 
-				date_tmp = g_date_new_dmy ( g_date_day ( date_jour ),
-							    g_date_month ( date_jour ),
-							    g_date_year ( date_jour ) );
+				date_tmp = g_date_new_dmy ( g_date_get_day ( date_jour ),
+							    g_date_get_month ( date_jour ),
+							    g_date_get_year ( date_jour ) );
 				g_date_subtract_months ( date_tmp,
 							 6 );
 				if ( g_date_compare ( date_tmp,
@@ -870,9 +865,9 @@ GSList *recupere_opes_etat ( gint report_number )
 			    case 12:
 				/* 12 derniers mois */
 
-				date_tmp = g_date_new_dmy ( g_date_day ( date_jour ),
-							    g_date_month ( date_jour ),
-							    g_date_year ( date_jour ) );
+				date_tmp = g_date_new_dmy ( g_date_get_day ( date_jour ),
+							    g_date_get_month ( date_jour ),
+							    g_date_get_year ( date_jour ) );
 				g_date_subtract_months ( date_tmp,
 							 12 );
 				if ( g_date_compare ( date_tmp,
