@@ -21,16 +21,19 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "etats_csv.h"
-#include "./dialog.h"
-#include "./utils_files.h"
-#include "./etats_config.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./etats_affiche.h"
+#include "dialog.h"
+#include "utils_files.h"
+#include "etats_config.h"
+#include "structures.h"
+#include "etats_affiche.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -150,20 +153,29 @@ void csv_attach_hsep ( gint x, gint x2, gint y, gint y2)
  */
 gint csv_initialise (GSList * opes_selectionnees, gchar * filename )
 {
+
     g_return_val_if_fail ( filename, FALSE );
+
    /* initialise values */
     csv_lastcol = 0;
     csv_lastline = 1;
 
-    unlink ( filename );	/* We don't care if this fails, this
-				 * is just to guarantee next will
-				 * not fail if file is existing.  This
-				 * will help against file races. */
-    csv_out = utf8_fopen ( filename, "w+x" );
+    /* on efface le fichier s'il existe déjà */
+    if ( g_file_test ( filename, G_FILE_TEST_IS_REGULAR ) )
+        g_unlink ( filename );
+
+    csv_out = utf8_fopen ( filename, "w" );
     if ( ! csv_out )
     {
-	dialogue_error ( g_strdup_printf (_("Unable to open file '%s'"), filename ));
-	return FALSE;
+        gchar *sMessage = NULL;
+
+        sMessage = g_strdup_printf ( _("Unable to create file \"%s\" :\n%s"),
+                         filename, g_strerror ( errno ) );
+        dialogue ( sMessage );
+
+        g_free ( sMessage );
+
+        return FALSE;
     }
 
     return TRUE;
