@@ -19,15 +19,18 @@
 /*     along with this program; if not, write to the Free Software */
 /*     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "etats_support.h"
-#include "./utils_dates.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_report.h"
-#include "./include.h"
+#include "utils_dates.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_report.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -217,7 +220,7 @@ gchar *etats_titre ( gint report_number)
 				      ", ", 
 				      g_strdup_printf ( _("%s %d"),
 							buffer_date,
-							g_date_year (today_date)),
+							g_date_get_year (today_date)),
 				      NULL );
 		break;
 
@@ -226,7 +229,7 @@ gchar *etats_titre ( gint report_number)
 
 		titre = g_strconcat ( titre,
 				      ", ", g_strdup_printf ( _("year %d"),
-							      g_date_year (today_date)),
+							      g_date_get_year (today_date)),
 				      NULL );
 		break;
 
@@ -264,7 +267,7 @@ gchar *etats_titre ( gint report_number)
 				      ", ", 
 				      g_strdup_printf ( _("%s %d"),
 							buffer_date,
-							g_date_year (today_date)),
+							g_date_get_year (today_date)),
 				      NULL );
 		break;
 
@@ -273,16 +276,14 @@ gchar *etats_titre ( gint report_number)
 
 		titre = g_strconcat ( titre,
 				      ", ", g_strdup_printf ( _("year %d"),
-							      g_date_year (today_date) - 1),
+							      g_date_get_year (today_date) - 1),
 				      NULL );
 		break;
 
 	    case 9:
 		/* 30 derniers jours */
 
-		date_tmp = g_date_new ();
-		g_date_set_time ( date_tmp,
-				  time ( NULL ));
+		date_tmp = gdate_today ( );
 
 		g_date_subtract_days ( date_tmp,
 				       30 );
@@ -298,9 +299,7 @@ gchar *etats_titre ( gint report_number)
 	    case 10:
 		/* 3 derniers mois */
 
-		date_tmp = g_date_new ();
-		g_date_set_time ( date_tmp,
-				  time ( NULL ));
+		date_tmp = gdate_today ( );
 		g_date_subtract_months ( date_tmp,
 					 3 );
 		g_date_strftime ( buffer_date_2,
@@ -316,20 +315,18 @@ gchar *etats_titre ( gint report_number)
 				      ", ", 
 				      g_strdup_printf ( _("from %s %d"),
 							buffer_date_2,
-							g_date_year ( date_tmp )),
+							g_date_get_year ( date_tmp )),
 				      " ",
 				      g_strdup_printf ( _("to %s %d"),
 							buffer_date,
-							g_date_year (today_date)),
+							g_date_get_year (today_date)),
 				      NULL );
 		break;
 
 	    case 11:
 		/* 6 derniers mois */
 
-		date_tmp = g_date_new ();
-		g_date_set_time ( date_tmp,
-				  time ( NULL ));
+		date_tmp = gdate_today ( );
 		g_date_subtract_months ( date_tmp,
 					 6 );
 		g_date_strftime ( buffer_date_2,
@@ -346,20 +343,18 @@ gchar *etats_titre ( gint report_number)
 				      ", ", 
 				      g_strdup_printf ( _("from %s %d"),
 							buffer_date_2,
-							g_date_year ( date_tmp )),
+							g_date_get_year ( date_tmp )),
 				      " ",
 				      g_strdup_printf ( _("to %s %d"),
 							buffer_date,
-							g_date_year (today_date)),
+							g_date_get_year (today_date)),
 				      NULL );
 		break;
 
 	    case 12:
 		/* 12 derniers mois */
 
-		date_tmp = g_date_new ();
-		g_date_set_time ( date_tmp,
-				  time ( NULL ));
+		date_tmp = gdate_today ( );
 		g_date_subtract_months ( date_tmp,
 					 12 );
 		g_date_strftime ( buffer_date_2,
@@ -375,11 +370,11 @@ gchar *etats_titre ( gint report_number)
 				      ", ", 
 				      g_strdup_printf ( _("from %s %d"),
 							buffer_date_2,
-							g_date_year ( date_tmp )),
+							g_date_get_year ( date_tmp )),
 				      " ",
 				      g_strdup_printf ( _("to %s %d"),
 							buffer_date,
-							g_date_year (today_date)),
+							g_date_get_year (today_date)),
 				      NULL );
 		break;
 	}
