@@ -30,26 +30,36 @@
 
 /*START_INCLUDE*/
 #include "export.h"
-#include "gsb_assistant.h"
+#include "dialog.h"
 #include "export_csv.h"
+#include "gsb_assistant.h"
+#include "gsb_automem.h"
 #include "gsb_data_account.h"
 #include "gsb_file.h"
-#include "dialog.h"
-#include "utils.h"
 #include "qif.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
 /*START_STATIC*/
 static GtkWidget * create_export_account_resume_page ( struct exported_account * account );
+static void export_account_all_toggled ( GtkToggleButton *button,
+                        GtkTreeView *tree_view );
 static gboolean export_account_change_format ( GtkWidget * combo,
 					struct exported_account * account );
+static gboolean export_account_radiobutton_format_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur );
+static void expert_account_free_account_structure ( struct exported_account *account );
 static void export_account_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
 			      GtkTreeModel * model );
 static GtkWidget * export_create_final_page ( GtkWidget * assistant );
 static GtkWidget * export_create_resume_page ( GtkWidget * assistant );
 static GtkWidget * export_create_selection_page ( GtkWidget * assistant );
+static gboolean export_enter_final_page ( GtkWidget *assistant );
 static gboolean export_enter_resume_page ( GtkWidget * assistant );
 static void export_resume_maybe_sensitive_next ( GtkWidget * assistant );
 /*END_STATIC*/
@@ -63,7 +73,6 @@ static GSList *selected_accounts = NULL;
 static GSList *exported_accounts = NULL;
 
 
-
 /**
  *
  *
@@ -72,53 +81,79 @@ static GSList *exported_accounts = NULL;
 void export_accounts ( void )
 {
     GtkWidget *dialog;
+    gchar *extension = NULL;
 
     selected_accounts = NULL;
     exported_accounts = NULL;
 
     dialog = gsb_assistant_new ( _("Exporting Grisbi accounts"),
-				 _("This assistant will guide you through the process of "
-				   "exporting Grisbi accounts into QIF or CSV files.\n\n"
-				   "As QIF and CSV do not support currencies, all "
-				   "transactions will be converted into currency of their "
-				   "respective account."),
-				 "impexp.png",
-				 NULL );
+                        _("This assistant will guide you through the process of "
+                        "exporting Grisbi accounts into QIF or CSV files.\n\n"
+                        "As QIF and CSV do not support currencies, all "
+                        "transactions will be converted into currency of their "
+                        "respective account."),
+                        "impexp.png",
+                        NULL );
 
-    gsb_assistant_add_page ( dialog, export_create_selection_page(dialog), 1, 0, 2,
-			     G_CALLBACK ( export_resume_maybe_sensitive_next ) );
-    gsb_assistant_add_page ( dialog, export_create_resume_page(dialog), 2, 1, 3,
-			     G_CALLBACK ( export_enter_resume_page ) );
+    gsb_assistant_add_page ( dialog, export_create_selection_page ( dialog ), 1, 0, 2,
+                        G_CALLBACK ( export_resume_maybe_sensitive_next ) );
+    gsb_assistant_add_page ( dialog, export_create_resume_page ( dialog ), 2, 1, 3,
+                        G_CALLBACK ( export_enter_resume_page ) );
 
 
     if ( gsb_assistant_run ( dialog ) == GTK_RESPONSE_APPLY )
     {
-	while ( exported_accounts )
-	{
-	    struct exported_account * account;
+        while ( exported_accounts )
+        {
+            struct exported_account *account;
 
-	    account = (struct exported_account *) exported_accounts -> data;
+            account = (struct exported_account *) exported_accounts->data;
 
-	    account -> filename = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER(account -> chooser) );
+            if ( etat.export_files_traitement )
+            {
+                const gchar *title;
+                gchar *tmp_str;
 
-	    if ( account -> format == EXPORT_QIF )
-	    {
-		qif_export ( account -> filename, account -> account_nb, 0 );
-	    }
-	    else
-	    {
-		gsb_csv_export_account ( account -> filename, account -> account_nb );
-	    }
+                if ( titre_fichier && strlen ( titre_fichier ) )
+                    title = titre_fichier;
+                else
+                    title = g_get_user_name ( );
 
-	    exported_accounts = exported_accounts -> next;
-	}
+                if ( extension == NULL )
+                    extension = g_strdup ( account->extension );
+
+                tmp_str = g_strconcat ( title, "-",
+                                gsb_data_account_get_name ( account -> account_nb ),
+                                ".",
+                                extension,
+                                NULL );
+
+                account -> filename = g_build_filename ( gsb_file_get_last_path (), tmp_str, NULL );
+
+                g_free ( tmp_str );
+            }
+            else
+            {
+                account->filename = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( account -> chooser ) );
+                extension = g_strdup ( account->extension );
+            }
+
+            if ( strcmp ( extension, "qif" ) == 0 )
+                qif_export ( account->filename, account->account_nb, 0 );
+            else    /* extension = csv */
+                gsb_csv_export_account ( account->filename, account->account_nb );
+
+            exported_accounts = exported_accounts->next;
+        }
     }
 
+    g_free ( extension );
+    g_slist_free ( selected_accounts );
+    g_slist_free_full ( exported_accounts, ( GDestroyNotify ) expert_account_free_account_structure );
     gtk_widget_destroy ( dialog );
 }
 
 
-
 /**
  *
  *
@@ -126,6 +161,9 @@ void export_accounts ( void )
 GtkWidget * export_create_selection_page ( GtkWidget * assistant )
 {
     GtkWidget * view, * vbox, * padding_box, * sw;
+    GtkWidget *combo;
+    GtkWidget *button;
+    GtkWidget *button_select;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
     GtkListStore * model;
@@ -191,17 +229,39 @@ GtkWidget * export_create_selection_page ( GtkWidget * assistant )
 	tmp_list = tmp_list -> next;
     }
 
+    button_select = g_object_get_data ( G_OBJECT ( assistant ), "button_select" );
+    g_object_set_data ( G_OBJECT ( button_select ), "tree_view", view );
+    g_signal_connect ( G_OBJECT ( button_select ),
+                        "toggled",
+                        G_CALLBACK ( export_account_all_toggled ),
+                        view );
+
+    combo = gsb_automem_radiobutton3_new_with_title ( vbox,
+					    _("Select options to export" ),
+					    _("QIF format" ), _("CSV format" ), NULL,
+					    &etat.export_file_format,
+					    G_CALLBACK ( export_account_radiobutton_format_changed ),
+                        &etat.export_file_format,
+                        GTK_ORIENTATION_HORIZONTAL );
+
+    button = gsb_automem_checkbutton_new ( _("Treat all files as the first" ),
+                        &etat.export_files_traitement,
+                        NULL,
+                        NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 0 );
+
+    /* return */
     return vbox;
 }
 
 
-
 /**
  *
  *
  */
 GtkWidget * export_create_resume_page ( GtkWidget * assistant )
 {
+    GtkWidget *sw;
     GtkWidget * view;
     GtkTextBuffer * buffer;
 
@@ -223,7 +283,15 @@ GtkWidget * export_create_resume_page ( GtkWidget * assistant )
 
     g_object_set_data ( G_OBJECT ( assistant ), "text-buffer", buffer );
 
-    return view;
+    /* Scroll for view. */
+    sw = gtk_scrolled_window_new ( NULL, NULL );
+    gtk_widget_set_size_request ( sw, 480, 200 );
+    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( sw ), GTK_SHADOW_ETCHED_IN );
+    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( sw ), GTK_POLICY_AUTOMATIC,
+                        GTK_POLICY_AUTOMATIC );
+    gtk_container_add ( GTK_CONTAINER ( sw ), view );
+
+    return sw;
 }
 
 
@@ -273,15 +341,20 @@ GtkWidget * export_create_final_page ( GtkWidget * assistant )
  */
 gboolean export_enter_resume_page ( GtkWidget * assistant )
 {
-    GtkTextBuffer * buffer;
+    GtkWidget *button_select;
+    GtkTextBuffer *buffer;
     GtkTextIter iter;
-    GSList * list;
+    GSList *list;
     gint page = 3;
+    gint index = 0;
 
     buffer = g_object_get_data ( G_OBJECT ( assistant ), "text-buffer" );
     gtk_text_buffer_set_text (buffer, "\n", -1 );
     gtk_text_buffer_get_iter_at_offset (buffer, &iter, 1);
 
+    button_select = g_object_get_data ( G_OBJECT ( assistant ), "button_select" );
+    gtk_widget_hide ( button_select );
+
     if ( selected_accounts && g_slist_length ( selected_accounts ) )
     {
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter,
@@ -296,8 +369,7 @@ gboolean export_enter_resume_page ( GtkWidget * assistant )
 				-1 );
 	gtk_text_buffer_insert (buffer, &iter, "\n\n", -1 );
 
-	while ( gtk_notebook_get_n_pages ( g_object_get_data ( G_OBJECT (assistant), "notebook" ) ) >
-		3 )
+	while ( gtk_notebook_get_n_pages ( g_object_get_data ( G_OBJECT (assistant), "notebook" ) ) > 3 )
 	{
 	    gtk_notebook_remove_page ( g_object_get_data ( G_OBJECT (assistant), "notebook" ), -1 );
 	}
@@ -305,24 +377,40 @@ gboolean export_enter_resume_page ( GtkWidget * assistant )
 	list = selected_accounts;
 	while ( list )
 	{
-	    struct exported_account * account;
-	    gint i = GPOINTER_TO_INT(list -> data);
+	    struct exported_account *account;
+	    gint i = GPOINTER_TO_INT ( list -> data );
 
 	    gtk_text_buffer_insert_with_tags_by_name (buffer, &iter,
-						      g_strconcat ( "• ",
-								    gsb_data_account_get_name ( i ),
-								    "\n\n",
-								    NULL ),
-						      -1, "indented", NULL );
+                                g_strconcat ( "• ",
+                                gsb_data_account_get_name ( i ),
+                                "\n\n",
+                                NULL ),
+                                -1, "indented", NULL );
 
 	    account = g_malloc0 ( sizeof ( struct exported_account ) );
 	    account -> account_nb = i;
+        account->extension = "";
 	    exported_accounts = g_slist_append ( exported_accounts, account );
-	    gsb_assistant_add_page ( assistant,
-				     create_export_account_resume_page ( account ),
-				     page, page - 1, page + 1, G_CALLBACK ( NULL ) );
-	    page ++;
 
+        if ( etat.export_files_traitement )
+        {
+            if ( index == 0 )
+            {
+                gsb_assistant_add_page ( assistant,
+                         create_export_account_resume_page ( account ),
+                         page, page - 1, page + 1, G_CALLBACK ( NULL ) );
+                page ++;
+            }
+        }
+        else
+        {
+            gsb_assistant_add_page ( assistant,
+                         create_export_account_resume_page ( account ),
+                         page, page - 1, page + 1, G_CALLBACK ( NULL ) );
+            page ++;
+        }
+
+        index++;
 	    list = list -> next;
 	}
 
@@ -339,7 +427,6 @@ gboolean export_enter_resume_page ( GtkWidget * assistant )
 }
 
 
-
 /**
  *
  *
@@ -381,7 +468,7 @@ GtkWidget * create_export_account_resume_page ( struct exported_account * accoun
     gtk_file_chooser_set_extra_widget ( GTK_FILE_CHOOSER(account -> chooser), hbox );
     gtk_box_pack_start ( GTK_BOX ( vbox ), account -> chooser, TRUE, TRUE, 0 );
 
-    gtk_combo_box_set_active ( GTK_COMBO_BOX(combo), 0 );
+    gtk_combo_box_set_active ( GTK_COMBO_BOX(combo), etat.export_file_format );
 
     return vbox;
 }
@@ -400,36 +487,38 @@ GtkWidget * create_export_account_resume_page ( struct exported_account * accoun
  *
  * \return FALSE
  */
-gboolean export_account_change_format ( GtkWidget * combo,
-					struct exported_account * account )
+gboolean export_account_change_format ( GtkWidget *combo,
+                        struct exported_account *account )
 {
-    gchar * extension = "", * title;
+    gchar *title;
 
-    switch ( gtk_combo_box_get_active ( GTK_COMBO_BOX(combo) ) )
+    switch ( gtk_combo_box_get_active ( GTK_COMBO_BOX ( combo ) ) )
     {
-	    case EXPORT_QIF:
-		extension = "qif";
-		account -> format = EXPORT_QIF;
-		break;
+        case EXPORT_QIF:
+        account->extension = "qif";
+        account->format = EXPORT_QIF;
+        break;
 
-	    case EXPORT_CSV:
-		extension = "csv";
-		account -> format = EXPORT_CSV;
-		break;
+        case EXPORT_CSV:
+        account->extension = "csv";
+        account -> format = EXPORT_CSV;
+        break;
     }
 
     if ( titre_fichier && strlen ( titre_fichier ) )
     {
-	title = titre_fichier;
+        title = titre_fichier;
     }
     else
     {
-	title = (gchar *) g_get_user_name ();
+        title = (gchar *) g_get_user_name ( );
     }
 
-    gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER(account -> chooser),
-		       g_strconcat ( title, "-", gsb_data_account_get_name ( account -> account_nb ), ".", extension, NULL ) );
-    gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER(account -> chooser), gsb_file_get_last_path () );
+    gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( account->chooser ),
+                        g_strconcat ( title, "-",
+                        gsb_data_account_get_name ( account->account_nb ), ".", account->extension,
+                        NULL ) );
+    gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( account->chooser ), gsb_file_get_last_path () );
 
     return FALSE;
 }
@@ -485,20 +574,108 @@ void export_account_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
  */
 void export_resume_maybe_sensitive_next ( GtkWidget * assistant )
 {
+    GtkWidget *button_select;
+
+    button_select = g_object_get_data ( G_OBJECT ( assistant ), "button_select" );
+    gtk_widget_show ( button_select );
+
     if ( selected_accounts && g_slist_length ( selected_accounts ) )
     {
-	gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ),
-				   TRUE );
+        gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ), TRUE );
     }
     else
     {
-	gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ),
-				   FALSE );
+        gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ), FALSE );
     }
 }
 
 
+void export_account_all_toggled ( GtkToggleButton *button,
+                        GtkTreeView *tree_view )
+{
+    GtkWidget *assistant;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    gint toggle_value;
 
+    model = gtk_tree_view_get_model ( tree_view );
+    assistant = g_object_get_data ( G_OBJECT ( model ), "assistant" );
+    toggle_value = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( button ) );
+    if ( toggle_value )
+    {
+      gtk_button_set_label ( GTK_BUTTON ( button ), _("Unselect all") );
+      gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ), TRUE );
+    }
+    else
+    {
+      gtk_button_set_label ( GTK_BUTTON ( button ), _("Select all") );
+      gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ), FALSE );
+    }
+
+    /* get first iter */
+    gtk_tree_model_get_iter_first ( GTK_TREE_MODEL ( model ), &iter );
+    do
+    {
+        gboolean toggle_item;
+        gint account_toggled;
+
+        gtk_tree_model_get (GTK_TREE_MODEL(model), &iter,
+                0, &toggle_item,
+                2, &account_toggled,
+                -1);
+
+        if ( toggle_value && !toggle_item )
+        {
+            selected_accounts = g_slist_append ( selected_accounts, GINT_TO_POINTER ( account_toggled ) );
+            gtk_list_store_set ( GTK_LIST_STORE(model), &iter, 0, !toggle_item, -1);
+        }
+        else if ( !toggle_value && toggle_item )
+        {
+            selected_accounts = g_slist_remove ( selected_accounts, GINT_TO_POINTER ( account_toggled ) );
+            gtk_list_store_set ( GTK_LIST_STORE(model), &iter, 0, !toggle_item, -1);
+        }
+    }
+    while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &iter ) );
+
+    /* clean up */
+    export_resume_maybe_sensitive_next ( assistant );
+}
+
+
+/**
+ * Set a boolean integer to the value of a checkbutton.  Normally called
+ * via a GTK "toggled" signal handler.
+ *
+ * \param checkbutton a pointer to a checkbutton widget.
+ * \param event
+ * \param pointeur vers la donnée à modifier
+ */
+gboolean export_account_radiobutton_format_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur )
+{
+    if ( pointeur )
+    {
+        gint value = 0;
+
+        value = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
+        *pointeur = value;
+
+        if ( etat.modification_fichier == 0 )
+            modification_fichier ( TRUE );
+    }
+
+    return FALSE;
+}
+
+
+void expert_account_free_account_structure ( struct exported_account *account )
+{
+    g_free ( account->extension );
+    g_free ( account->filename );
+
+    g_free ( account );
+}
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
