@@ -6,6 +6,7 @@ typedef enum GSB_GENERAL_NOTEBOOK_PAGES {
     GSB_ACCOUNT_PAGE,
     GSB_SCHEDULER_PAGE,
     GSB_PAYEES_PAGE,
+    GSB_SIMULATOR_PAGE, 
     GSB_CATEGORIES_PAGE,
     GSB_BUDGETARY_LINES_PAGE,
     GSB_REPORTS_PAGE,
@@ -13,6 +14,14 @@ typedef enum GSB_GENERAL_NOTEBOOK_PAGES {
     GSB_AQBANKING_PAGE,
 } GsbGeneralNotebookPages;
 
+typedef enum GSB_ACCOUNT_NOTEBOOK_PAGES {
+    GSB_TRANSACTIONS_PAGE,
+    GSB_ESTIMATE_PAGE,
+    GSB_HISTORICAL_PAGE,
+    GSB_FINANCE_PAGE,
+    GSB_PROPERTIES_PAGE,
+} GsbaccountNotebookPages;
+
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
@@ -22,7 +31,7 @@ GtkWidget * create_main_widget ( void );
 void gsb_gui_headings_update_suffix ( gchar * suffix );
 void gsb_gui_headings_update_title ( gchar * title );
 void gsb_gui_notebook_change_page ( GsbGeneralNotebookPages page );
-gint gsb_gui_on_account_get_property_page ( GtkNotebook *account_page );
+void gsb_gui_on_account_change_page ( GsbaccountNotebookPages page );
 gboolean gsb_gui_on_account_switch_page ( GtkNotebook *notebook,
                         GtkNotebookPage *page,
                         guint page_number,
