@@ -25,27 +25,30 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "file_obfuscate.h"
-#include "./dialog.h"
-#include "./gsb_assistant.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_bank.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_file_save.h"
-#include "./gsb_file_util.h"
-#include "./gsb_status.h"
-#include "./utils_files.h"
-#include "./utils.h"
-#include "./include.h"
+#include "dialog.h"
+#include "gsb_assistant.h"
+#include "gsb_data_account.h"
+#include "gsb_data_bank.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_report.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_file_save.h"
+#include "gsb_file_util.h"
+#include "gsb_status.h"
+#include "utils_files.h"
+#include "utils.h"
 /*END_INCLUDE*/
 
 
