@@ -20,37 +20,37 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_account.h"
-#include "./dialog.h"
-#include "./gsb_account_property.h"
-#include "./gsb_category.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_file.h"
-#include "./gsb_form_scheduler.h"
-#include "./navigation.h"
-#include "./menu.h"
-#include "./gsb_real.h"
-#include "./gsb_scheduler_list.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./tiers_onglet.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./transaction_list.h"
-#include "./gsb_transactions_list.h"
-#include "./fenetre_principale.h"
-#include "./gsb_form_scheduler.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./gsb_real.h"
-#include "./gsb_data_account.h"
+#include "dialog.h"
+#include "gsb_account_property.h"
+#include "gsb_category.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_file.h"
+#include "gsb_form_scheduler.h"
+#include "navigation.h"
+#include "fenetre_principale.h"
+#include "menu.h"
+#include "gsb_real.h"
+#include "gsb_scheduler_list.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "tiers_onglet.h"
+#include "categories_onglet.h"
+#include "imputation_budgetaire.h"
+#include "transaction_list.h"
+#include "gsb_transactions_list.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -117,7 +117,7 @@ gboolean gsb_account_new ( kind_account account_type,
     gsb_data_account_set_name (account_number, name);
 
     /* update the combofix for categ */ 
-    gsb_category_update_combofix ();
+    gsb_category_update_combofix ( FALSE );
 
     /* update the name of accounts in form */
     gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (SCHEDULED_FORM_ACCOUNT),
@@ -137,10 +137,8 @@ gboolean gsb_account_new ( kind_account account_type,
         gsb_gui_navigation_add_account ( account_number, TRUE );
 
         /* Go to accounts properties */
-        gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook_general ),
-                    GSB_ACCOUNT_PAGE );
-        gtk_notebook_set_current_page ( GTK_NOTEBOOK ( account_page ),
-                        gsb_gui_on_account_get_property_page ( GTK_NOTEBOOK ( account_page ) ) );
+        gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook_general ), GSB_ACCOUNT_PAGE );
+        gtk_notebook_set_current_page ( GTK_NOTEBOOK ( account_page ), GSB_PROPERTIES_PAGE );
 
         gsb_account_property_fill_page ();
     }
