@@ -29,46 +29,45 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 
 /*START_INCLUDE*/
 #include "gsb_account_property.h"
-#include "./dialog.h"
-#include "./gsb_account.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_bank.h"
-#include "./utils_buttons.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_bank.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_editables.h"
-#include "./gsb_file.h"
-#include "./gsb_form.h"
-#include "./gsb_form_scheduler.h"
-#include "./navigation.h"
-#include "./accueil.h"
-#include "./menu.h"
-#include "./gsb_scheduler_list.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./tiers_onglet.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./transaction_list.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./accueil.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form_scheduler.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./gtk_combofix.h"
+#include "dialog.h"
+#include "gsb_account.h"
+#include "gsb_autofunc.h"
+#include "gsb_bank.h"
+#include "utils_buttons.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_bank.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_transaction.h"
+#include "utils_editables.h"
+#include "gsb_file.h"
+#include "gsb_form.h"
+#include "gsb_form_scheduler.h"
+#include "navigation.h"
+#include "accueil.h"
+#include "menu.h"
+#include "gsb_scheduler_list.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "tiers_onglet.h"
+#include "categories_onglet.h"
+#include "imputation_budgetaire.h"
+#include "transaction_list.h"
+#include "structures.h"
+#include "gsb_transactions_list.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -180,7 +179,6 @@ extern gint mise_a_jour_liste_comptes_accueil;
 extern gint mise_a_jour_liste_echeances_manuelles_accueil;
 extern gint mise_a_jour_soldes_minimaux;
 extern gsb_real null_real;
-extern gchar *titre_fichier;
 /*END_EXTERN*/
 
 
@@ -235,7 +233,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Account name")) );
+    label = gtk_label_new ( _("Account name: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -256,7 +254,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Account type")) );
+    label = gtk_label_new ( _("Account type: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -274,7 +272,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Account currency")) );
+    label = gtk_label_new ( _("Account currency: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -300,7 +298,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_button_set_relief ( GTK_BUTTON ( bouton_icon ), GTK_RELIEF_NONE );
 
     g_signal_connect ( G_OBJECT( bouton_icon ),
-                        "pressed",
+                        "clicked",
                         G_CALLBACK(gsb_data_account_change_account_icon),
                         NULL );
 
@@ -309,7 +307,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Holder name")) );
+    label = gtk_label_new ( _("Holder name: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -341,7 +339,7 @@ GtkWidget *gsb_account_property_create_page ( void )
 
     /* now the checkbutton for different address */
     button_holder_address = gsb_autofunc_checkbutton_new (
-                        COLON(_("Holder's own address")), FALSE,
+                        _("Holder's own address: "), FALSE,
                         G_CALLBACK (gsb_editable_erase_text_view),
                         detail_adresse_titulaire,
                         NULL,
@@ -375,7 +373,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Financial institution")) );
+    label = gtk_label_new ( _("Financial institution: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -403,7 +401,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("BIC code")) );
+    label = gtk_label_new ( _("BIC code: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -417,7 +415,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("IBAN number")) );
+    label = gtk_label_new ( _("IBAN number: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -446,7 +444,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Bank sort code")) );
+    label = gtk_label_new ( _("Bank sort code: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -460,7 +458,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Bank branch code")) );
+    label = gtk_label_new ( _("Bank branch code: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -481,7 +479,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Account number / Key")) );
+    label = gtk_label_new ( _("Account number / Key: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -518,7 +516,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Initial balance")) );
+    label = gtk_label_new ( _("Initial balance: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
@@ -534,7 +532,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Minimum authorised balance")) );
+    label = gtk_label_new ( _("Minimum authorised balance: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
@@ -551,7 +549,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Minimum desired balance")) );
+    label = gtk_label_new ( _("Minimum desired balance: ") );
     gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
@@ -1444,7 +1442,7 @@ gint gsb_account_property_iban_control_iban ( gchar *iban )
     while ( gstring -> len > 0 )
     {
         substr = g_strndup ( gstring -> str, 9 );
-        lnum = ( gulong ) my_strtod ( substr, NULL );
+        lnum = ( gulong ) utils_str_safe_strtod ( substr, NULL );
         reste = lnum % 97;
 
         g_free ( substr );
@@ -1515,7 +1513,6 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
 {
     gint origin = GPOINTER_TO_INT (p_origin);
     gint account_number;
-    const gchar *tmpstr;
 
     account_number = gsb_gui_navigation_get_current_account ();
     if ( account_number == -1)
@@ -1541,10 +1538,7 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
         payee_fill_tree ();
         break;
     case PROPERTY_HOLDER_NAME:
-        tmpstr = gtk_entry_get_text ( GTK_ENTRY ( widget ) );
-        titre_fichier = my_strdup ( tmpstr );
-        gsb_main_page_update_homepage_title ( titre_fichier );
-        gsb_file_update_window_title ( );
+        gsb_main_set_grisbi_title ( account_number );
         break;
     }
 
