@@ -26,29 +26,31 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_archive_config.h"
-#include "./gsb_account_property.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_dates.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_transactions_list.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./dialog.h"
-#include "./transaction_list.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
+#include "gsb_account_property.h"
+#include "gsb_autofunc.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_transaction.h"
+#include "utils_dates.h"
+#include "navigation.h"
+#include "gsb_real.h"
+#include "gsb_transactions_list.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "dialog.h"
+#include "transaction_list.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /** Columns for payment methods tree */
@@ -67,14 +69,14 @@ static GtkWidget *archive_name_entry = NULL;
 
 
 /*START_STATIC*/
-static  gboolean gsb_archive_config_delete_archive ( GtkWidget *button,
+static gboolean gsb_archive_config_delete_archive ( GtkWidget *button,
                         GtkWidget *tree_view );
-static  gboolean gsb_archive_config_destroy_archive ( GtkWidget *button,
+static gboolean gsb_archive_config_destroy_archive ( GtkWidget *button,
                         GtkWidget *tree_view );
-static  void gsb_archive_config_fill_list ( GtkListStore *store );
-static  gboolean gsb_archive_config_name_changed ( GtkWidget *entry,
+static void gsb_archive_config_fill_list ( GtkListStore *store );
+static gboolean gsb_archive_config_name_changed ( GtkWidget *entry,
                         GtkWidget *tree_view );
-static  gboolean gsb_archive_config_select ( GtkTreeSelection *selection,
+static gboolean gsb_archive_config_select ( GtkTreeSelection *selection,
                         GtkWidget *paddingbox );
 /*END_STATIC*/
 
@@ -183,7 +185,7 @@ GtkWidget *gsb_archive_config_create ( void )
     gtk_box_pack_start ( GTK_BOX ( modification_paddingbox ), table,
 			 FALSE, FALSE, 6 );
 
-    label = gtk_label_new ( COLON(_("Name")) );
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_table_attach ( GTK_TABLE ( table ),
 		       label, 0, 1, 0, 1,
@@ -207,7 +209,7 @@ GtkWidget *gsb_archive_config_create ( void )
 		       "clicked",
 		       G_CALLBACK (gsb_archive_config_delete_archive),
 		       archive_treeview );
-    tmpstr = g_build_filename ( PIXMAPS_DIR, "import.png", NULL );
+    tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR, "import.png", NULL );
     gtk_button_set_image ( GTK_BUTTON(button), 
 			   gtk_image_new_from_file ( tmpstr ) );
     g_free ( tmpstr );
@@ -224,7 +226,7 @@ GtkWidget *gsb_archive_config_create ( void )
 		       "clicked",
 		       G_CALLBACK (gsb_archive_config_destroy_archive),
 		       archive_treeview );
-    tmpstr = g_build_filename ( PIXMAPS_DIR, "import.png", NULL );
+    tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR, "import.png", NULL );
     gtk_button_set_image ( GTK_BUTTON(button), 
 			   gtk_image_new_from_file ( tmpstr ) );
     g_free ( tmpstr );
