@@ -27,48 +27,51 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_assistant_archive.h"
-#include "./etats_support.h"
-#include "./gsb_assistant.h"
-#include "./gsb_calendar_entry.h"
-#include "./gsb_data_archive.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_dates.h"
-#include "./gsb_fyear.h"
-#include "./navigation.h"
-#include "./gsb_report.h"
-#include "./gsb_transactions_list.h"
-#include "./dialog.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./etats_calculs.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./include.h"
+#include "etats_support.h"
+#include "gsb_assistant.h"
+#include "gsb_calendar_entry.h"
+#include "gsb_data_archive.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_report.h"
+#include "gsb_data_transaction.h"
+#include "utils_dates.h"
+#include "gsb_fyear.h"
+#include "navigation.h"
+#include "gsb_report.h"
+#include "gsb_transactions_list.h"
+#include "dialog.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "etats_calculs.h"
+#include "utils.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  void gsb_assistant_archive_add_children_to_list ( gint transaction_number );
-static  void gsb_assistant_archive_add_contra_transaction_to_list ( gint transaction_number );
-static  void gsb_assistant_archive_add_transaction_to_list ( gpointer transaction_pointer );
-static  GtkWidget *gsb_assistant_archive_page_archive_name ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_archive_page_success ( void );
-static  gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assistant,
+static void gsb_assistant_archive_add_children_to_list ( gint transaction_number );
+static void gsb_assistant_archive_add_contra_transaction_to_list ( gint transaction_number );
+static void gsb_assistant_archive_add_transaction_to_list ( gpointer transaction_pointer );
+static GtkWidget *gsb_assistant_archive_page_archive_name ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_archive_page_success ( void );
+static gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assistant,
                         gint new_page );
-static  gboolean gsb_assistant_archive_switch_to_intro ( GtkWidget *assistant,
+static gboolean gsb_assistant_archive_switch_to_intro ( GtkWidget *assistant,
                         gint new_page );
-static  gboolean gsb_assistant_archive_switch_to_menu ( GtkWidget *assistant,
+static gboolean gsb_assistant_archive_switch_to_menu ( GtkWidget *assistant,
                         gint new_page );
-static  gboolean gsb_assistant_archive_switch_to_succes ( GtkWidget *assistant,
+static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
                         gint new_page );
-static  gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant );
+static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant );
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -167,7 +170,7 @@ GtkResponseType gsb_assistant_archive_run ( gboolean origin )
 			     ARCHIVE_ASSISTANT_SUCCESS,
 			     ARCHIVE_ASSISTANT_MENU,
 			     0,
-			     G_CALLBACK (gsb_assistant_archive_switch_to_succes));
+			     G_CALLBACK (gsb_assistant_archive_switch_to_success));
     return_value = gsb_assistant_run (assistant);
     gtk_widget_destroy (assistant);
 
@@ -227,7 +230,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
                         G_OBJECT (hbox));
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON ( _("Initial date" ) ) );
+    label = gtk_label_new ( _("Initial date: " ) );
     gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
@@ -239,7 +242,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
                         G_CONNECT_AFTER | G_CONNECT_SWAPPED);
     gtk_box_pack_start ( GTK_BOX (hbox), initial_date, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON ( _("Final date")) );
+    label = gtk_label_new ( _("Final date: ") );
     gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
@@ -275,7 +278,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
                         G_OBJECT (hbox));
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( _("Financial year :") );
+    label = gtk_label_new ( _("Financial year: ") );
     gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
@@ -311,7 +314,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
                         G_OBJECT (hbox));
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON ( _("Report") ) );
+    label = gtk_label_new ( _("Report: ") );
     gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
     report_button = gsb_report_make_combobox ();
@@ -358,7 +361,7 @@ static GtkWidget *gsb_assistant_archive_page_archive_name ( GtkWidget *assistant
 			 FALSE, FALSE, 0 );
 
     /* set up the menu */
-    label = gtk_label_new ( COLON(_("Please choose a name for archive") ) );
+    label = gtk_label_new ( _("Please choose a name for archive: ") );
     gtk_misc_set_alignment ( GTK_MISC (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox),
@@ -623,7 +626,7 @@ static gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assist
  *
  * \return FALSE
  * */
-static gboolean gsb_assistant_archive_switch_to_succes ( GtkWidget *assistant,
+static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
                         gint new_page )
 {
     /* if we come here, we are sure that :
@@ -708,11 +711,12 @@ static gboolean gsb_assistant_archive_switch_to_succes ( GtkWidget *assistant,
     gsb_transactions_list_fill_archive_store ( );
 
     /* set the message */
+    guint archived_transaction_count = g_slist_length (list_transaction_to_archive);
     string = g_strdup_printf ( _("Archive '%s' was successfully created and %d transactions "
                                  "out of %d were archived.\n\n"),
                         gsb_data_archive_get_name (archive_number),
-                        g_slist_length (list_transaction_to_archive),
-                        g_slist_length (list_transaction_to_archive) +
+                        archived_transaction_count,
+                        archived_transaction_count +
                         g_slist_length (gsb_data_transaction_get_transactions_list ()));
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (congratulations_view));
