@@ -26,40 +26,43 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_assistant_file.h"
-#include "./gsb_assistant.h"
-#include "./gsb_automem.h"
-#include "./gsb_bank.h"
-#include "./gsb_category.h"
-#include "./gsb_currency_config.h"
-#include "./gsb_currency.h"
-#include "./gsb_file.h"
-#include "./parametres.h"
-#include "./gsb_select_icon.h"
-#include "./import.h"
-#include "./traitement_variables.h"
-#include "./utils_files.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./affichage.h"
-#include "./structures.h"
-#include "./gsb_currency_config.h"
-#include "./include.h"
+#include "gsb_assistant.h"
+#include "gsb_automem.h"
+#include "gsb_bank.h"
+#include "gsb_category.h"
+#include "gsb_currency_config.h"
+#include "gsb_currency.h"
+#include "gsb_file.h"
+#include "parametres.h"
+#include "gsb_select_icon.h"
+#include "import.h"
+#include "traitement_variables.h"
+#include "utils_files.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "affichage.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
+static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
 						  GtkWidget *filename_entry );
-static  gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
+static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
 						     GtkWidget *entry );
-static  GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_file_page_3 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_file_page_4 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_file_page_5 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
+static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_file_page_3 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_file_page_4 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_file_page_5 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
 						   gboolean import );
 /*END_STATIC*/
 
@@ -280,7 +283,7 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 	gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 0);
 
 	/* label account name */
-	label = gtk_label_new (COLON(_("Accounts file title")));
+	label = gtk_label_new ( _("Accounts file title: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -302,7 +305,7 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
 
 	/* filename */
-	label = gtk_label_new (COLON(_("Filename")));
+	label = gtk_label_new ( _("Filename: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
@@ -325,9 +328,17 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
 			 FALSE, FALSE, 0 );
 
+    if ( etat.crypt_file )
+        run.new_crypted_file = TRUE;
+
+    /* date format */
+    paddingbox = gsb_config_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+
+    /* decimal and thousands separator */
+    paddingbox = gsb_config_number_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+
     /* Address */
-    paddingbox = new_paddingbox_with_title ( vbox, FALSE,
-					     _("Your address"));
+    paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Your address") );
 
     /* Common address */
     scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
