@@ -29,48 +29,51 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_bank.h"
-#include "./dialog.h"
-#include "./gsb_account_property.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_bank.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
+#include "dialog.h"
+#include "gsb_account_property.h"
+#include "gsb_autofunc.h"
+#include "gsb_data_account.h"
+#include "gsb_data_bank.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "structures.h"
+#include "gsb_transactions_list.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  gboolean gsb_bank_add ( GtkWidget *button,
+static gboolean gsb_bank_add ( GtkWidget *button,
                         gpointer null );
-static  void gsb_bank_bic_code_changed ( GtkEntry *entry, gpointer data );
-static  void gsb_bank_code_changed ( GtkEntry *entry, gpointer data );
-static  gboolean gsb_bank_combobox_changed ( GtkWidget *combobox,
+static void gsb_bank_bic_code_changed ( GtkEntry *entry, gpointer data );
+static void gsb_bank_code_changed ( GtkEntry *entry, gpointer data );
+static gboolean gsb_bank_combobox_changed ( GtkWidget *combobox,
 					    gboolean default_func (gint, gint));
-static  gboolean gsb_bank_create_combobox_model ( void );
-static  GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
+static gboolean gsb_bank_create_combobox_model ( void );
+static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         GtkWidget *combobox );
-static  gboolean gsb_bank_delete ( GtkWidget *button,
+static gboolean gsb_bank_delete ( GtkWidget *button,
                         gpointer null );
-static  gboolean gsb_bank_edit_bank ( gint bank_number,
+static gboolean gsb_bank_edit_bank ( gint bank_number,
                         GtkWidget *combobox );
-static  gboolean gsb_bank_list_change_selection ( GtkTreeSelection *selection,
+static gboolean gsb_bank_list_change_selection ( GtkTreeSelection *selection,
                         GtkWidget *container );
-static  gboolean gsb_bank_list_changed ( GtkWidget *combobox,
+static gboolean gsb_bank_list_changed ( GtkWidget *combobox,
                         gpointer null );
-static  gboolean gsb_bank_list_check_separator ( GtkTreeModel *model,
+static gboolean gsb_bank_list_check_separator ( GtkTreeModel *model,
                         GtkTreeIter *iter,
 						gpointer null );
-static  gboolean gsb_bank_update_form ( gint bank_number,
+static gboolean gsb_bank_update_form ( gint bank_number,
                         GtkWidget *frame );
-static  gboolean gsb_bank_update_selected_line ( GtkEntry *entry,
+static gboolean gsb_bank_update_selected_line ( GtkEntry *entry,
 						GtkWidget *combobox );
-static  gboolean gsb_bank_update_selected_line_model ( GtkWidget *combobox );
+static gboolean gsb_bank_update_selected_line_model ( GtkWidget *combobox );
 /*END_STATIC*/
 
 static GtkWidget *bank_list_tree_view;
@@ -729,7 +732,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
     size_group = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
 
     /* Bank name item */
-    label = gtk_label_new ( COLON(_("Name")) );
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -744,7 +747,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Bank Sort code item */
-    label = gtk_label_new ( COLON(_("Sort code")) );
+    label = gtk_label_new ( _("Sort code: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -759,7 +762,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Bank BIC code item */
-    label = gtk_label_new ( COLON(_("BIC code")) );
+    label = gtk_label_new ( _("BIC code: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -776,7 +779,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Bank address */
-    label = gtk_label_new ( COLON(_("Address")) );
+    label = gtk_label_new ( _("Address: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -799,7 +802,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Phone number */
-    label = gtk_label_new ( COLON(_("Phone")) );
+    label = gtk_label_new ( _("Phone: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -814,7 +817,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* E-mail */
-    label = gtk_label_new ( COLON(_("E-Mail")) );
+    label = gtk_label_new ( _("E-Mail: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -829,7 +832,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Website */
-    label = gtk_label_new ( COLON(_("Website")) );
+    label = gtk_label_new ( _("Website: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -852,7 +855,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 			 TRUE, TRUE, 5 );
 
     /* Name */
-    label = gtk_label_new ( COLON(_("Name")) );
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -867,7 +870,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Phone number */
-    label = gtk_label_new ( COLON(_("Phone")) );
+    label = gtk_label_new ( _("Phone: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -882,7 +885,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* Fax */
-    label = gtk_label_new ( COLON(_("Fax")) );
+    label = gtk_label_new ( _("Fax: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -897,7 +900,7 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
 		       0, 0 );
 
     /* E-Mail */
-    label = gtk_label_new ( COLON(_("E-Mail")) );
+    label = gtk_label_new ( _("E-Mail: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
