@@ -27,15 +27,19 @@
  *
  * */
 
-#include <ctype.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
+
+#include <ctype.h>
 #include <gdk/gdkkeysyms.h>
 
 /*START_INCLUDE*/
 #include "gsb_calendar_entry.h"
-#include "./utils_dates.h"
-#include "./gsb_form_widget.h"
-#include "./include.h"
+#include "utils_dates.h"
+#include "gsb_form_widget.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -608,7 +612,7 @@ gboolean gsb_calendar_entry_calendar_key_press ( GtkCalendar *pCalendar,
 	case GDK_KP_Enter :
 	    /* get the date an close the calendar */
 	    gtk_entry_set_text ( GTK_ENTRY ( entry ),
-				 gsb_format_date ( day, month + 1, year ));
+				 gsb_format_date ( day, month, year ));
 	    if ( GTK_WIDGET_TOPLEVEL ( pTopLevelWidget ) )
 		gtk_widget_destroy ( pTopLevelWidget );
 	    g_date_free (date);
@@ -675,9 +679,9 @@ gboolean gsb_calendar_entry_calendar_key_press ( GtkCalendar *pCalendar,
 	    return TRUE;
     }
 
-    day = g_date_day (date);
-    month = g_date_month (date);
-    year = g_date_year (date);
+    day = g_date_get_day (date);
+    month = g_date_get_month (date);
+    year = g_date_get_year (date);
     g_date_free (date);
 
     /* to avoid a warning */
