@@ -27,31 +27,35 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_currency.h"
-#include "./dialog.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_currency_link.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_real.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./utils_files.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
-#include "./gsb_currency_config.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
+#include "dialog.h"
+#include "gsb_autofunc.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_currency_link.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form_widget.h"
+#include "gsb_real.h"
+#include "utils.h"
+#include "structures.h"
+#include "utils_files.h"
+#include "gsb_data_form.h"
+#include "gsb_currency_config.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static struct cached_exchange_rate *gsb_currency_config_get_cached_exchange ( gint currency1_number,
                         gint currency2_number );
+static gboolean gsb_currency_checkbutton_link_changed ( GtkWidget *checkbutton,
+						  gboolean *value );
 static void gsb_currency_config_set_cached_exchange ( gint currency1_number,
                         gint currency2_number,
                         gsb_real change, gsb_real fees );
@@ -319,7 +323,7 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
         gint currency_number;
 
         currency_number = gsb_data_currency_get_no_currency (list_tmp -> data);
-        string = g_strconcat( PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
+        string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
                     "flags", C_DIRECTORY_SEPARATOR,
                     gsb_data_currency_get_code_iso4217 (currency_number),
                     ".png", NULL );
@@ -494,15 +498,16 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
                         gsb_real exchange_fees,
                         gboolean force )
 {
-    GtkWidget *dialog, *label, *entry, *hbox, *fees_entry, *paddingbox, *table;
-    GtkWidget *amount_entry, *amount_1_entry, *amount_2_entry, *widget;
-    struct cached_exchange_rate *cache;
-    gint result;
+    GtkWidget *dialog, *label, *hbox, *paddingbox, *table, *widget;
+    GtkWidget *entry, *amount_entry, *amount_1_entry, *amount_2_entry, *fees_entry;
     GtkWidget *combobox_1;
     GtkWidget *combobox_2;
+    struct cached_exchange_rate *cache;
     gchar* tmpstr;
     gint row = 0;
+    gint result;
     gint link_number;
+    gint change_link_currency = 1;
 
     if ( account_currency_number == 0 || transaction_currency_number == 0 )
         return;
@@ -562,7 +567,7 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     label = gtk_label_new ( _("Exchange rate") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.5, 0.0 );
     gtk_table_attach ( GTK_TABLE(table), label, 2, 3, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* echange line currency 2 */
     combobox_2 = gsb_currency_make_combobox_exchange_dialog (
@@ -570,7 +575,7 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
                         account_currency_number,
                         !link_currency );
     gtk_table_attach ( GTK_TABLE(table), combobox_2, 3, 4, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
     row++;
 
     link_number = gsb_data_currency_link_search ( account_currency_number,
@@ -582,27 +587,27 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     }
 
     /* amount line */
-    label = gtk_label_new ( COLON(_("Amounts")) );
+    label = gtk_label_new ( _("Amounts: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
     gtk_table_attach ( GTK_TABLE(table), label, 0, 1, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     amount_1_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( amount_1_entry ), TRUE );
     gtk_table_attach ( GTK_TABLE(table), amount_1_entry, 1, 2, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* echange line input field */
     entry = gtk_entry_new ();
     gtk_widget_set_size_request ( entry, 100, -1 );
     gtk_entry_set_activates_default ( GTK_ENTRY ( entry ), TRUE );
     gtk_table_attach ( GTK_TABLE(table), entry, 2, 3, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     amount_2_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( amount_2_entry ), TRUE );
     gtk_table_attach ( GTK_TABLE(table), amount_2_entry, 3, 4, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* if amount exist already, fill them here */
     if ( link_currency )
@@ -655,22 +660,40 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     row++;
 
     /* exchange fees line label */
-    label = gtk_label_new ( COLON(_("Exchange fees")) );
+    label = gtk_label_new ( _("Exchange fees: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
     gtk_table_attach ( GTK_TABLE(table), label, 0, 1, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* exchange fees line input field */
     fees_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( fees_entry ), TRUE );
     gtk_table_attach ( GTK_TABLE(table), fees_entry, 1, 2, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* exchange fees currency for fees */
     label = gtk_label_new (gsb_data_currency_get_name ( account_currency_number ) );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
     gtk_table_attach ( GTK_TABLE(table), label, 2, 3, row, row+1,
-               GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+
+    if ( link_number )
+    {
+        GtkWidget *checkbox;
+
+        change_link_currency = !gsb_data_currency_link_get_fixed_link ( link_number );
+        checkbox = gtk_check_button_new_with_label ( _("Change the link") );
+        if ( change_link_currency )
+            gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( checkbox ), TRUE );
+        gtk_widget_set_sensitive ( checkbox, TRUE );
+        g_signal_connect ( G_OBJECT ( checkbox ),
+                        "toggled",
+                        G_CALLBACK ( gsb_currency_checkbutton_link_changed ),
+                        &change_link_currency );
+
+        gtk_table_attach ( GTK_TABLE(table), checkbox, 3, 4, row, row+1,
+                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    }
 
     /* if the rate or fees exist already, fill them here */
     if ( exchange_rate.mantissa )
@@ -727,7 +750,9 @@ dialog_return:
 
         if ( link_number )
         {
-            if ( gsb_real_cmp ( current_exchange,
+            if ( change_link_currency
+             &&
+             gsb_real_cmp ( current_exchange,
              gsb_data_currency_link_get_change_rate ( link_number ) ) != 0 )
                 gsb_data_currency_link_set_change_rate ( link_number,
                         current_exchange );
@@ -1000,8 +1025,8 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
 		else
         {
             gtk_widget_set_sensitive ( GTK_WIDGET ( entry ), FALSE );
-            amount_1 = gsb_str_to_real ( gtk_entry_get_text ( GTK_ENTRY ( entry_1 ) ) );
-            amount_2 = gsb_str_to_real ( gtk_entry_get_text ( GTK_ENTRY ( entry_2 ) ) );
+            amount_1 = gsb_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_1 ) ) );
+            amount_2 = gsb_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_2 ) ) );
             taux = gsb_real_div ( amount_2, amount_1 );
             gtk_entry_set_text ( GTK_ENTRY ( entry ), gsb_real_get_string ( taux ) );
         }
@@ -1028,7 +1053,7 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
     combobox_store = gtk_list_store_new ( 3, G_TYPE_INT, GDK_TYPE_PIXBUF,
 						G_TYPE_STRING);
 
-    string = g_strconcat( PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
                         "flags", C_DIRECTORY_SEPARATOR,
                         gsb_data_currency_get_code_iso4217 (
                         transaction_currency_number ),
@@ -1043,7 +1068,7 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
                     2, gsb_data_currency_get_name ( transaction_currency_number ),
                     -1 );
 
-    string = g_strconcat( PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
                         "flags", C_DIRECTORY_SEPARATOR,
                         gsb_data_currency_get_code_iso4217 (
                         account_currency_number ),
@@ -1081,17 +1106,66 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
 }
 
 
+/**
+ *
+ *
+**/
 gsb_real gsb_currency_get_current_exchange ( void )
 {
     return current_exchange;
 }
 
 
+/**
+ *
+ *
+**/
+gboolean gsb_currency_set_current_exchange ( gsb_real exchange )
+{
+    current_exchange.mantissa = exchange.mantissa;
+    current_exchange.exponent = exchange.exponent;
+
+    return FALSE;
+}
+
+
+/**
+ *
+ *
+**/
 gsb_real gsb_currency_get_current_exchange_fees ( void )
 {
     return current_exchange_fees;
 }
 
+
+/**
+ *
+ *
+**/
+gboolean gsb_currency_set_current_exchange_fees ( gsb_real fees )
+{
+    current_exchange_fees.mantissa = fees.mantissa;
+    current_exchange_fees.exponent = fees.exponent;
+
+    return FALSE;
+}
+
+
+/**
+ * met à jour value à chaque changement du check_button
+ *
+**/
+static gboolean gsb_currency_checkbutton_link_changed ( GtkWidget *checkbutton,
+						  gboolean *value )
+{
+    if ( value )
+        *value = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( checkbutton ) );
+
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
