@@ -27,28 +27,29 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_account.h"
-#include "./dialog.h"
-#include "./utils_dates.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_form.h"
-#include "./gsb_data_transaction.h"
-#include "./fenetre_principale.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_select_icon.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./custom_list.h"
-#include "./gsb_transactions_list.h"
-#include "./gsb_data_transaction.h"
-#include "./structures.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
+#include "custom_list.h"
+#include "dialog.h"
+#include "fenetre_principale.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_form.h"
+#include "gsb_data_transaction.h"
+#include "gsb_select_icon.h"
+#include "gsb_transactions_list.h"
+#include "navigation.h"
+#include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -62,19 +63,22 @@ typedef struct
     kind_account account_kind;
     gchar 	*account_name;
     gint 	currency;
-    gchar   *name_icon;                         /* path for not standard icon ajout pbiava 31/12/2008 */
     gint 	closed_account;                     /**< if 1 => closed */
     gchar 	*comment;
     gchar 	*holder_name;
     gchar 	*holder_address;
 
+    /** @name account_icon */
+    gchar   *name_icon;                 /* path for not standard icon */
+    GdkPixbuf *pixbuf;                  /* pixbuf for the account */
+
     /** @name method of payment */
     gint 	default_debit;
     gint 	default_credit;
 
     /** @name showed list stuff */
-    gint 	show_r;                      /**< 1 : reconciled transactions are showed */
-    gint 	nb_rows_by_transaction;      /**< 1, 2, 3, 4  */
+    gint 	show_r;                     /**< 1 : reconciled transactions are showed */
+    gint 	nb_rows_by_transaction;     /**< 1, 2, 3, 4  */
     gint    show_l;                     /** 1 archived lines are showed */
 
     /** @name remaining of the balances */
@@ -117,21 +121,28 @@ typedef struct
     gpointer 	form_organization;
 
     /** @name bet data */
+    gint bet_use_budget;                /* 1 = use the budget module */
     GDate *bet_start_date;              /* date de début */
-    gint bet_spin_range;                /* echelle de la période 0 = mois 1 = années */
     gint bet_months;                    /* nombre de mois ou d'années */
+    gint bet_spin_range;                /* echelle de la période 0 = mois 1 = années */
     gint bet_auto_inc_month;            /* incrémente automatiquement le mois */
     gint bet_select_transaction_label;  /* fixe le label pour les opérations */
     gint bet_select_scheduled_label;    /* fixe le label pour les opérations planifiées */
     gint bet_select_futur_label;        /* fixe le label pour les données futures */
     gint bet_hist_data;                 /* origine des données 0 = catégories 1 = IB */
     gint bet_hist_fyear;                /* numéro d'exercice */
+    gint bet_maj;                       /* MAJ du module estiamte balance */
+    gdouble bet_capital;                /* capital emprunté */
+    gdouble bet_taux_annuel;            /* taux d'interet annuel */
+    gdouble bet_frais;                  /* frais par echeance */
+    gint bet_type_taux;                 /* type de taux : actuariel ou proportionnel */
 } struct_account;
 
 
 /*START_STATIC*/
-static  void _gsb_data_account_free ( struct_account* account );
+static void _gsb_data_account_free ( struct_account* account );
 static void gsb_data_account_delete_all_accounts (void);
+static gchar *gsb_data_account_get_account_standard_pixbuf_filename ( kind_account account_kind );
 static struct_account *gsb_data_account_get_structure ( gint no );
 static gint gsb_data_account_max_number ( void );
 static gboolean gsb_data_account_set_default_sort_values ( gint account_number );
@@ -140,7 +151,6 @@ static gboolean gsb_data_form_dup_sort_values ( gint origin_account,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gboolean balances_with_scheduled;
 extern gsb_real error_real;
 extern gsb_real null_real;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
@@ -184,7 +194,9 @@ void gsb_data_account_delete_all_accounts (void)
  * */
 gboolean gsb_data_account_init_variables ( void )
 {
-    gsb_data_account_delete_all_accounts();
+    gsb_data_account_delete_all_accounts ();
+    gsb_select_icon_init_account_variables ();
+
     return FALSE;
 }
 
@@ -225,8 +237,7 @@ gint gsb_data_account_new ( kind_account account_kind )
     last_number = gsb_data_account_max_number ();
     /* we have to append the account first because some functions later will
      * look for that account */
-    list_accounts = g_slist_append ( list_accounts,
-				     account );
+    list_accounts = g_slist_append ( list_accounts, account );
 
     /* set the base */
     account -> account_number = last_number + 1;
@@ -285,31 +296,37 @@ static void _gsb_data_account_free ( struct_account* account )
 {
     if ( ! account )
         return;
-    if ( account -> account_id );
-	g_free ( account -> account_id );
-    if ( account -> account_name );
-	g_free ( account -> account_name );
-    if ( account -> name_icon );
-	g_free ( account -> name_icon );
-    if ( account -> comment );
-	g_free ( account -> comment );
-    if ( account -> holder_name );
-	g_free ( account -> holder_name );
-    if ( account -> holder_address );
-	g_free ( account -> holder_address );
-    if ( account -> bank_branch_code );
-	g_free ( account -> bank_branch_code );
-    if ( account -> bank_account_number );
-	g_free ( account -> bank_account_number );
-    if ( account -> bank_account_key );
-	g_free ( account -> bank_account_key );
-    if ( account -> bank_account_iban );
-	g_free ( account -> bank_account_iban );
-    /* TODO dOm : free row_align */
-    /* TODO dOm : free sort_list */
+    if ( account -> account_id )
+	    g_free ( account -> account_id );
+    if ( account -> account_name )
+	    g_free ( account -> account_name );
+    if ( account -> name_icon )
+	    g_free ( account -> name_icon );
+    if ( account -> comment )
+	    g_free ( account -> comment );
+    if ( account -> holder_name )
+	    g_free ( account -> holder_name );
+    if ( account -> holder_address )
+	    g_free ( account -> holder_address );
+    if ( account -> bank_branch_code )
+	    g_free ( account -> bank_branch_code );
+    if ( account -> bank_account_number )
+	    g_free ( account -> bank_account_number );
+    if ( account -> bank_account_key )
+	    g_free ( account -> bank_account_key );
+    if ( account -> bank_account_iban )
+	    g_free ( account -> bank_account_iban );
+    if ( account -> sort_list )
+        g_slist_free( account -> sort_list ) ;
+    if ( account -> form_organization )
+        g_free ( account -> form_organization );
+    if ( account -> bet_start_date )
+        g_date_free ( account -> bet_start_date );
+    if ( account -> pixbuf )
+        g_object_unref ( account -> pixbuf );
     g_free ( account );
     if ( account_buffer == account )
-	account_buffer = NULL;
+        account_buffer = NULL;
 }
 
 
@@ -329,11 +346,10 @@ gboolean gsb_data_account_delete ( gint account_number )
     if (!account )
 	return FALSE;
 
-    g_slist_free ( account -> sort_list );
-    list_accounts = g_slist_remove ( list_accounts,
-				     account );
+    list_accounts = g_slist_remove ( list_accounts, account );
 
     _gsb_data_account_free ( account );
+
     return TRUE;
 }
 
@@ -447,7 +463,7 @@ gint gsb_data_account_get_no_account ( gpointer account_ptr )
  * \return the new number, or -1 if failed
  * */
 gint gsb_data_account_set_account_number ( gint account_number,
-					   gint new_no )
+                        gint new_no )
 {
     struct_account *account;
 
@@ -876,7 +892,7 @@ gsb_real gsb_data_account_get_init_balance ( gint account_number,
  * \return TRUE, ok ; FALSE, problem
  * */
 gboolean gsb_data_account_set_init_balance ( gint account_number,
-					     gsb_real balance )
+                        gsb_real balance )
 {
     struct_account *account;
 
@@ -1017,7 +1033,7 @@ gboolean gsb_data_account_set_balances_are_dirty ( gint account_number )
 gsb_real gsb_data_account_calculate_current_and_marked_balances ( gint account_number )
 {
     struct_account *account;
-    GDate *date_jour = g_date_new ( );
+    GDate *date_jour;
     GSList *tmp_list;
     gsb_real current_balance;
 	gsb_real current_balance_later = null_real;
@@ -1025,7 +1041,7 @@ gsb_real gsb_data_account_calculate_current_and_marked_balances ( gint account_n
 	gsb_real marked_balance_later = null_real;
     gint floating_point;
 
-    //~ devel_debug_int ( account_number );
+    /* devel_debug_int ( account_number ); */
     account = gsb_data_account_get_structure ( account_number );
 
     if ( !account )
@@ -1038,7 +1054,7 @@ gsb_real gsb_data_account_calculate_current_and_marked_balances ( gint account_n
     marked_balance = gsb_real_adjust_exponent ( account -> init_balance,
 						floating_point );
 
-    g_date_set_time_t (date_jour, time (NULL));
+    date_jour = gdate_today ( );
 
     tmp_list = gsb_data_transaction_get_complete_transactions_list ();
 
@@ -1049,11 +1065,16 @@ gsb_real gsb_data_account_calculate_current_and_marked_balances ( gint account_n
 
 	transaction_number = gsb_data_transaction_get_transaction_number (tmp_list->data);
     /* on regarde si on tient compte ou pas des échéances pour les soldes */
-    if ( balances_with_scheduled )
+    if ( conf.balances_with_scheduled )
         res = 0;
     else
-        res = g_date_compare ( date_jour,
-                        gsb_data_transaction_get_date ( transaction_number ) );
+    {
+        const GDate *date;
+
+        date = gsb_data_transaction_get_value_date_or_date ( transaction_number );
+        res = g_date_compare ( date_jour, date );
+    }
+
 	if ( gsb_data_transaction_get_account_number (transaction_number) == account_number
 	     &&
 	     !gsb_data_transaction_get_mother_transaction_number (transaction_number)
@@ -1200,12 +1221,17 @@ gint gsb_data_account_get_element_sort ( gint account_number,
 	 ||
 	 no_column > CUSTOM_MODEL_VISIBLE_COLUMNS )
     {
-    	/* TODO dOm : the return value of g_strdup_printf was not used ! I add the devel_debug to print it. Is it OK to do that ?*/
-	gchar* tmpstr = g_strdup_printf ( _("Bad no column to gsb_data_account_get_element_sort () in data_account.c\nno_column = %d\n" ),
-			  no_column );
-	devel_debug (tmpstr);
-	g_free(tmpstr);
-	return FALSE;
+        gchar* tmpstr;
+
+    	/* TODO dOm : the return value of g_strdup_printf was not used ! 
+         I add the devel_debug to print it. Is it OK to do that ? */
+        tmpstr = g_strdup_printf ( _("Bad no column to gsb_data_account_get_element_sort () "
+                                   "in data_account.c\nno_column = %d\n" ),
+                                   no_column );
+        devel_debug (tmpstr);
+        g_free(tmpstr);
+
+        return FALSE;
     }
 
     account = gsb_data_account_get_structure ( account_number );
@@ -1238,10 +1264,16 @@ gboolean gsb_data_account_set_element_sort ( gint account_number,
 	 ||
 	 no_column > CUSTOM_MODEL_VISIBLE_COLUMNS )
     {
-        /* TODO dOm : the value of g_strdup_printf was not used. I add the devel_debug function to print it. Is it OK ? */
-	gchar* tmpstr = g_strdup_printf ( _("Bad no column to gsb_data_account_set_element_sort () in data_account.c\nno_column = %d\n" ), no_column );
+        gchar* tmpstr;
+
+        /* TODO dOm : the value of g_strdup_printf was not used.
+         I add the devel_debug function to print it. Is it OK ? */
+        tmpstr = g_strdup_printf ( _("Bad no column to gsb_data_account_set_element_sort () "
+                                  "in data_account.c\nno_column = %d\n" ),
+                                  no_column );
 	devel_debug ( tmpstr );
 	g_free (tmpstr);
+
 	return FALSE;
     }
 
@@ -1287,7 +1319,7 @@ gint gsb_data_account_get_current_transaction_number ( gint account_number )
  * \return TRUE, ok ; FALSE, problem
  * */
 gboolean gsb_data_account_set_current_transaction_number ( gint account_number,
-							   gint transaction_number )
+                        gint transaction_number )
 {
     struct_account *account;
 
@@ -1393,7 +1425,7 @@ gboolean gsb_data_account_set_mini_balance_authorized_message ( gint account_num
  * 
  * \param account_number no of the account
  * 
- * \return last number of reconcile or 0 if the account doesn't exist
+ * \return currency or 0 if the account doesn't exist
  * */
 gint gsb_data_account_get_currency ( gint account_number )
 {
@@ -2494,8 +2526,8 @@ gchar *gsb_data_account_get_name_icon (gint account_number)
 
     account = gsb_data_account_get_structure ( account_number );
 
-    if (!account )
-	return NULL;
+    if ( !account )
+        return NULL;
 
     return account -> name_icon;
 }
@@ -2517,20 +2549,26 @@ gboolean gsb_data_account_set_name_icon ( gint account_number,
 
     account = gsb_data_account_get_structure ( account_number );
 
-    if (!account )
-    return FALSE;
+    if ( !account )
+        return FALSE;
 
     if ( account -> name_icon )
         g_free ( account -> name_icon );
 
-    if (!filename || !strlen (filename))
-    account -> name_icon = NULL;
+    if ( !filename || !strlen ( filename ) )
+        account -> name_icon = NULL;
     else
-    account -> name_icon = my_strdup (filename);
+    {
+        if ( !g_file_test ( filename, G_FILE_TEST_EXISTS ) )
+            account -> name_icon = NULL;
+        else
+            account -> name_icon = my_strdup ( filename );
+    }
 
     return TRUE;
 }
 
+
 /**
  * get the image icon of the account
  * 
@@ -2558,33 +2596,45 @@ GtkWidget *gsb_data_account_get_account_icon_image ( gint account_number )
  * */
 GdkPixbuf *gsb_data_account_get_account_icon_pixbuf ( gint account_number )
 {
-    GdkPixbuf * pixbuf = NULL;
-    gchar * account_icon;
-    GError *error = NULL;
+    struct_account *account;
 
-    account_icon = gsb_data_account_get_name_icon ( account_number );
-    if ( account_icon && strlen ( account_icon ) > 0 )
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return NULL;
+
+    if ( account -> pixbuf )
+        return account -> pixbuf;
+    else
     {
-        pixbuf = gdk_pixbuf_new_from_file_at_size ( account_icon , 32, 32, &error );
-        g_object_set_data ( G_OBJECT ( pixbuf ), "name_icon", account_icon );
-    }
+        GdkPixbuf *pixbuf = NULL;
 
-    if ( ! pixbuf )
-    {
-        if ( account_icon && strlen ( account_icon ) > 0 )
-        {
-            gchar* tmpstr = g_strconcat( "Erreur de pixbuf : " , 
-                 error -> message, " image ",
-                 account_icon, NULL );
-            devel_debug (tmpstr);
-            dialogue_error ( tmpstr );
-            g_free ( tmpstr );
-        }        
-        pixbuf = gsb_data_account_get_account_standard_pixbuf ( 
-                    gsb_data_account_get_kind ( account_number ) );
-    }
+        pixbuf = gsb_data_account_get_account_standard_pixbuf ( account -> account_kind );
 
-    return pixbuf;
+        return pixbuf;
+    }
+}
+
+
+gboolean gsb_data_account_set_account_icon_pixbuf ( gint account_number,
+                        GdkPixbuf *pixbuf )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return FALSE;
+
+    if ( account -> pixbuf )
+        g_object_unref ( account -> pixbuf );
+
+    if ( pixbuf )
+        account -> pixbuf = g_object_ref ( pixbuf );
+    else
+        account -> pixbuf = NULL;
+
+    return TRUE;
 }
 
 
@@ -2599,9 +2649,37 @@ GdkPixbuf *gsb_data_account_get_account_icon_pixbuf ( gint account_number )
 GdkPixbuf *gsb_data_account_get_account_standard_pixbuf ( kind_account account_kind )
 {
     GdkPixbuf * pixbuf = NULL;
-    gchar * account_icon;
+    gchar *filename;
     GError *error = NULL;
 
+    filename = gsb_data_account_get_account_standard_pixbuf_filename ( account_kind );
+
+    pixbuf = gdk_pixbuf_new_from_file ( filename, &error );
+    if ( pixbuf )
+        g_object_set_data ( G_OBJECT ( pixbuf ), "name_icon", filename );
+    else
+        devel_debug ( error -> message );
+
+    if ( filename )
+        g_free ( filename );
+
+    return pixbuf;
+}
+
+
+/**
+ * get the filename of the default pixbuf icon for the kind_account
+ * 
+ * \param kind_account
+ * 
+ * \return filename 
+ * */
+
+gchar *gsb_data_account_get_account_standard_pixbuf_filename ( kind_account account_kind )
+{
+    gchar *account_icon;
+    gchar *filename;
+
     switch ( account_kind )
     {
     case GSB_TYPE_BANK:
@@ -2620,16 +2698,10 @@ GdkPixbuf *gsb_data_account_get_account_standard_pixbuf ( kind_account account_k
         account_icon = "ac_bank.png";
         break;
     }
-    pixbuf = gdk_pixbuf_new_from_file ( g_build_filename (PIXMAPS_DIR,
-                           account_icon, NULL), &error );
-    if ( pixbuf )
-        g_object_set_data ( G_OBJECT ( pixbuf ), "name_icon",  
-                               g_build_filename (PIXMAPS_DIR,
-                               account_icon, NULL) );
-    else
-        devel_debug ( error -> message );
 
-    return pixbuf;
+    filename = g_build_filename ( GRISBI_PIXMAPS_DIR, account_icon, NULL );
+
+    return filename;
 }
 
 
@@ -2641,29 +2713,46 @@ GdkPixbuf *gsb_data_account_get_account_standard_pixbuf ( kind_account account_k
  * */
 void gsb_data_account_change_account_icon ( GtkWidget *button, gpointer data )
 {
-    GdkPixbuf * pixbuf;
+    GdkPixbuf *pixbuf;
     GtkWidget *image;
-    gchar * name_icon;
-    gchar * new_icon;
+    gchar *name_icon;
+    gchar *new_icon;
     gint current_account;
 
     devel_debug ( NULL );
 
-    image = gtk_button_get_image ( GTK_BUTTON ( button ) );
-    pixbuf = gtk_image_get_pixbuf ( GTK_IMAGE ( image ) );
-    if ( pixbuf )
-        name_icon = g_object_get_data ( G_OBJECT ( pixbuf ), "name_icon" );
-    else
-        name_icon = g_build_filename (PIXMAPS_DIR, "ac_bank.png", NULL);
+    current_account = gsb_gui_navigation_get_current_account ();
+
+    name_icon = gsb_data_account_get_name_icon ( current_account );
+    if ( name_icon == NULL || g_file_test ( name_icon, G_FILE_TEST_EXISTS ) == FALSE )
+        name_icon = gsb_data_account_get_account_standard_pixbuf_filename (
+                        gsb_data_account_get_kind ( current_account ) );
 
     new_icon = gsb_select_icon_create_window ( name_icon );
     if ( new_icon )
     {
-        current_account = gsb_gui_navigation_get_current_account ();
-        gsb_data_account_set_name_icon ( current_account, new_icon );
+        if ( strcmp ( new_icon, name_icon ) == 0 )
+            return;
+        else if ( strcmp ( new_icon, gsb_data_account_get_account_standard_pixbuf_filename (
+         gsb_data_account_get_kind ( current_account ) ) ) == 0 )
+        {
+            gsb_data_account_set_name_icon ( current_account, NULL );
+            gsb_data_account_set_account_icon_pixbuf ( current_account, NULL );
+            gsb_select_icon_remove_account_pixbuf ( current_account );
+        }
+        else
+        {
+            gsb_data_account_set_name_icon ( current_account, new_icon );
+            pixbuf = gsb_select_icon_change_account_pixbuf ( current_account, new_icon );
+            gsb_data_account_set_account_icon_pixbuf ( current_account, pixbuf );
+        }
+
         image = gsb_data_account_get_account_icon_image ( current_account );
         gtk_button_set_image ( GTK_BUTTON ( button ), image );
         gsb_gui_navigation_update_account ( current_account );
+
+        if ( etat.modification_fichier == 0 )
+            modification_fichier ( TRUE );
     }
 }
 
@@ -2751,7 +2840,7 @@ gsb_real gsb_data_account_calculate_current_day_balance ( gint account_number,
                         GDate *day )
 {
     struct_account *account;
-    GDate *date_jour = g_date_new ( );
+    GDate *date_jour;
     GSList *tmp_list;
     gsb_real current_balance;
 	gsb_real current_balance_later = null_real;
@@ -2823,7 +2912,7 @@ GDate *gsb_data_account_get_bet_start_date ( gint account_number )
     account = gsb_data_account_get_structure ( account_number );
 
     if (!account )
-	    return 0;
+        return 0;
 
     date = account -> bet_start_date;
 
@@ -2922,7 +3011,7 @@ gint gsb_data_account_get_bet_months ( gint account_number )
     account = gsb_data_account_get_structure ( account_number );
 
     if (!account )
-	    return 0;
+        return 0;
 
     if ( account -> bet_months == 0 )
         return 1;
@@ -2943,7 +3032,7 @@ gboolean gsb_data_account_set_bet_months ( gint account_number, gint months )
     account = gsb_data_account_get_structure ( account_number );
 
     if (!account )
-	    return FALSE;
+        return FALSE;
 
     account -> bet_months = months;
 
@@ -3057,7 +3146,7 @@ gboolean gsb_data_account_set_bet_auto_inc_month ( gint account_number,
 
     account = gsb_data_account_get_structure ( account_number );
 
-    if (!account )
+    if ( !account )
 	    return FALSE;
 
     account -> bet_auto_inc_month = auto_inc_month;
@@ -3130,6 +3219,11 @@ gboolean gsb_data_account_set_bet_select_label ( gint account_number,
 }
 
 
+/**
+ * 
+ *
+ *
+ * */
 gboolean gsb_data_account_bet_update_initial_date_if_necessary ( gint account_number )
 {
     GDate *date_jour;
@@ -3140,12 +3234,306 @@ gboolean gsb_data_account_bet_update_initial_date_if_necessary ( gint account_nu
     g_date_add_months ( tmp_date, 1 );
 
     if ( g_date_compare ( date_jour, tmp_date ) >= 0 )
-        gsb_data_account_set_bet_start_date ( account_number, tmp_date );
+    {
+        if ( g_date_get_month ( date_jour ) == g_date_get_month ( tmp_date ) )
+            gsb_data_account_set_bet_start_date ( account_number, tmp_date );
+        else
+        {
+            g_date_set_day ( date_jour, g_date_get_day ( tmp_date ) );
+            gsb_data_account_set_bet_start_date ( account_number, date_jour );
+        }
+    }
 
     g_date_free ( tmp_date );
+    g_date_free ( date_jour );
 
     return FALSE;
 }
+
+
+/**
+ * retourne le bit utilisation du module budget. 
+ *
+ *  -1 pas de module possible 0 non utilisé 1 utilisé
+ * */
+gint gsb_data_account_get_bet_use_budget ( gint account_number )
+{
+    struct_account *account;
+    kind_account kind;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    kind = account -> account_kind;
+
+    switch ( kind )
+    {
+        case GSB_TYPE_BANK:
+        case GSB_TYPE_CASH:
+        case GSB_TYPE_LIABILITIES:
+            return account -> bet_use_budget;
+            break;
+        case GSB_TYPE_ASSET:
+            return -1;
+            break;
+        default:
+            return -1;
+            break;
+    }
+
+    return -1;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_use_budget ( gint account_number, gint value )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+	    return FALSE;
+
+    account -> bet_use_budget = value;
+
+    return TRUE;
+}
+/**
+ *
+ *
+ *
+ *
+ * */
+gint gsb_data_account_get_bet_maj ( gint account_number )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    return account -> bet_maj;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_maj ( gint account_number, gint type_maj )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return FALSE;
+
+    account -> bet_maj = type_maj;
+
+    return TRUE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gdouble gsb_data_account_get_bet_finance_capital ( gint account_number )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    return account -> bet_capital;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_finance_capital ( gint account_number, gdouble capital )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return FALSE;
+
+    account -> bet_capital = capital;
+
+    return TRUE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gdouble gsb_data_account_get_bet_finance_taux_annuel ( gint account_number )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    return account -> bet_taux_annuel;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_finance_taux_annuel ( gint account_number, gdouble taux_annuel )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return FALSE;
+
+    account -> bet_taux_annuel = taux_annuel;
+
+    return TRUE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gdouble gsb_data_account_get_bet_finance_frais ( gint account_number )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    return account -> bet_frais;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_finance_frais ( gint account_number, gdouble frais )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if ( !account )
+        return FALSE;
+
+    account -> bet_frais = frais;
+
+    return TRUE;
+}
+
+
+/**
+ * 
+ *
+ *
+ * */
+gint gsb_data_account_get_bet_finance_type_taux ( gint account_number )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+
+    return account -> bet_type_taux;
+}
+
+
+/**
+ * 
+ *
+ *
+ * */
+gboolean gsb_data_account_set_bet_finance_type_taux ( gint account_number, gint type_taux )
+{
+    struct_account *account;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return FALSE;
+
+    account -> bet_type_taux = type_taux;
+
+    return TRUE;
+}
+
+
+/**
+ * get floating_point of the currency on the account given
+ * 
+ * \param account_number no of the account
+ * 
+ * \return floating_point or 0 if the account or the currency doesn't exist
+ * */
+gint gsb_data_account_get_currency_floating_point ( gint account_number )
+{
+    struct_account *account;
+    gint floating_point;
+
+    account = gsb_data_account_get_structure ( account_number );
+
+    if (!account )
+        return 0;
+    else
+    {
+        floating_point = gsb_data_currency_get_floating_point ( account -> currency );
+        return floating_point;
+    }
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
