@@ -3,7 +3,7 @@
 
 
 /* START_INCLUDE_H */
-#include "././gsb_real.h"
+#include "gsb_real.h"
 /* END_INCLUDE_H */
 
 /* START_DECLARATION */
