@@ -26,12 +26,16 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_bank.h"
-#include "./gsb_data_account.h"
-#include "./utils_str.h"
+#include "gsb_data_account.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 
@@ -61,7 +65,7 @@ typedef struct
 } struct_bank;
 
 /*START_STATIC*/
-static  void _gsb_data_bank_free ( struct_bank* bank);
+static void _gsb_data_bank_free ( struct_bank* bank);
 static gpointer gsb_data_bank_get_structure ( gint bank_number );
 /*END_STATIC*/
 
