@@ -26,15 +26,18 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_fyear.h"
-#include "./utils_dates.h"
-#include "./gsb_fyear.h"
-#include "./dialog.h"
-#include "./utils_str.h"
-#include "./include.h"
+#include "utils_dates.h"
+#include "gsb_fyear.h"
+#include "dialog.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 
@@ -48,7 +51,7 @@ enum fyear_invalid {
 };
 
 /*START_STATIC*/
-static  void _gsb_data_fyear_free ( struct_fyear *fyear );
+static void _gsb_data_fyear_free ( struct_fyear *fyear );
 static gpointer gsb_data_fyear_get_structure ( gint fyear_number );
 static gint gsb_data_fyear_max_number ( void );
 /*END_STATIC*/
