@@ -25,25 +25,26 @@
  * \file data_partial_balance.c
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_partial_balance.h"
-#include "./dialog.h"
-#include "./gsb_currency_config.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_currency_link.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./gsb_data_account.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
+#include "dialog.h"
+#include "gsb_currency_config.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_currency_link.h"
+#include "navigation.h"
+#include "gsb_real.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -61,7 +62,7 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_partial_balance_free ( struct_partial_balance *partial_balance);
+static void _gsb_data_partial_balance_free ( struct_partial_balance *partial_balance);
 static gpointer gsb_data_partial_balance_get_structure ( gint partial_balance_number );
 static gboolean gsb_data_partial_balance_init_from_liste_cptes ( gint partial_balance_number,
                         GtkWidget *parent );
@@ -1039,11 +1040,11 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
     partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
 
     if ( !partial_balance )
-        return 0;
+        return NULL;
 
     if ( partial_balance -> liste_cptes == NULL || 
      strlen ( partial_balance -> liste_cptes ) == 0 )
-        return 0;
+        return NULL;
 
     tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
     for ( i = 0; tab[i]; i++ )
@@ -1078,9 +1079,10 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
     if ( partial_balance -> colorise && solde.mantissa < 0 )
         string = g_strdup_printf ( "<span color=\"red\">%s</span>",
                         gsb_real_get_string_with_currency (
-                        solde, partial_balance -> currency, TRUE) );
+                        solde, partial_balance -> currency, TRUE ) );
     else
-        string = gsb_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
+        string = gsb_real_get_string_with_currency (
+                        solde, partial_balance -> currency, TRUE );
 
     return string;
 }
@@ -1090,22 +1092,21 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
  * 
  *
  * */
-gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_number )
+gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_number )
 {
     struct_partial_balance *partial_balance;
     gsb_real solde = null_real;
     gchar **tab;
-    gchar *string;
     gint i;
 
     partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
 
     if ( !partial_balance )
-        return 0;
+        return null_real;
 
     if ( partial_balance -> liste_cptes == NULL || 
      strlen ( partial_balance -> liste_cptes ) == 0 )
-        return 0;
+        return null_real;
 
     tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
     for ( i = 0; tab[i]; i++ )
@@ -1136,12 +1137,34 @@ gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_numbe
         solde = gsb_real_add ( solde, tmp_real );
     }
 
+    return solde;
+}
+
+
+/**
+ * 
+ *
+ * */
+gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_number )
+{
+    struct_partial_balance *partial_balance;
+    gsb_real solde = null_real;
+    gchar *string;
+
+    partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
+
+    if ( !partial_balance )
+        return NULL;
+
+    solde = gsb_data_partial_balance_get_current_amount ( partial_balance_number );
+
     if ( partial_balance -> colorise && solde.mantissa < 0 )
         string = g_strdup_printf ( "<span color=\"red\">%s</span>",
                         gsb_real_get_string_with_currency (
-                        solde, partial_balance -> currency, TRUE) );
+                        solde, partial_balance -> currency, TRUE ) );
     else
-        string = gsb_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
+        string = gsb_real_get_string_with_currency (
+                        solde, partial_balance -> currency, TRUE );
 
     return string;
 }
@@ -1528,7 +1551,7 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, TRUE, TRUE, 0 );
 
     /* Partial balance name */
-    label = gtk_label_new ( COLON ( _("Name") ) );
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1 );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -1539,7 +1562,7 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
                         GTK_EXPAND|GTK_FILL, 0, 0, 0 );
 
     /* List of the accounts */
-    label = gtk_label_new ( COLON ( _("Accounts list") ) );
+    label = gtk_label_new ( _("Accounts list: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
@@ -1554,7 +1577,7 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
                         GTK_EXPAND | GTK_FILL, 0, 0, 0 );
 
     /* create the position */
-    label = gtk_label_new ( COLON ( _("Position in the list of accounts") ) );
+    label = gtk_label_new ( _("Position in the list of accounts: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 4, 5,
@@ -1602,7 +1625,7 @@ gint gsb_partial_balance_request_currency ( GtkWidget *parent )
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ), hbox, TRUE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON ( _("Select the currency of the partial balance") ) );
+    label = gtk_label_new ( _("Select the currency of the partial balance: ") );
     gtk_misc_set_alignment ( GTK_MISC  ( label ), 0, 1 );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, TRUE, TRUE, 0 );
