@@ -27,21 +27,26 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_payee.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./tiers_onglet.h"
-#include "./gsb_real.h"
-#include "./utils_str.h"
-#include "./meta_payee.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./gsb_real.h"
-#include "./erreur.h"
+#include "gsb_data_form.h"
+#include "gsb_data_report.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form_widget.h"
+#include "gtk_combofix.h"
+#include "tiers_onglet.h"
+#include "gsb_real.h"
+#include "utils_str.h"
+#include "meta_payee.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
@@ -62,7 +67,7 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_payee_free ( struct_payee* payee);
+static void _gsb_data_payee_free ( struct_payee* payee);
 static GSList *gsb_data_payee_get_name_list ( void );
 static gint gsb_data_payee_get_pointer_from_name_in_glist ( struct_payee *payee,
 						     const gchar *name );
@@ -243,13 +248,21 @@ gint gsb_data_payee_new ( const gchar *name )
 {
     struct_payee *payee;
 
-    payee = g_malloc0 ( sizeof ( struct_payee ));
+    payee = g_malloc0 ( sizeof ( struct_payee ) );
     payee -> payee_number = gsb_data_payee_max_number () + 1;
 
-    if (name)
-	payee -> payee_name = my_strdup (name);
+    if ( name )
+    {
+        GtkWidget *combofix;
+
+        payee -> payee_name = my_strdup ( name );
+        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
+    
+        if ( combofix && name )
+            gtk_combofix_append_text ( GTK_COMBOFIX ( combofix ), name );
+    }
     else 
-	payee -> payee_name = NULL;
+        payee -> payee_name = NULL;
 
     payee_list = g_slist_append ( payee_list, payee );
 
@@ -287,12 +300,17 @@ static void _gsb_data_payee_free ( struct_payee* payee)
 gboolean gsb_data_payee_remove ( gint no_payee )
 {
     struct_payee *payee;
+    GtkWidget *combofix;
 
     payee = gsb_data_payee_get_structure ( no_payee );
 
     if (!payee)
-	return FALSE;
-    
+        return FALSE;
+
+    combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
+    if ( combofix )
+        gtk_combofix_remove_text ( GTK_COMBOFIX ( combofix ), payee -> payee_name );
+
     payee_list = g_slist_remove ( payee_list,
 				  payee );
     _gsb_data_payee_free (payee);
@@ -336,29 +354,28 @@ gint gsb_data_payee_set_new_number ( gint no_payee,
  * \return the number of the payee or 0 if problem
  * */
 gint gsb_data_payee_get_number_by_name ( const gchar *name,
-					 gboolean create )
+                        gboolean create )
 {
     GSList *list_tmp;
     gint payee_number = 0;
 
     list_tmp = g_slist_find_custom ( payee_list,
-				     name,
-				     (GCompareFunc) gsb_data_payee_get_pointer_from_name_in_glist );
+                        name,
+                        (GCompareFunc) gsb_data_payee_get_pointer_from_name_in_glist );
     
     if ( list_tmp )
     {
-	struct_payee *payee;
-	
-	payee = list_tmp -> data;
-	payee_number = payee -> payee_number;
+        struct_payee *payee;
+        
+        payee = list_tmp -> data;
+        payee_number = payee -> payee_number;
     }
     else
     {
-	if (create)
-	{
-	    payee_number = gsb_data_payee_new (name);
-	    gsb_payee_update_combofix ();
-	}
+        if (create)
+        {
+            payee_number = gsb_data_payee_new ( name );
+        }
     }
     return payee_number;
 }
@@ -419,20 +436,28 @@ gboolean gsb_data_payee_set_name ( gint no_payee,
 				   const gchar *name )
 {
     struct_payee *payee;
+    GtkWidget *combofix;
 
     payee = gsb_data_payee_get_structure ( no_payee );
 
     if (!payee)
-	return FALSE;
+        return FALSE;
+
+    combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
 
     /* we free the last name */
     if ( payee -> payee_name )
-	g_free (payee -> payee_name);
+    {
+        if ( combofix )
+            gtk_combofix_remove_text ( GTK_COMBOFIX ( combofix ), payee -> payee_name );
+	    g_free ( payee -> payee_name );
+    }
     
     /* and copy the new one or set NULL */
-    payee -> payee_name = my_strdup (name);
+    payee -> payee_name = my_strdup ( name );
 
-    gsb_payee_update_combofix ();
+    if ( combofix && name && strlen ( name ) )
+        gtk_combofix_append_text ( GTK_COMBOFIX ( combofix ), name );
 
     return TRUE;
 }
@@ -460,8 +485,7 @@ GSList *gsb_data_payee_get_name_list ( void )
         payee = tmp_list -> data;
 
         if ( payee -> payee_name )
-            return_list = g_slist_insert_sorted ( return_list, payee -> payee_name,
-                        (GCompareFunc) g_utf8_collate );
+			return_list = g_slist_append ( return_list, payee -> payee_name );
 
         tmp_list = tmp_list -> next;
     }
@@ -744,19 +768,22 @@ void gsb_data_payee_remove_transaction_from_payee ( gint transaction_number )
      * we work with empty_payee */
 
     if (!payee
-	&&
-	!gsb_data_transaction_get_split_of_transaction (transaction_number)
-	&& 
-	gsb_data_transaction_get_contra_transaction_number (transaction_number) == 0)
-	payee = empty_payee;
+            &&
+            !gsb_data_transaction_get_split_of_transaction (transaction_number)
+            && 
+            gsb_data_transaction_get_contra_transaction_number (transaction_number) == 0)
+        payee = empty_payee;
 
-	payee -> payee_nb_transactions --;
-	payee -> payee_balance = gsb_real_sub ( payee -> payee_balance,
-						gsb_data_transaction_get_adjusted_amount_for_currency ( transaction_number,
-													payee_tree_currency (), -1));
+    if (payee)
+    {
+        payee -> payee_nb_transactions --;
+        payee -> payee_balance = gsb_real_sub ( payee -> payee_balance,
+                gsb_data_transaction_get_adjusted_amount_for_currency ( transaction_number,
+                    payee_tree_currency (), -1));
 
-	if ( !payee -> payee_nb_transactions ) /* Cope with float errors */
-	    payee -> payee_balance = null_real;
+        if ( !payee -> payee_nb_transactions ) /* Cope with float errors */
+            payee -> payee_balance = null_real;
+    }
 }
 
 
