@@ -26,16 +26,19 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_reconcile.h"
-#include "./dialog.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_dates.h"
-#include "./utils_str.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_real.h"
+#include "dialog.h"
+#include "gsb_data_transaction.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "gsb_real.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -57,7 +60,7 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_reconcile_free ( struct_reconcile *reconcile );
+static void _gsb_data_reconcile_free ( struct_reconcile *reconcile );
 static gint gsb_data_reconcile_cmp_int (struct_reconcile *reconcile_1,
                         struct_reconcile *reconcile_2);
 static gpointer gsb_data_reconcile_get_structure ( gint reconcile_number );
