@@ -28,14 +28,18 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_report.h"
-#include "./gsb_data_report_amout_comparison.h"
-#include "./gsb_data_report_text_comparison.h"
-#include "./utils_dates.h"
-#include "./utils_str.h"
+#include "gsb_data_report_amout_comparison.h"
+#include "gsb_data_report_text_comparison.h"
+#include "utils_dates.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -156,7 +160,7 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_report_free ( struct_report *report );
+static void _gsb_data_report_free ( struct_report *report );
 static GSList *gsb_data_report_copy_categ_budget_struct (GSList *orig_categ_budget_list);
 static struct_report *gsb_data_report_get_structure ( gint report_number );
 /*END_STATIC*/
