@@ -29,11 +29,15 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_report_amout_comparison.h"
-#include "./gsb_real.h"
+#include "gsb_real.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -67,8 +71,8 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_report_amount_comparison_free ( struct_amount_comparison *amount_comparison );
-static  struct_amount_comparison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number );
+static void _gsb_data_report_amount_comparison_free ( struct_amount_comparison *amount_comparison );
+static struct_amount_comparison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number );
 static gint gsb_data_report_amount_comparison_max_number ( void );
 /*END_STATIC*/
 
