@@ -29,11 +29,15 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_data_report_text_comparison.h"
-#include "./utils_str.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -87,8 +91,8 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_report_text_comparison_free ( struct_text_comparison* text_comparison );
-static  struct_text_comparison *gsb_data_report_text_comparison_get_struct_by_no ( gint text_comparison_number );
+static void _gsb_data_report_text_comparison_free ( struct_text_comparison* text_comparison );
+static struct_text_comparison *gsb_data_report_text_comparison_get_struct_by_no ( gint text_comparison_number );
 static gint gsb_data_report_text_comparison_max_number ( void );
 /*END_STATIC*/
 
