@@ -26,15 +26,23 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "gsb_data_scheduled.h"
-#include "./dialog.h"
-#include "./utils_dates.h"
-#include "./utils_str.h"
-#include "./include.h"
+#include "dialog.h"
+#include "gsb_currency.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_currency_link.h"
+#include "gsb_real.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
@@ -82,7 +90,7 @@ typedef struct
 
 
 /*START_STATIC*/
-static  void _gsb_data_scheduled_free ( struct_scheduled *scheduled );
+static void _gsb_data_scheduled_free ( struct_scheduled *scheduled );
 static void gsb_data_scheduled_delete_all_scheduled ();
 static gint gsb_data_scheduled_get_last_number (void);
 static gint gsb_data_scheduled_get_last_white_number (void);
@@ -1741,6 +1749,169 @@ gint gsb_data_scheduled_get_white_line ( gint scheduled_number)
 }
 
 
+/**
+ * get floating point of the currency of the scheduled given
+ *
+ * \param scheduled_number the number of the scheduled
+ *
+ * \return the floating_point of currency number of the scheduled
+ * */
+gint gsb_data_scheduled_get_currency_floating_point ( gint scheduled_number )
+{
+    struct_scheduled *scheduled;
+    gint floating_point;
+
+    scheduled = gsb_data_scheduled_get_scheduled_by_no ( scheduled_number);
+
+    if ( !scheduled )
+        return -1;
+    else
+    {
+        floating_point = gsb_data_currency_get_floating_point ( scheduled -> currency_number );
+        return floating_point;
+    }
+}
+
+
+/**
+ * get the amount of the scheduled, modified to be ok with the currency
+ * given in param 
+ * 
+ * \param scheduled_number 		the number of the scheduled
+ * \param return_currency_number 	the currency we want to adjust the transaction's amount
+ * \param return_exponent 		the exponent we want to have for the returned number, or -1 for the exponent of the returned currency
+ * 
+ * \return the amount of the transaction
+ * */
+gsb_real gsb_data_scheduled_get_adjusted_amount_for_currency ( gint scheduled_number,
+                        gint return_currency_number,
+                        gint return_exponent )
+{
+    struct_scheduled *scheduled;
+    gsb_real amount = null_real;
+    gint link_number;
+
+    if (return_exponent == -1)
+        return_exponent = gsb_data_currency_get_floating_point ( return_currency_number );
+
+    scheduled = gsb_data_scheduled_get_scheduled_by_no ( scheduled_number);
+
+    if ( ! (scheduled && return_currency_number ) )
+        return gsb_real_adjust_exponent  ( null_real, return_exponent );
+
+    /* if the transaction currency is the same of the account's one,
+     * we just return the transaction's amount */
+    if ( scheduled -> currency_number == return_currency_number )
+        return gsb_real_adjust_exponent  ( scheduled -> scheduled_amount,
+					   return_exponent );
+
+    /* now we can adjust the amount */
+    if ( ( link_number = gsb_data_currency_link_search ( scheduled -> currency_number,
+							return_currency_number ) ) )
+    {
+	/* there is a hard link between the transaction currency and the return currency */
+        if ( gsb_data_currency_link_get_first_currency ( link_number ) == scheduled -> currency_number )
+            amount = gsb_real_mul ( scheduled -> scheduled_amount,
+                        gsb_data_currency_link_get_change_rate ( link_number ) );
+        else
+            amount = gsb_real_div ( scheduled -> scheduled_amount,
+                        gsb_data_currency_link_get_change_rate (link_number));
+
+    }
+    else if ( return_currency_number > 0 && scheduled -> currency_number > 0 )
+    {
+        gchar *tmp_str;
+
+        tmp_str = g_strdup ( _("Error: is missing one or more links between currencies.\n"
+                        "You need to fix it and start over.") );
+        dialogue_error ( tmp_str );
+
+        g_free ( tmp_str );
+    }
+
+    return gsb_real_adjust_exponent  ( amount, return_exponent );
+}
+
+
+/**
+ * copy the content of a scheduled transaction into the second one
+ * the 2 scheduled transactions must exist before
+ * only the scheduled_number will be modified in the target transaction
+ *
+ * \param source_scheduled_number the transaction we want to copy
+ * \param target_scheduled_number the transaction we want to fill with the content of the first one
+ *
+ * \return TRUE if ok, FALSE else
+ * */
+gboolean gsb_data_scheduled_copy_scheduled ( gint source_scheduled_number,
+                        gint target_scheduled_number )
+{
+    struct_scheduled *source_scheduled;
+    struct_scheduled *target_scheduled;
+
+    source_scheduled = gsb_data_scheduled_get_scheduled_by_no ( source_scheduled_number );
+    target_scheduled = gsb_data_scheduled_get_scheduled_by_no ( target_scheduled_number );
+
+    if ( !source_scheduled || !target_scheduled )
+        return FALSE;
+
+    memcpy ( target_scheduled, source_scheduled, sizeof ( struct_scheduled ) );
+
+    target_scheduled -> scheduled_number = target_scheduled_number;
+
+    /* make a new copy of all the pointers */
+    if ( target_scheduled -> notes)
+        target_scheduled -> notes = my_strdup ( source_scheduled -> notes );
+
+    if ( target_scheduled -> date)
+        target_scheduled -> date = gsb_date_copy ( source_scheduled -> date );
+
+    if ( target_scheduled -> limit_date)
+        target_scheduled -> limit_date = gsb_date_copy ( source_scheduled -> limit_date );
+
+    if ( target_scheduled -> method_of_payment_content)
+        target_scheduled -> method_of_payment_content = my_strdup (
+                        source_scheduled -> method_of_payment_content );
+    return TRUE;
+}
+
+
+/**
+ * retourne TRUE si la variance de l'opration ventile == 0
+ *
+ *
+ *
+ * */
+gboolean gsb_data_scheduled_get_variance ( gint mother_scheduled_number )
+{
+    GSList *tmp_list;
+    gsb_real total_split = null_real;
+    gsb_real variance;
+
+    tmp_list = scheduled_list;
+    while ( tmp_list )
+    {
+        struct_scheduled *tmp_scheduled;
+
+        tmp_scheduled = tmp_list -> data;
+
+        if ( tmp_scheduled -> mother_scheduled_number == mother_scheduled_number )
+        {
+            total_split = gsb_real_add ( total_split,
+                        gsb_data_scheduled_get_amount ( tmp_scheduled -> scheduled_number ) );
+        }
+        tmp_list = tmp_list -> next;
+    }
+
+    variance = gsb_real_sub ( gsb_data_scheduled_get_amount ( mother_scheduled_number ), total_split );
+
+    if ( variance.mantissa == 0 )
+        return TRUE;
+    else
+        return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
