@@ -3,7 +3,7 @@
 
 
 /* START_INCLUDE_H */
-#include "././gsb_real.h"
+#include "gsb_real.h"
 /* END_INCLUDE_H */
 
 
@@ -19,7 +19,7 @@ enum operation_etat_rapprochement {
 /* START_DECLARATION */
 gboolean gsb_data_transaction_add_archived_to_list ( gint transaction_number );
 gint gsb_data_transaction_check_content_payment ( gint payment_number,
-                        gint number );
+                        const gchar *number );
 gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
                         gint target_transaction_number,
                         gboolean reset_mark );
@@ -45,6 +45,7 @@ GSList *gsb_data_transaction_get_complete_transactions_list ( void );
 gint gsb_data_transaction_get_contra_transaction_account ( gint transaction_number );
 gint gsb_data_transaction_get_contra_transaction_number ( gint transaction_number );
 gint gsb_data_transaction_get_currency_number ( gint transaction_number );
+gint gsb_data_transaction_get_currency_floating_point ( gint transaction_number );
 const GDate *gsb_data_transaction_get_date ( gint transaction_number );
 gsb_real gsb_data_transaction_get_exchange_fees ( gint transaction_number );
 gsb_real gsb_data_transaction_get_exchange_rate ( gint transaction_number );
