@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2005-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*                      2008-2009 Pierre Biava (grisbi@pierre.biava.name)     */
+/*                      2008-2011 Pierre Biava (grisbi@pierre.biava.name)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -28,22 +28,23 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_file_config.h"
-#include "./dialog.h"
-#include "./gsb_file.h"
-#include "./utils_str.h"
-#include "./main.h"
-#include "./utils_files.h"
-#include "./print_config.h"
-#include "./structures.h"
-#include "./utils_str.h"
-#include "./utils_buttons.h"
-#include "./print_config.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "gsb_file.h"
+#include "main.h"
+#include "print_config.h"
+#include "structures.h"
+#include "utils_buttons.h"
+#include "utils_files.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -55,12 +56,11 @@ static void gsb_file_config_get_xml_text_element ( GMarkupParseContext *context,
                         gpointer user_data,
                         GError **error);
 static gboolean gsb_file_config_load_last_xml_config ( gchar *filename );
-static  void gsb_file_config_remove_old_config_file ( gchar *filename );
+static void gsb_file_config_remove_old_config_file ( gchar *filename );
 /*END_STATIC*/
 
 
 /*START_EXTERN*/
-extern gboolean balances_with_scheduled;
 extern struct conditional_message delete_msg[];
 extern gboolean execute_scheduled_of_month;
 extern GtkWidget *main_hpaned;
@@ -70,6 +70,9 @@ extern gchar *nom_fichier_comptes;
 extern GtkWidget *window;
 /*END_EXTERN*/
 
+/* global variable, see structures.h */
+struct gsb_conf_t conf;
+
 gint mini_paned_width = 0;
 
 /* contient le nb de derniers fichiers ouverts */
@@ -79,6 +82,11 @@ gsize nb_derniers_fichiers_ouverts = 0;
 gint nb_max_derniers_fichiers_ouverts = 0;
 gchar **tab_noms_derniers_fichiers_ouverts = NULL;
 
+#if IS_DEVELOPMENT_VERSION == 1
+/* flag de chargement du fichier modèle */
+static gboolean used_model = FALSE;
+#endif
+
 
 /**
  * load the config file
@@ -98,10 +106,19 @@ gboolean gsb_file_config_load_config ( void )
     gint i;
     gint int_ret;
     GError* err = NULL;
-
+devel_debug (NULL);
     gsb_file_config_clean_config ();
 
     filename = g_strconcat ( my_get_XDG_grisbirc_dir(), C_GRISBIRC, NULL );
+#if IS_DEVELOPMENT_VERSION == 1
+    if ( !g_file_test (filename, G_FILE_TEST_EXISTS) )
+    {
+        g_free ( filename );
+        filename = g_strconcat ( my_get_XDG_grisbirc_dir(), "/", PACKAGE, ".conf", NULL );
+        used_model = FALSE;
+    }
+#endif
+
     config = g_key_file_new ();
     
     result = g_key_file_load_from_file ( config,
@@ -113,16 +130,16 @@ gboolean gsb_file_config_load_config ( void )
     if (!result)
     {
         /* On recherche le fichier dans HOME */
-        #ifndef _WIN32
+#ifndef _WIN32
         /* On recherche les fichiers possibles seulement sous linux */
         g_free ( filename );
         filename = gsb_config_get_old_conf_name ( );
         devel_debug (filename);
         if ( ! filename || strlen ( filename ) == 0 )
             return FALSE;
-        #else
+#else
         filename = g_strconcat ( my_get_grisbirc_dir(), C_OLD_GRISBIRC, NULL );
-        #endif
+#endif
         
         config = g_key_file_new ();
         
@@ -143,6 +160,28 @@ gboolean gsb_file_config_load_config ( void )
             g_unlink ( filename );
     }
 
+#if IS_DEVELOPMENT_VERSION == 1
+    /* get config model */
+    conf.stable_config_file_model = g_key_file_get_integer ( config,
+                        "Model",
+                        "Stable_config_file_model",
+                        NULL );
+    if ( conf.stable_config_file_model )
+    {
+        used_model = TRUE;
+        filename = g_strconcat ( my_get_XDG_grisbirc_dir(), "/", PACKAGE, ".conf", NULL );
+        if ( !g_file_test (filename, G_FILE_TEST_EXISTS) )
+            return FALSE;
+
+        g_key_file_free (config);
+        config = g_key_file_new ();
+        result = g_key_file_load_from_file ( config,
+                        filename,
+                        G_KEY_FILE_KEEP_COMMENTS,
+                        NULL );
+    }
+#endif
+
     /* get the geometry */
     conf.root_x = g_key_file_get_integer ( config,
                         "Geometry",
@@ -234,6 +273,10 @@ gboolean gsb_file_config_load_config ( void )
                         "Pluriel_final",
                         NULL );
                         
+    conf.metatree_action_2button_press = g_key_file_get_integer ( config,
+                        "General",
+                        "Metatree_action_2button_press",
+                        NULL );
 
     /* get backup part */
     conf.make_backup = g_key_file_get_integer ( config,
@@ -256,6 +299,12 @@ gboolean gsb_file_config_load_config ( void )
                         "Make backup nb minutes",
                         NULL );
 
+    /* exec gsb_file_automatic_backup_start ( ) if necessary */
+    if ( conf.make_backup_every_minutes
+	&&
+	conf.make_backup_nb_minutes )
+        gsb_file_automatic_backup_start ( NULL, NULL );
+
     conf.compress_backup = g_key_file_get_integer ( config,
                         "Backup",
                         "Compress backup",
@@ -333,7 +382,7 @@ gboolean gsb_file_config_load_config ( void )
                         "Balances with scheduled",
                         &err );
     if ( err == NULL )
-        balances_with_scheduled = int_ret;
+        conf.balances_with_scheduled = int_ret;
     else
         err = NULL;
 
@@ -352,14 +401,15 @@ gboolean gsb_file_config_load_config ( void )
                         "Display",
                         "Show transaction gives balance",
                         NULL );
-    conf.transactions_list_sort_by_date = g_key_file_get_integer ( config,
+
+    conf.transactions_list_primary_sorting = g_key_file_get_integer ( config,
                         "Display",
-                        "Transactions list sort by date",
+                        "Transactions_list_primary_sorting",
                         NULL );
 
-    conf.transactions_list_sort_by_value_date = g_key_file_get_integer ( config,
+    conf.transactions_list_secondary_sorting = g_key_file_get_integer ( config,
                         "Display",
-                        "Transactions list sort by value date",
+                        "Transactions_list_secondary_sorting",
                         NULL );
 
     etat.largeur_auto_colonnes = g_key_file_get_integer ( config,
@@ -377,15 +427,20 @@ gboolean gsb_file_config_load_config ( void )
                         "Automatic completion payee",
                         &err );
     if ( err == NULL )
-        etat.automatic_completion_payee = int_ret;
+        conf.automatic_completion_payee = int_ret;
     else
         err = NULL;
 
-    etat.limit_completion_to_current_account = g_key_file_get_integer ( config,
+    conf.limit_completion_to_current_account = g_key_file_get_integer ( config,
                         "Display",
                         "Limit payee completion",
                         NULL );
 
+    conf.automatic_recover_splits = g_key_file_get_integer ( config,
+                        "Display",
+                        "Automatic_recover_splits",
+                        NULL );
+
     etat.display_toolbar = g_key_file_get_integer ( config,
                         "Display",
                         "Display toolbar",
@@ -406,7 +461,7 @@ gboolean gsb_file_config_load_config ( void )
                         "Show closed accounts",
                         NULL );
 
-    etat.display_grisbi_title = g_key_file_get_integer ( config,
+    conf.display_grisbi_title = g_key_file_get_integer ( config,
                         "Display",
                         "Display grisbi title",
                         NULL );
@@ -515,7 +570,15 @@ gboolean gsb_file_config_save_config ( void )
 
     filename = g_strconcat ( my_get_XDG_grisbirc_dir(), C_GRISBIRC, NULL );
     config = g_key_file_new ();
-    
+
+#if IS_DEVELOPMENT_VERSION == 1
+    /* set config model */
+    g_key_file_set_integer ( config,
+                        "Model",
+                        "Stable_config_file_model",
+                        conf.stable_config_file_model );
+#endif
+
     /* get the geometry */
     if ( GTK_WIDGET ( window) -> window ) 
         gtk_window_get_size ( GTK_WINDOW ( window ),
@@ -619,7 +682,8 @@ gboolean gsb_file_config_save_config ( void )
         gchar *string;
 
         string = my_strdelimit ( conf.browser_command, "&", "\\e" );
-        g_key_file_set_string ( config,
+        if ( string )
+            g_key_file_set_string ( config,
                         "General",
                         "Web",
                         string );
@@ -631,6 +695,11 @@ gboolean gsb_file_config_save_config ( void )
                         "Pluriel_final",
                         conf.pluriel_final );
 
+    g_key_file_set_integer ( config,
+                        "General",
+                        "Metatree_action_2button_press",
+                        conf.metatree_action_2button_press );
+
      /* save backup part */
     g_key_file_set_integer ( config,
                         "Backup",
@@ -727,7 +796,7 @@ gboolean gsb_file_config_save_config ( void )
     g_key_file_set_integer ( config,
                         "Scheduled",
                         "Balances with scheduled",
-                        balances_with_scheduled );
+                        conf.balances_with_scheduled );
 
     /* save shown section */
     g_key_file_set_integer ( config,
@@ -747,13 +816,13 @@ gboolean gsb_file_config_save_config ( void )
 
     g_key_file_set_integer ( config,
                         "Display",
-                        "Transactions list sort by date",
-                        conf.transactions_list_sort_by_date );
+                        "Transactions_list_primary_sorting",
+                        conf.transactions_list_primary_sorting );
 
     g_key_file_set_integer ( config,
                         "Display",
-                        "Transactions list sort by value date",
-                        conf.transactions_list_sort_by_value_date );
+                        "Transactions_list_secondary_sorting",
+                        conf.transactions_list_secondary_sorting );
 
     g_key_file_set_integer ( config,
                         "Display",
@@ -763,12 +832,17 @@ gboolean gsb_file_config_save_config ( void )
     g_key_file_set_integer ( config,
                         "Display",
                         "Automatic completion payee",
-                        etat.automatic_completion_payee );
+                        conf.automatic_completion_payee );
 
     g_key_file_set_integer ( config,
                         "Display",
                         "Limit payee completion",
-                        etat.limit_completion_to_current_account );
+                        conf.limit_completion_to_current_account );
+
+    g_key_file_set_integer ( config,
+                        "Display",
+                        "Automatic_recover_splits",
+                        conf.automatic_recover_splits );
 
     g_key_file_set_integer ( config,
                         "Display",
@@ -793,7 +867,7 @@ gboolean gsb_file_config_save_config ( void )
     g_key_file_set_integer ( config,
                         "Display",
                         "Display grisbi title",
-                        etat.display_grisbi_title );
+                        conf.display_grisbi_title );
 
     /* save messages */
     for ( i = 0; messages[i].name; i ++ )
@@ -811,7 +885,6 @@ gboolean gsb_file_config_save_config ( void )
                         delete_msg[i].hidden );
     }
 
-
     g_key_file_set_integer ( config,
                         "Messages",
                         "Last tip",
@@ -823,13 +896,13 @@ gboolean gsb_file_config_save_config ( void )
                         etat.show_tip );
 
     /* save printer config */
-
     g_key_file_set_integer ( config,
                         "Print config",
                         "Printer",
                         etat.print_config.printer );
 
-    g_key_file_set_string ( config,
+    if ( etat.print_config.printer_name )
+        g_key_file_set_string ( config,
                         "Print config",
                         "Printer name",
                         etat.print_config.printer_name );
@@ -851,7 +924,8 @@ gboolean gsb_file_config_save_config ( void )
                         etat.print_config.orientation );
 
     /* save the paper config */
-    g_key_file_set_string ( config,
+    if ( etat.print_config.paper_config.name )
+        g_key_file_set_string ( config,
                         "Paper config",
                         "Name",
                         etat.print_config.paper_config.name );
@@ -885,7 +959,7 @@ gboolean gsb_file_config_save_config ( void )
     {
         gchar* tmpstr = g_strdup_printf ( _("Cannot save configuration file '%s': %s"),
                         filename,
-                        latin2utf8(strerror ( errno )) );
+                        g_strerror ( errno ) );
         dialogue_error ( tmpstr );
         g_free ( tmpstr );
         g_free ( file_content);
@@ -963,7 +1037,7 @@ gboolean gsb_file_config_load_last_xml_config ( gchar *filename )
     {
 	gchar* tmpstr = g_strdup_printf (_("Cannot open config file '%s': %s"),
 					 filename,
-					 latin2utf8 (strerror(errno)));
+					 g_strerror(errno));
 	dialogue_error ( tmpstr );
 	g_free ( tmpstr );
 	return FALSE;
@@ -1296,7 +1370,6 @@ void gsb_file_config_clean_config ( void )
     conf.prefs_width = 600;
 
     conf.force_enregistrement = 1;
-    etat.utilise_logo = 1;
 
     conf.r_modifiable = 0;       /* we can not change the reconciled transaction */
     conf.dernier_fichier_auto = 1;   /*  on n'ouvre pas directement le dernier fichier */
@@ -1304,21 +1377,21 @@ void gsb_file_config_clean_config ( void )
     conf.entree = 1;    /* la touche entree provoque l'enregistrement de l'opération */
     nb_days_before_scheduled = 0;     /* nb de jours avant l'échéance pour prévenir */
     execute_scheduled_of_month = FALSE;
-    balances_with_scheduled = TRUE;
+    conf.balances_with_scheduled = TRUE;
     etat.formulaire_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 opé */
     etat.affichage_exercice_automatique = 0;        /* l'exercice est choisi en fonction de la date */
-    etat.get_fyear_by_value_date = 0;        /* By default use transaction-date */
-    etat.automatic_completion_payee = 1;        /* by default automatic completion */
-    etat.limit_completion_to_current_account = 0;        /* By default, do full search */
+    conf.automatic_completion_payee = 1;        /* by default automatic completion */
+    conf.limit_completion_to_current_account = 0;        /* By default, do full search */
+    conf.automatic_recover_splits = 1;
 
-    etat.display_grisbi_title = GSB_ACCOUNTS_TITLE;  /* show Accounts file title par défaut */
+    conf.display_grisbi_title = GSB_ACCOUNTS_TITLE;  /* show Accounts file title par défaut */
     etat.display_toolbar = GSB_BUTTON_BOTH;         /* How to display toolbar icons. */
     etat.show_toolbar = TRUE;                       /* Show toolbar or not. */
     etat.show_headings_bar = TRUE;                  /* Show toolbar or not. */
     conf.show_transaction_selected_in_form = 1;     /* show selected transaction in form */
     conf.show_transaction_gives_balance = 1;        /* show transaction that gives the balance of the day */
-    conf.transactions_list_sort_by_date = 0;        /* Options for sorting by date */  
-    conf.transactions_list_sort_by_value_date = 1;  /* Options for sorting by value date */  
+    conf.transactions_list_primary_sorting = 1;     /* Primary sorting option for the transactions */
+    conf.transactions_list_secondary_sorting = 0;   /* Secondary sorting option for the transactions */
     etat.show_closed_accounts = FALSE;
 
     if ( conf.font_string )
@@ -1334,6 +1407,10 @@ void gsb_file_config_clean_config ( void )
     conf.make_backup_every_minutes = FALSE;
     conf.make_backup_nb_minutes = 0;
 
+#if IS_DEVELOPMENT_VERSION == 1
+    conf.stable_config_file_model = 0;
+#endif
+
     nb_derniers_fichiers_ouverts = 0;
     nb_max_derniers_fichiers_ouverts = 3;
     tab_noms_derniers_fichiers_ouverts = NULL;
@@ -1349,7 +1426,7 @@ void gsb_file_config_clean_config ( void )
     etat.largeur_auto_colonnes = 0;
     etat.retient_affichage_par_compte = 0;
 
-    etat.last_tip = 0;
+    etat.last_tip = -1;
     etat.show_tip = FALSE;
 
     /* Commands */
@@ -1357,31 +1434,10 @@ void gsb_file_config_clean_config ( void )
     conf.latex_command = "latex";
     conf.dvips_command = "dvips";
 
-/* mise en conformité avec les recommandations FreeDesktop. */
-//~ #ifndef _WIN32
-    //~ if ( g_file_test ( "/usr/bin/firefox", G_FILE_TEST_EXISTS ) )
-    //~ {
-    //~ conf.browser_command = g_strdup ( "/usr/bin/firefox" );
-    //~ }
-    //~ else if ( g_file_test ( "/usr/bin/iceweasel", G_FILE_TEST_EXISTS ) )
-    //~ {
-    //~ conf.browser_command = g_strdup ( "/usr/bin/iceweasel" );
-    //~ }
-    //~ else if ( g_file_test ( "/usr/bin/opera", G_FILE_TEST_EXISTS ) )
-    //~ {
-    //~ conf.browser_command = g_strdup ( "/usr/bin/opera" );
-    //~ }
-    //~ else if ( g_file_test ( "/usr/bin/mozilla", G_FILE_TEST_EXISTS ) )
-    //~ {
-    //~ conf.browser_command = g_strdup ( "/usr/bin/mozilla" );
-    //~ }
-    //~ else
-    //~ {
-//~ #endif /* _WIN32 */
+    /* mise en conformité avec les recommandations FreeDesktop. */
     conf.browser_command = g_strdup (ETAT_WWW_BROWSER);
-//~ #ifndef _WIN32
-    //~ }
-//~ #endif /* _WIN32 */
+
+    conf.metatree_action_2button_press = 0;     /* action par défaut pour le double clic sur division */
 
     /* Print */
     etat.print_config.printer = 0;
@@ -1484,7 +1540,10 @@ gchar *gsb_config_get_old_conf_name ( void )
         }
     }
     else
+    {
         dialogue_error ( error -> message );
+        g_error_free ( error );
+    }
 
     if ( g_slist_length ( liste ) == 0 )
         return NULL;
