@@ -26,25 +26,28 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_file_others.h"
-#include "./dialog.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_report.h"
-#include "./gsb_file_load.h"
-#include "./gsb_file_save.h"
-#include "./navigation.h"
-#include "./utils_str.h"
-#include "./traitement_variables.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./utils_files.h"
-#include "./structures.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_report.h"
+#include "gsb_file_load.h"
+#include "gsb_file_save.h"
+#include "navigation.h"
+#include "utils_str.h"
+#include "traitement_variables.h"
+#include "categories_onglet.h"
+#include "imputation_budgetaire.h"
+#include "utils_files.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -143,7 +146,7 @@ gboolean gsb_file_others_save_category ( gchar *filename )
     {
         gchar *tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
 					   filename,
-					   latin2utf8(strerror(errno)) );
+					   g_strerror(errno) );
 	dialogue_error ( tmpstr );
 	g_free ( tmpstr );
 	g_free ( file_content);
@@ -224,7 +227,7 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
     {
 	gchar* tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
 					   filename,
-					   latin2utf8(strerror(errno)) );
+					   g_strerror(errno) );
 	dialogue_error ( tmpstr );
 	g_free ( tmpstr );
 	g_free ( file_content);
@@ -307,7 +310,7 @@ gboolean gsb_file_others_save_report ( gchar *filename )
     {
 	gchar* tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
 					   filename,
-					   latin2utf8(strerror(errno)) );
+					   g_strerror(errno) );
 	dialogue_error ( tmpstr);
 	g_free ( tmpstr );
 	g_free ( file_content);
@@ -424,7 +427,7 @@ gboolean gsb_file_others_load ( gchar *filename,
     {
         gchar* tmpstr = g_strdup_printf (_("Cannot open file '%s': %s"),
 					 filename,
-					 latin2utf8 (strerror(errno)));
+					 g_strerror(errno));
 	dialogue_error ( tmpstr );
 	g_free ( tmpstr );
 	return FALSE;
@@ -561,7 +564,7 @@ gboolean gsb_file_others_load ( gchar *filename,
     {
         gchar* tmpstr = g_strdup_printf (_("Cannot open file '%s': %s"),
 					 filename,
-					 latin2utf8 (strerror(errno)));
+					 g_strerror(errno));
 	dialogue_error ( tmpstr );
 	g_free ( tmpstr );
 	return FALSE;
@@ -748,7 +751,7 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
     {
         tmp_str = g_strdup_printf (_("Cannot open file '%s': %s"),
 					 filename,
-					 latin2utf8 ( strerror ( errno ) ) );
+					 g_strerror ( errno ) );
         dialogue_error ( tmp_str );
         g_free ( tmp_str );
         return FALSE;
@@ -808,7 +811,7 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
     {
         tmp_str = g_strdup_printf (_("Cannot open file '%s': %s"),
 					 filename,
-					 latin2utf8 ( strerror ( errno ) ) );
+					 g_strerror ( errno ) );
         dialogue_error ( tmp_str );
         g_free ( tmp_str );
         return FALSE;
