@@ -25,24 +25,26 @@
  * configuration page for the form
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_form_config.h"
-#include "./utils.h"
-#include "./dialog.h"
-#include "./gsb_account.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_form.h"
-#include "./gsb_form.h"
-#include "./gsb_form_widget.h"
-#include "./navigation.h"
-#include "./utils_str.h"
-#include "./traitement_variables.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
-#include "./structures.h"
+#include "utils.h"
+#include "dialog.h"
+#include "gsb_account.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_data_form.h"
+#include "gsb_form.h"
+#include "gsb_form_widget.h"
+#include "navigation.h"
+#include "utils_str.h"
+#include "traitement_variables.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -93,9 +95,6 @@ static GtkWidget *form_config_buttons[TRANSACTION_FORM_WIDGET_NB-3];
 /** the option menu which contains all the accounts, to configure the form */
 static GtkWidget *accounts_combobox;
 
-/** the button to update all the accounts forms */
-//~ static GtkWidget *update_button;
-
 /** the tree view */
 static GtkWidget *form_config_tree_view;
 
@@ -140,10 +139,8 @@ void gsb_form_config_make_configuration_box ( GtkWidget *vbox_parent )
 {
     GtkWidget *sw;
     GtkWidget *hbox;
-    //~ GtkWidget *button;
     GtkWidget *paddingbox;
-    //~ GtkWidget *label;
-	GtkListStore* list_store;
+    GtkListStore* list_store;
 
     /* create the paddingbox into the parent */
     paddingbox = new_paddingbox_with_title ( vbox_parent, TRUE, _("Form structure preview"));
@@ -154,32 +151,8 @@ void gsb_form_config_make_configuration_box ( GtkWidget *vbox_parent )
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX (paddingbox), hbox, FALSE, FALSE, 0 );
 
-    /* the button to choose the configuration for all/one account */
-    //~ button = gsb_automem_checkbutton_new ( _("Each account has his own form"),
-                        //~ &etat.formulaire_distinct_par_compte,
-                        //~ G_CALLBACK ( gsb_form_config_switch_general_to_several_form ),
-                        //~ NULL);
-    //~ gtk_box_pack_start ( GTK_BOX (hbox ), button, FALSE, FALSE, 0 );
-
     /* the accounts option_menu */
     accounts_combobox = gsb_account_create_combo_list ((GtkSignalFunc) gsb_form_config_change_account_choice, NULL, FALSE );
-    //~ gtk_widget_set_sensitive ( accounts_combobox, etat.formulaire_distinct_par_compte );
-    //~ gtk_box_pack_start ( GTK_BOX (hbox ), accounts_combobox, FALSE, FALSE, 0 );
-
-    /* add the update-form button */
-    //~ hbox = gtk_hbox_new ( FALSE, 5 );
-    //~ gtk_box_pack_start ( GTK_BOX (paddingbox), hbox, FALSE, FALSE, 0 );
-
-    //~ update_button = gtk_button_new_with_label (_("Update"));
-    //~ gtk_widget_set_sensitive ( update_button, etat.formulaire_distinct_par_compte );
-    //~ g_signal_connect ( G_OBJECT (update_button),
-                        //~ "clicked",
-                        //~ G_CALLBACK (gsb_form_config_update_accounts),
-                        //~ accounts_combobox );
-    //~ gtk_box_pack_start ( GTK_BOX (hbox), update_button, FALSE, FALSE, 0 );
-
-    //~ label = gtk_label_new ( _(" : Duplicate the selected form for all accounts") );
-    //~ gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
     /*create the scolled window for tree_view */
     sw = gtk_scrolled_window_new ( NULL, NULL);
@@ -547,39 +520,6 @@ gboolean gsb_form_config_update_form_config ( gint account_number )
 }
 
 
-/**
- * called when click on the button "each account has his form",
- * unsensitive/sensitive the accounts option_menu,
- * if unsensitive, set the menu to the first account
- *
- * \param
- *
- * \return FALSE*/
-//~ gboolean gsb_form_config_switch_general_to_several_form ( void )
-//~ {
-    //~ if ( etat.formulaire_distinct_par_compte )
-    //~ {
-	//~ gtk_widget_set_sensitive ( accounts_combobox,
-				   //~ TRUE );
-	//~ gtk_widget_set_sensitive ( update_button,
-				   //~ TRUE );
-    //~ }
-    //~ else
-    //~ {
-	//~ gtk_combo_box_set_active ( GTK_COMBO_BOX (accounts_combobox),
-				   //~ 0 );
-	//~ /* just in case we were already on the first choice */
-	//~ gsb_form_config_change_account_choice (accounts_combobox, NULL);
-
-	//~ gtk_widget_set_sensitive ( accounts_combobox,
-				   //~ FALSE );
-	//~ gtk_widget_set_sensitive ( update_button,
-				   //~ FALSE );
-    //~ }
-    //~ return FALSE;
-//~ }
-
-						       
 /**
  * called if we change the account in the option menu of the accounts
  *
@@ -599,27 +539,6 @@ gboolean gsb_form_config_change_account_choice ( GtkWidget *combobox,
 }
 
 
-/**
- * callback for update all the accounts forms organization
- * 	according to the selected account
- *
- * \param button	the update_button
- * \param null		the combobox of accounts
- *
- * \return FALSE
- * */
-//~ static gboolean gsb_form_config_update_accounts ( GtkWidget *button,
-						  //~ GtkWidget *combobox )
-//~ {
-    //~ if (!question_yes_no (_("Warning : all the form of the accounts will be updated according to the selected account. All the changes in the other accounts will be overwritten.\n\nAre you sure to do that ?"), GTK_RESPONSE_CANCEL))
-	//~ return FALSE;
-
-    //~ /* update all the accounts */
-    //~ gsb_form_config_update_from_account (gsb_account_get_combo_account_number (combobox));
-
-    //~ return FALSE;
-//~ }
-
 /**
  * called when toggle a button of the form configuration, append or remove
  * the value from the tree view
@@ -747,11 +666,14 @@ gboolean gsb_form_config_toggle_element_button ( GtkWidget *toggle_button )
 						NULL );
 
 	    if ( no_second_element == -1 )
-		dialogue_hint ( _("There is no place enough to put the element. You need to increase the number of rows or columns to add an element."),
-				_("The table is full"));
+		dialogue_hint ( _("There is no place enough to put the element. You need to increase "
+                          "the number of rows or columns to add an element."),
+                        _("The table is full"));
 	    else
-		dialogue_hint ( _("There is no place enough to put the two elements (you have clicked on an element which contains two). You need to increase the number of rows or columns to add the elements."),
-				_("The table is full"));
+		dialogue_hint ( _("There is no place enough to put the two elements (you have clicked on "
+                          "an element which contains two). You need to increase the number of rows "
+                          "or columns to add the elements."),
+                        _("The table is full"));
 
 	    return TRUE;
 	}
@@ -802,6 +724,10 @@ gboolean gsb_form_config_toggle_element_button ( GtkWidget *toggle_button )
 
     gsb_form_config_update_from_account (
                         gsb_account_get_combo_account_number ( accounts_combobox ) );
+    /* update the form */
+    gsb_form_config_fill_store (account_number);
+    gsb_form_create_widgets ();
+
     if ( etat.modification_fichier == 0 )
         modification_fichier ( TRUE );
     return FALSE;
@@ -908,9 +834,6 @@ gboolean gsb_form_config_change_column_size ( GtkWidget *tree_view,
 
     for (i=0 ; i<gsb_data_account_get_accounts_amount () ; i++)
     {
-	if (!etat.formulaire_distinct_par_compte
-	    ||
-	    i == account_number)
 	    for ( column=0 ; column < gsb_data_form_get_nb_columns (i) ; column++ )
 	    {
 		gint size_column;
@@ -927,13 +850,9 @@ gboolean gsb_form_config_change_column_size ( GtkWidget *tree_view,
         modification_fichier ( TRUE );
 
     /* update the form if needed */
-    if ( !etat.formulaire_distinct_par_compte
-	 ||
-	 gsb_account_get_combo_account_number ( accounts_combobox ) == gsb_gui_navigation_get_current_account ())
-    {
 	saved_allocation_size = 0;
 	gsb_form_allocate_size ( NULL, &(form_transaction_part -> allocation), NULL );
-    }
+    gsb_form_create_widgets ();
 
     return FALSE;
 }
