@@ -26,32 +26,32 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_form_scheduler.h"
-#include "./gsb_account.h"
-#include "./gsb_calendar_entry.h"
-#include "./gsb_combo_box.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_scheduled.h"
-#include "./utils_dates.h"
-#include "./gsb_form.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_fyear.h"
-#include "./gsb_payment_method.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_transactions_list.h"
-#include "./gtk_combofix.h"
-#include "./utils_str.h"
-#include "./gtk_combofix.h"
-#include "./gsb_form.h"
-#include "./structures.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./gsb_form_widget.h"
+#include "gsb_account.h"
+#include "gsb_calendar_entry.h"
+#include "gsb_combo_box.h"
+#include "gsb_currency.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_scheduled.h"
+#include "utils_dates.h"
+#include "gsb_form.h"
+#include "gsb_form_widget.h"
+#include "gsb_fyear.h"
+#include "gsb_payment_method.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_transactions_list.h"
+#include "gtk_combofix.h"
+#include "utils_str.h"
+#include "structures.h"
+#include "gsb_data_form.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -161,18 +161,18 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
 		    widget = gsb_account_create_combo_list ((GtkSignalFunc) 
                         gsb_form_scheduler_change_account, NULL, FALSE);
 		    gtk_combo_box_set_active ( GTK_COMBO_BOX (widget), 0 );
-		    tooltip_text = SPACIFY(_("Choose the account"));
+		    tooltip_text = _("Choose the account");
 		    break;
 
 		case SCHEDULED_FORM_AUTO:
 		    widget = gsb_combo_box_new_with_index ( text_auto, NULL, NULL );
-		    tooltip_text = SPACIFY(_("Automatic/manual scheduled transaction"));
+		    tooltip_text = _("Automatic/manual scheduled transaction");
 		    break;
 
 		case SCHEDULED_FORM_FREQUENCY_BUTTON:
 		    widget = gsb_combo_box_new_with_index ( text_frequency,
                         G_CALLBACK (gsb_form_scheduler_frequency_button_changed), NULL );
-		    tooltip_text = SPACIFY(_("Frequency"));
+		    tooltip_text = _("Frequency");
 		    break;
 
         case SCHEDULED_FORM_LIMIT_DATE:
@@ -189,7 +189,7 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
                         "focus-out-event",
                         G_CALLBACK (gsb_form_scheduler_entry_lose_focus),
                         GINT_TO_POINTER (element_number));
-            tooltip_text = SPACIFY(_("Frequency"));
+            tooltip_text = _("Frequency");
             break;
 
 		case SCHEDULED_FORM_FREQUENCY_USER_ENTRY:
@@ -202,13 +202,13 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
                         "focus-out-event",
                         G_CALLBACK (gsb_form_scheduler_entry_lose_focus),
                         GINT_TO_POINTER (element_number));
-		    tooltip_text = SPACIFY(_("Own frequency"));
+		    tooltip_text = _("Own frequency");
 		    break;
 
 		case SCHEDULED_FORM_FREQUENCY_USER_BUTTON:
 		    widget = gsb_combo_box_new_with_index ( text_frequency_user,
 							    NULL, NULL );
-		    tooltip_text = SPACIFY(_("Custom frequency"));
+		    tooltip_text = _("Custom frequency");
 		    break;
 	    }
 
@@ -514,24 +514,25 @@ void gsb_form_scheduler_set_content_list ( GSList *content_list )
 		case TRANSACTION_FORM_BANK:
 		case TRANSACTION_FORM_VOUCHER:
 		    gsb_form_entry_get_focus (form_element -> element_widget);
-		    gtk_entry_set_text ( GTK_ENTRY (form_element -> element_widget),
-					 element -> element_string );
+            if ( element -> element_string )
+                gtk_entry_set_text ( GTK_ENTRY (form_element -> element_widget),
+                                element -> element_string );
 		    break;
 
 		case TRANSACTION_FORM_TYPE:
 		    gsb_payment_method_create_combo_list ( form_element -> element_widget,
 							   gsb_data_payment_get_sign (element -> element_int),
-							   account_number, FALSE );
+							   account_number, 0, FALSE );
 		    gsb_payment_method_set_combobox_history ( form_element -> element_widget,
-							      gsb_data_payment_get_similar (element -> element_int, account_number));
+							   gsb_data_payment_get_similar (element -> element_int, account_number), TRUE );
 		    break;
 
 		case TRANSACTION_FORM_CONTRA:
 		    gsb_payment_method_create_combo_list ( form_element -> element_widget,
 							   gsb_data_payment_get_sign (element -> element_int),
-							   account_number, FALSE );
+							   account_number, 0, TRUE );
 		    gsb_payment_method_set_combobox_history ( form_element -> element_widget,
-							      gsb_data_payment_get_similar (element -> element_int, account_number));
+							   gsb_data_payment_get_similar (element -> element_int, account_number), TRUE );
 			break;
 
 		case TRANSACTION_FORM_EXERCICE:
@@ -549,8 +550,9 @@ void gsb_form_scheduler_set_content_list ( GSList *content_list )
 		case TRANSACTION_FORM_CATEGORY:
 		case TRANSACTION_FORM_BUDGET:
 		    gsb_form_entry_get_focus (form_element -> element_widget);
-		    gtk_combofix_set_text ( GTK_COMBOFIX ( form_element -> element_widget ),
-					    element -> element_string );
+            if ( element -> element_string )
+                gtk_combofix_set_text ( GTK_COMBOFIX ( form_element -> element_widget ),
+                                element -> element_string );
 		    break;
 	    }
 	    form_list = form_list -> next;
