@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*                      2009 Pierre Biava (grisbi@pierre.biava.name)          */
+/*                      2009-2010 Pierre Biava (grisbi@pierre.biava.name)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -27,39 +27,36 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_form_widget.h"
-#include "./gsb_calendar_entry.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_form.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_form.h"
-#include "./gsb_form_transaction.h"
-#include "./gsb_fyear.h"
-#include "./gsb_payment_method.h"
-#include "./gtk_combofix.h"
-#include "./traitement_variables.h"
-#include "./gsb_form.h"
-#include "./gsb_data_payment.h"
-#include "./gtk_combofix.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./gsb_data_form.h"
-#include "./erreur.h"
+#include "gsb_calendar_entry.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_form.h"
+#include "gsb_data_payee.h"
+#include "gsb_form.h"
+#include "gsb_form_transaction.h"
+#include "gsb_fyear.h"
+#include "gsb_payment_method.h"
+#include "gtk_combofix.h"
+#include "traitement_variables.h"
+#include "gsb_data_payment.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static gboolean gsb_form_combo_selection_changed ( GtkTreeSelection *tree_selection,
 						  gint *ptr_origin );
 static gboolean gsb_form_widget_can_focus ( gint element_number );
-static gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
-                        GdkEventFocus *ev,
-                        gint *ptr_origin );
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -75,6 +72,8 @@ static gchar *old_debit = NULL;
 static gchar *old_credit = NULL;
 static gint old_credit_payment_number = 0;
 static gint old_debit_payment_number = 0;
+static gchar *old_credit_payment_content = NULL;
+static gchar *old_debit_payment_content = NULL;
 
 /**
  * return the list wich contains the widgets of the form
@@ -130,6 +129,7 @@ gboolean gsb_form_widget_free_list ( void )
                     g_signal_handlers_block_by_func ( element -> element_widget,
                         gsb_payment_method_changed_callback, NULL );
                     gtk_combofix_set_text ( GTK_COMBOFIX (element -> element_widget), "" );
+                    gsb_form_widget_set_empty ( GTK_WIDGET ( element -> element_widget ), TRUE );
                 }
                 gtk_widget_destroy (element -> element_widget);
                 element -> element_widget = NULL;
@@ -162,7 +162,6 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
                         gint account_number )
 {
     GtkWidget *widget;
-    GtkTreeSelection *tree_selection;
 
     if (!element_number)
 	return NULL;
@@ -205,11 +204,11 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	case TRANSACTION_FORM_EXERCICE:
 	    widget = gsb_fyear_make_combobox (TRUE);
 	    gtk_widget_set_tooltip_text ( GTK_WIDGET (widget),
-					  SPACIFY(_("Choose the financial year")));
+					  _("Choose the financial year") );
 	    break;
 
 	case TRANSACTION_FORM_PARTY:
-	    widget = gtk_combofix_new_complex (
+	    widget = gtk_combofix_new (
                         gsb_data_payee_get_name_and_report_list ( ) );
 	    gtk_combofix_set_force_text ( GTK_COMBOFIX (widget),
 					  etat.combofix_force_payee );
@@ -217,8 +216,6 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 					 etat.combofix_max_item );
 	    gtk_combofix_set_case_sensitive ( GTK_COMBOFIX (widget),
 					      etat.combofix_case_sensitive );
-	    //~ gtk_combofix_set_enter_function ( GTK_COMBOFIX (widget),
-					      //~ etat.combofix_enter_select_completion );
 	    /* we never mix the payee because the only case of the complex combofix is
 	     * for the report and there is non sense to mix report with the payee */
 	    gtk_combofix_set_mixed_sort ( GTK_COMBOFIX (widget),
@@ -226,7 +223,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    break;
 
 	case TRANSACTION_FORM_CATEGORY:
-	    widget = gtk_combofix_new_complex (
+	    widget = gtk_combofix_new (
                          gsb_data_category_get_name_list ( TRUE, TRUE, TRUE, TRUE ) );
 	    gtk_combofix_set_force_text ( GTK_COMBOFIX (widget),
 					  etat.combofix_force_category );
@@ -234,8 +231,6 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 					 etat.combofix_max_item );
 	    gtk_combofix_set_case_sensitive ( GTK_COMBOFIX (widget),
 					      etat.combofix_case_sensitive );
-	    //~ gtk_combofix_set_enter_function ( GTK_COMBOFIX (widget),
-					      //~ etat.combofix_enter_select_completion );
 	    gtk_combofix_set_mixed_sort ( GTK_COMBOFIX (widget),
 					  etat.combofix_mixed_sort );
 	    break;
@@ -245,7 +240,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    break;
 
 	case TRANSACTION_FORM_BUDGET:
-	    widget = gtk_combofix_new_complex (
+	    widget = gtk_combofix_new (
                         gsb_data_budget_get_name_list (TRUE, TRUE));
 	    gtk_combofix_set_force_text ( GTK_COMBOFIX (widget),
 					  etat.combofix_force_category );
@@ -253,8 +248,6 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 					 etat.combofix_max_item );
 	    gtk_combofix_set_case_sensitive ( GTK_COMBOFIX (widget),
 					      etat.combofix_case_sensitive );
-	    //~ gtk_combofix_set_enter_function ( GTK_COMBOFIX (widget),
-					      //~ etat.combofix_enter_select_completion );
 	    gtk_combofix_set_mixed_sort ( GTK_COMBOFIX (widget),
 					  etat.combofix_mixed_sort );
 	    break;
@@ -263,10 +256,10 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    widget = gtk_combo_box_new ();
 	    gsb_payment_method_create_combo_list ( widget,
                         GSB_PAYMENT_DEBIT,
-                        account_number, 0 );
+                        account_number, 0, FALSE );
 	    gtk_combo_box_set_active ( GTK_COMBO_BOX (widget), 0 );
 	    gtk_widget_set_tooltip_text ( GTK_WIDGET (widget),
-                        SPACIFY(_("Choose the method of payment")));
+                        _("Choose the method of payment") );
         g_signal_connect ( G_OBJECT (widget),
                         "changed",
                         G_CALLBACK (gsb_payment_method_changed_callback),
@@ -276,7 +269,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	case TRANSACTION_FORM_DEVISE:
 	    widget = gsb_currency_make_combobox (FALSE);
 	    gtk_widget_set_tooltip_text ( GTK_WIDGET (widget),
-					  SPACIFY(_("Choose currency")));
+					  _("Choose currency") );
 	    gsb_currency_set_combobox_history ( widget,
 						gsb_data_account_get_currency (account_number));
         g_signal_connect ( G_OBJECT (  widget ),
@@ -290,7 +283,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    gtk_button_set_relief ( GTK_BUTTON ( widget ),
 				    GTK_RELIEF_NONE );
 	    gtk_widget_set_tooltip_text ( GTK_WIDGET (widget),
-					  SPACIFY(_("Define the change for that transaction")));
+					  _("Define the change for that transaction") );
 	    g_signal_connect ( G_OBJECT (  widget ),
 			       "clicked",
 			       G_CALLBACK (gsb_form_transaction_change_clicked),
@@ -301,7 +294,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    /* no menu at beginning, appened when choose the contra-account */
 	    widget = gtk_combo_box_new ();
 	    gtk_widget_set_tooltip_text ( GTK_WIDGET (widget),
-					  SPACIFY(_("Contra-transaction method of payment")));
+					  _("Contra-transaction method of payment"));
 	    break;
 
 	case TRANSACTION_FORM_OP_NB:
@@ -321,7 +314,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	form_list_widgets = g_slist_append ( form_list_widgets, element );
 
 	/* set the signals */
-	if ( GTK_IS_ENTRY ( widget ))
+	if ( GTK_IS_ENTRY ( widget ) )
 	{
 	    g_signal_connect ( G_OBJECT ( widget ),
 			       "focus-in-event",
@@ -342,11 +335,8 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	}
 	else
 	{
-	    if ( GTK_IS_COMBOFIX ( widget ))
+	    if ( GTK_IS_COMBOFIX ( widget ) )
 	    {
-            tree_selection = gtk_tree_view_get_selection (
-                        GTK_TREE_VIEW ( GTK_COMBOFIX ( widget ) -> tree_view ) );
-
 		    g_signal_connect ( G_OBJECT ( GTK_COMBOFIX ( widget ) -> entry ),
                        "focus-in-event",
                        G_CALLBACK ( gsb_form_entry_get_focus ),
@@ -359,14 +349,13 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
                        "button-press-event",
                        G_CALLBACK ( gsb_form_button_press_event ),
                        GINT_TO_POINTER ( element_number ));
-            g_signal_connect ( G_OBJECT ( GTK_COMBOFIX (widget ) -> entry ),
+            g_signal_connect ( G_OBJECT ( GTK_COMBOFIX ( widget ) -> entry ),
                        "key-press-event",
                        G_CALLBACK ( gsb_form_key_press_event ),
                        GINT_TO_POINTER ( element_number ));
-            g_signal_connect ( G_OBJECT ( tree_selection ),
-                       "changed",
-                       G_CALLBACK ( gsb_form_combo_selection_changed ),
-                       GINT_TO_POINTER ( element_number ) );
+            gtk_combofix_set_selection_callback ( GTK_COMBOFIX ( widget ),
+						G_CALLBACK ( gsb_form_combo_selection_changed ),
+					    GINT_TO_POINTER ( element_number ) );
 	    }
 	    else
 		/* neither an entry, neither a combofix */
@@ -738,6 +727,10 @@ void gsb_form_widget_set_empty ( GtkWidget *entry,
 				 &gray );
     }
 
+	gtk_widget_modify_base ( entry, 
+				 GTK_STATE_NORMAL,
+				 NULL );
+
     g_object_set_data ( G_OBJECT(entry), "empty", GINT_TO_POINTER( empty ) );
 }
 
@@ -757,6 +750,7 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
 {
     GtkWidget *fyear_button;
     GtkWidget *widget;
+    GtkWidget *tmp_widget;
     gint element_number;
     gint account_number;
 
@@ -783,7 +777,9 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
     case TRANSACTION_FORM_VALUE_DATE:
         /* set the financial year on automatic by default */
         fyear_button = gsb_form_widget_get_widget (TRANSACTION_FORM_EXERCICE);
-        if (fyear_button)
+        if ( fyear_button
+         &&
+         gsb_data_account_get_current_transaction_number (account_number) == -1 )
             gsb_fyear_set_combobox_history ( fyear_button, 0 );
         break;
     case TRANSACTION_FORM_DEBIT :
@@ -791,12 +787,12 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
         if ( old_debit && strlen ( old_debit ) > 0 )
             old_debit = NULL;
 
-        /* we change the payment method to adapt it for the debit */
-        /* empty the credit */
+        /* save the credit if necessary */
         widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_CREDIT );
         if ( !gsb_form_widget_check_empty ( widget ) )
             old_credit = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( widget ) ) );
 
+        /* we change the payment method to adapt it for the debit */
         widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_TYPE);
 
         /* change the method of payment if necessary
@@ -808,23 +804,30 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
             /* change the signe of the method of payment and the contra */
             if ( gsb_payment_method_get_combo_sign ( widget ) == GSB_PAYMENT_CREDIT )
             {
-                old_credit_payment_number = gsb_payment_method_get_selected_number (
-                        widget );
+                old_credit_payment_number = gsb_payment_method_get_selected_number ( widget );
+
+                tmp_widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_CHEQUE );
+                if ( tmp_widget && GTK_WIDGET_VISIBLE ( tmp_widget ) )
+                {
+                    if ( old_credit_payment_content )
+                        g_free ( old_credit_payment_content );
+                    if ( gsb_form_widget_check_empty ( tmp_widget ) == FALSE )
+                        old_credit_payment_content = g_strdup ( gtk_entry_get_text (
+                                        GTK_ENTRY ( tmp_widget ) ) );
+                    else
+                        old_credit_payment_content = NULL;
+                }
 
                 gsb_payment_method_create_combo_list ( widget,
                                         GSB_PAYMENT_DEBIT,
-                                        account_number, 0 );
-                /* if there is no payment method, the last function hide it, but we have
-                 * to hide the cheque element too */
-                if ( ! GTK_WIDGET_VISIBLE (widget) )
-                    gtk_widget_hide (gsb_form_widget_get_widget (TRANSACTION_FORM_CHEQUE));
+                                        account_number, 0, FALSE );
 
                 widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_CONTRA );
                 if ( widget && GTK_WIDGET_VISIBLE ( widget ) )
                     gsb_payment_method_create_combo_list ( gsb_form_widget_get_widget (
                                         TRANSACTION_FORM_CONTRA ),
                                         GSB_PAYMENT_CREDIT,
-                                        account_number, 0 );
+                                        account_number, 0, TRUE );
             }
         }
         gsb_form_check_auto_separator ( entry );
@@ -834,12 +837,12 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
         if ( old_credit && strlen ( old_credit ) > 0 )
             old_credit = NULL;
 
-        /* we change the payment method to adapt it for the debit */
-        /* empty the credit */
+        /* save the debit if necessary */
         widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_DEBIT );
         if ( !gsb_form_widget_check_empty ( widget ) )
             old_debit = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( widget ) ) );
 
+        /* we change the payment method to adapt it for the debit */
         widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_TYPE);
 
         /* change the method of payment if necessary
@@ -851,22 +854,29 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
             /* change the signe of the method of payment and the contra */
             if ( gsb_payment_method_get_combo_sign (widget) == GSB_PAYMENT_DEBIT)
             {
-                old_debit_payment_number = gsb_payment_method_get_selected_number (
-                        widget );
+                old_debit_payment_number = gsb_payment_method_get_selected_number ( widget );
+
+                tmp_widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_CHEQUE );
+                if ( tmp_widget && GTK_WIDGET_VISIBLE ( tmp_widget ) )
+                {
+                    if ( old_debit_payment_content )
+                        g_free ( old_debit_payment_content );
+                    if ( gsb_form_widget_check_empty ( tmp_widget ) == FALSE )
+                        old_debit_payment_content = g_strdup ( gtk_entry_get_text (
+                                        GTK_ENTRY ( tmp_widget ) ) );
+                    else
+                        old_debit_payment_content = NULL;
+                }
 
                 gsb_payment_method_create_combo_list ( widget,
                                         GSB_PAYMENT_CREDIT,
-                                        account_number, 0 );
-                /* if there is no payment method, the last function hide it, but we have
-                 * to hide the cheque element too */
-                if ( !GTK_WIDGET_VISIBLE (widget))
-                    gtk_widget_hide (gsb_form_widget_get_widget (TRANSACTION_FORM_CHEQUE));
+                                        account_number, 0, FALSE );
 
                 widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_CONTRA);
                 if ( widget && GTK_WIDGET_VISIBLE ( widget ) )
                     gsb_payment_method_create_combo_list ( widget,
                                         GSB_PAYMENT_DEBIT,
-                                        account_number, 0 );
+                                        account_number, 0, TRUE );
             }
         }
         gsb_form_check_auto_separator (entry);
@@ -918,6 +928,7 @@ gboolean gsb_form_widget_amount_entry_changed ( GtkWidget *entry,
      * because it's a special style too */
     element_number = GPOINTER_TO_INT ( g_object_get_data (
                         G_OBJECT ( entry ), "element_number" ) );
+
     if ( g_strcmp0 ( gsb_form_widget_get_name ( element_number ),
      gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) == 0 )
         return FALSE;
@@ -958,39 +969,98 @@ gboolean gsb_form_widget_amount_entry_changed ( GtkWidget *entry,
  * */
 gboolean gsb_form_widget_get_valide_amout_entry ( const gchar *string )
 {
-    struct lconv *conv = localeconv ( );
-    gchar *mon_thousands_sep;
-    gunichar thousands_sep;
     const gchar *ptr;
+    gchar *mon_decimal_point;
+    gunichar decimal_point;
+    gchar *mon_thousands_sep;
+    gunichar thousands_sep = ( gunichar ) -1;
 
     ptr = string;
-    mon_thousands_sep = g_locale_to_utf8 ( conv->mon_thousands_sep,
-                        -1, NULL, NULL, NULL );
-    thousands_sep = g_utf8_get_char_validated ( mon_thousands_sep, -1 );
-    
-    while ( g_utf8_strlen (ptr, -1) > 0 )
+
+    if ( ( g_utf8_strchr ( ptr, -1, '*' ) && g_utf8_strchr ( ptr, -1, '+' ) )
+     ||
+     ( g_utf8_strchr ( ptr, -1, '*' ) && g_utf8_strchr ( ptr, -1, '-' ) ) )
+        return FALSE;
+
+    mon_decimal_point = gsb_real_get_decimal_point ( );
+    decimal_point = g_utf8_get_char_validated ( mon_decimal_point, -1 );
+    mon_thousands_sep = gsb_real_get_thousands_sep ( );
+    if ( mon_thousands_sep )
+        thousands_sep = g_utf8_get_char_validated ( mon_thousands_sep, -1 );
+
+    while ( g_utf8_strlen ( ptr, -1) > 0 )
     {
         gunichar ch;
 
-        ch = g_utf8_get_char_validated (ptr, -1);
+        ch = g_utf8_get_char_validated ( ptr, -1 );
+
         if ( !g_unichar_isdefined ( ch ) )
+        {
+            g_free ( mon_decimal_point );
+            if ( mon_thousands_sep )
+                g_free ( mon_thousands_sep );
+
             return FALSE;
+        }
+
         if ( !g_ascii_isdigit ( ch ) )
         {
             if ( g_unichar_isdefined ( thousands_sep ) )
             {
                 if ( ch != '.' && ch != ',' && ch != '+' && ch != '-'
-                 && ch != thousands_sep
-                  )
+                 && ch != '*' && ch != '/' && ch != thousands_sep )
+                {
+                    g_free ( mon_decimal_point );
+                    g_free ( mon_thousands_sep );
+
                     return FALSE;
+                }
+
+                if ( ch == decimal_point
+                 && g_utf8_strlen ( ptr, -1) == 1
+                 && g_utf8_strchr ( string, -1, thousands_sep ) )
+                {
+                    gchar **tab;
+                    guint i = 1;    /* le premier champs peut etre < à 3 */
+                    guint nbre_champs;
+
+                    tab = g_strsplit ( string, mon_thousands_sep, 0 );
+                    nbre_champs = g_strv_length ( tab );
+
+                    while ( i < nbre_champs )
+                    {
+                        if ( i < nbre_champs - 1 && g_utf8_strlen ( tab[i], -1 ) != 3 )
+                        {
+                            g_strfreev ( tab );
+                            g_free ( mon_decimal_point );
+                            g_free ( mon_thousands_sep );
+
+                            return FALSE;
+                        }
+                        else if ( i == nbre_champs - 1 && g_utf8_strlen ( tab[i], -1 ) != 4 )
+                        {
+                            g_strfreev ( tab );
+                            g_free ( mon_decimal_point );
+                            g_free ( mon_thousands_sep );
+
+                            return FALSE;
+                        }
+                        i++;
+                    }
+                    g_strfreev ( tab );
+                }
             }
-            else if ( ch != '.' && ch != ',' && ch != '+' && ch != '-' )
-                    return FALSE;
+            else if ( ch != '.' && ch != ',' && ch != '+' && ch != '-' && ch != '*' && ch != '/' )
+                return FALSE;
         }
 
-        ptr = g_utf8_next_char (ptr);
+        ptr = g_utf8_next_char ( ptr );
     }
 
+    g_free ( mon_decimal_point );
+    if ( mon_thousands_sep )
+        g_free ( mon_thousands_sep );
+
     return TRUE;
 }
 
@@ -1002,7 +1072,7 @@ gboolean gsb_form_widget_get_valide_amout_entry ( const gchar *string )
  *
  * */
 gboolean gsb_form_combo_selection_changed ( GtkTreeSelection *tree_selection,
-						  gint *ptr_origin )
+                        gint *ptr_origin )
 {
     GtkWidget *widget;
     GtkTreeModel *model;
@@ -1064,7 +1134,7 @@ gboolean gsb_form_combo_selection_changed ( GtkTreeSelection *tree_selection,
  *
  *
  * */
-gint gsb_form_widget_get_old_credit_payment ( void )
+gint gsb_form_widget_get_old_credit_payment_number ( void )
 {
     return old_credit_payment_number;
 }
@@ -1076,7 +1146,96 @@ gint gsb_form_widget_get_old_credit_payment ( void )
  *
  *
  * */
-gint gsb_form_widget_get_old_debit_payment ( void )
+gint gsb_form_widget_get_old_debit_payment_number ( void )
 {
     return old_debit_payment_number;
 }
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+const gchar *gsb_form_widget_get_old_credit_payment_content ( void )
+{
+    return old_credit_payment_content;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+const gchar *gsb_form_widget_get_old_debit_payment_content ( void )
+{
+    return old_debit_payment_content;
+}
+
+
+/**
+ * called when entry validated by Enter Tab lose focus
+ * check the entry and set the entry red/invalid if not a good number
+ *
+ * \param entry
+ *
+ * \return TRUE if entry is valid
+ * */
+gboolean gsb_form_widget_amount_entry_validate ( gint element_number )
+{
+    GtkWidget *entry;
+    const gchar *text;
+    gchar *tmp_str;
+    gchar *mon_decimal_point;
+    gboolean valide;
+    gboolean return_value;
+
+    entry = gsb_form_widget_get_widget ( element_number );
+    if ( gsb_form_widget_check_empty ( entry ) )
+        return TRUE;
+
+    text = gtk_entry_get_text ( GTK_ENTRY ( entry ) );
+    if ( g_strcmp0 ( gsb_form_widget_get_name ( element_number ), text ) == 0 )
+        return TRUE;
+
+    /* if nothing in the entry, set the widget empty */
+    if ( !strlen ( text ) )
+    {
+        gsb_form_widget_set_empty ( entry, TRUE );
+        return TRUE;
+    }
+
+    mon_decimal_point = gsb_real_get_decimal_point ( );
+    if ( g_strrstr ( text, gsb_real_get_decimal_point ( ) ) == NULL )
+        tmp_str = g_strconcat ( text, mon_decimal_point, NULL );
+    else
+        tmp_str= g_strdup ( text );
+
+    valide = gsb_form_widget_get_valide_amout_entry ( tmp_str );
+    if ( valide )
+    {
+        /* the entry is valid, make it normal */
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, NULL );
+        return_value = TRUE;
+    }
+    else
+    {
+        /* the entry is not valid, make it red */
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, &calendar_entry_color );
+        return_value = FALSE;
+    }
+
+    g_free ( tmp_str );
+    g_free ( mon_decimal_point );
+
+    return return_value;
+}
+
+
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
+
