@@ -24,29 +24,30 @@
  * \file gsb_payment_method_config.c
  * all that you need for the config of the payment method is here !!!
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_payment_method_config.h"
-#include "./dialog.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_form.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_payment_method.h"
-#include "./gsb_reconcile_sort_config.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./transaction_list.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
+#include "dialog.h"
+#include "gsb_autofunc.h"
+#include "gsb_data_account.h"
+#include "gsb_data_form.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form.h"
+#include "gsb_form_widget.h"
+#include "gsb_payment_method.h"
+#include "gsb_reconcile_sort_config.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "transaction_list.h"
+#include "structures.h"
+#include "gsb_transactions_list.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -236,7 +237,7 @@ GtkWidget *gsb_payment_method_config_create ( void )
     gtk_box_pack_start ( GTK_BOX ( details_paddingbox ), table,
 			 TRUE, TRUE, 6 );
 
-    label = gtk_label_new ( COLON(_("Name")) );
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -265,7 +266,7 @@ GtkWidget *gsb_payment_method_config_create ( void )
 
 
     /* Automatic numbering */
-    label = gtk_label_new ( COLON(_("Automatic numbering")) );
+    label = gtk_label_new ( _("Automatic numbering: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -294,7 +295,7 @@ GtkWidget *gsb_payment_method_config_create ( void )
 		       0, 0 );
 
     /* Payment method method_ptr */
-    label = gtk_label_new ( COLON(_("Type")) );
+    label = gtk_label_new ( _("Type: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -729,12 +730,12 @@ gboolean gsb_payment_method_config_name_changed ( GtkWidget *entry,
 		{
 		    gsb_payment_method_create_combo_list ( widget,
 							   GSB_PAYMENT_DEBIT,
-							   account_number, 0);
+							   account_number, 0, FALSE );
 
 		    if (GTK_WIDGET_VISIBLE (widget))
 		    {
 			gsb_payment_method_set_combobox_history ( widget,
-								  gsb_data_account_get_default_debit (account_number));
+								  gsb_data_account_get_default_debit (account_number), TRUE );
 		    }
 		    else
 		    {
@@ -1292,7 +1293,7 @@ gboolean gsb_payment_method_config_switch_payment ( gint payment_number )
     if (!gsb_payment_method_create_combo_list ( combo_box,
 						gsb_data_payment_get_sign (payment_number),
 						account_number,
-						payment_number ))
+						payment_number, FALSE ))
     {
 	dialogue_error ( _("Problem while filling the target method of payment to delete it.\nThis is not normal, please contact the grisbi team."));
 	return FALSE;
@@ -1311,7 +1312,7 @@ gboolean gsb_payment_method_config_switch_payment ( gint payment_number )
     hbox = gtk_hbox_new ( FALSE, 0 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Associate transactions with")));
+    label = gtk_label_new ( _("Associate transactions with: "));
 	gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, TRUE, TRUE, 0 );
 
