@@ -1,10 +1,8 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*                                  gsb_real                                  */
-/*                                                                            */
 /*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*                      2009 Pierre Biava (grisbi@pierre.biava.name)          */
+/*                      2009-2010 Pierre Biava (grisbi@pierre.biava.name)     */
 /*                      2009 Mickaël Remars (grisbi@remars.com)               */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
@@ -31,42 +29,32 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 #include <assert.h>
 
 /*START_INCLUDE*/
 #include "gsb_real.h"
-#include "./gsb_data_currency.h"
 /*END_INCLUDE*/
 
 gsb_real null_real = { 0 , 0 };
-gsb_real error_real = { 0x80000000, 0 };
+gsb_real error_real = { G_MININT64, 0 };
+
+static gchar *gsb_thousands_sep;
+static gchar *gsb_decimal_point;
 
 glong gsb_real_power_10[] = { 1, 10, 100, 1000, 10000, 100000,
                             1000000, 10000000, 100000000, 1000000000 };
 
-#define sizeofarray(x) (sizeof(x)/sizeof(*x))
-
 #ifdef _MSC_VER
-typedef struct _lldiv_t
-{
-	long long 	quot;
-	long long 	rem;
-} lldiv_t;
-
-lldiv_t lldiv(long long numerator, long long denominator)
-{
-	//TODO find a standard/efficient impl for this
-	lldiv_t result;
-	result.quot = numerator / denominator;
-	result.rem = numerator % denominator;
-	return result;
-}
-#define lrint(x) (floor(x + 0.5))
 #define rint(x) (floor(x + 0.5))
-#endif//_MSC_VER
+#endif /*_MSC_VER */
 
 /*START_STATIC*/
+static gchar *gsb_real_add_thousands_sep ( gchar *str_number, const gchar *thousands_sep );
 static gsb_real gsb_real_double_to_real_add_exponent ( gdouble number, gint exp_add );
 static gboolean gsb_real_grow_exponent( gsb_real *num, guint target_exponent );
 static void gsb_real_minimize_exponent ( gsb_real *num );
@@ -93,29 +81,9 @@ static gboolean gsb_real_raw_truncate_number ( gint64 *mantissa, gint *exponent
 */
 gchar *gsb_real_get_string ( gsb_real number )
 {
-    return gsb_real_format_string ( number, 0, FALSE );
-}
+    struct lconv *conv = localeconv ();
 
-/**
- * format a gsb_real into a string from gsb_real_get_string
- *	adapt the format of the real to the currency (nb digits after , ...)
- *	show if asked the currency symbol
- *
- * \param number		A number to format.
- * \param currency_number	Currency to use.
- *
- * \return a newly allocated string of the number
- * */
-gchar *gsb_real_get_string_with_currency ( gsb_real number,
-                        gint currency_number,
-                        gboolean show_symbol )
-{
-    gchar *string;
-
-    string = gsb_real_format_string (number,
-				     currency_number,
-				     show_symbol);
-    return string;
+    return gsb_real_raw_format_string ( number, conv, FALSE );
 }
 
 
@@ -135,164 +103,57 @@ gchar *gsb_real_raw_format_string (gsb_real number,
                         struct lconv *conv,
                         const gchar *currency_symbol )
 {
+    gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
     gchar format[40];
-    gchar *result = NULL;
+    gchar *result = NULL, *temp = NULL;
 	const gchar *cs_start;
     const gchar *cs_start_space;
     const gchar *sign;
     const gchar *mon_decimal_point;
     const gchar *cs_end_space;
     const gchar *cs_end;
-	ldiv_t units;
-
+    gint nbre_char;
+	lldiv_t units;
+/*printf ("currency_symbol = %s\n", currency_symbol);*/
     cs_start = (currency_symbol && conv->p_cs_precedes) ? currency_symbol : "";
     cs_start_space = (currency_symbol && conv->p_cs_precedes && conv->p_sep_by_space) ? " " : "";
     sign = (number.mantissa < 0) ? conv->negative_sign : conv->positive_sign;
-    mon_decimal_point = conv->mon_decimal_point && *conv->mon_decimal_point ? conv->mon_decimal_point : ".";
+    mon_decimal_point = gsb_decimal_point;
     cs_end_space = (currency_symbol && !conv->p_cs_precedes && conv->p_sep_by_space) ? " " : "";
     cs_end = (currency_symbol && !conv->p_cs_precedes) ? currency_symbol : "";
+    
+    units = lldiv ( llabs (number.mantissa), gsb_real_power_10[number.exponent] );
 
-    units = ldiv ( labs (number.mantissa), gsb_real_power_10[number.exponent] );
-    if ( units.quot < 1000 )
+    nbre_char = g_sprintf ( buffer, "%.0f", (gdouble) units.quot );
+
+    temp = g_strndup ( buffer, nbre_char );
+
+    if ( units.quot >= 1000 )
     {
-        g_snprintf (format, sizeof(format), "%s%d%s",
-                                           "%s%s%s%d%s%0",
-                                           number.exponent,
-                                           "d%s%s" );
-        result = g_strdup_printf ( format, 
-                        cs_start,
-                        cs_start_space,
-                        sign,
-                        units.quot,
-                        mon_decimal_point,
-                        units.rem,
-                        cs_end_space,
-                        cs_end );
+        temp = gsb_real_add_thousands_sep ( temp, gsb_thousands_sep );
     }
-    else
-    {
-        gchar *mon_thousands_sep = g_locale_to_utf8 ( conv->mon_thousands_sep, -1,
-                                                        NULL, NULL, NULL );
-        div_t thousands = div ( units.quot, 1000 );
-        if ( thousands.quot < 1000 )
-        {
-            g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                "%s%s%s%d%s%03d%s%0",
-                                                number.exponent,
-                                                "d%s%s");
-            result = g_strdup_printf ( format, 
+
+    g_snprintf ( format, sizeof ( format ), "%s%d%s",
+                                            "%s%s%s%s%s%0",
+                                            number.exponent,
+                                            "lld%s%s" );
+
+    result = g_strdup_printf ( format, 
                             cs_start,
                             cs_start_space,
                             sign,
-                            thousands.quot,
-                            mon_thousands_sep,
-                            thousands.rem,
+                            temp,
                             mon_decimal_point,
                             units.rem,
                             cs_end_space,
                             cs_end );
-        }
-        else
-        {
-            div_t millions = div ( thousands.quot, 1000 );
-            if ( millions.quot < 1000 )
-            {
-                g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                    "%s%s%s%d%s%03d%s%03d%s%0",
-                                                    number.exponent,
-                                                    "d%s%s");
-                result = g_strdup_printf ( format, 
-                                cs_start,
-                                cs_start_space,
-                                sign,
-                                millions.quot,
-                                mon_thousands_sep,
-                                millions.rem,
-                                mon_thousands_sep,
-                                thousands.rem,
-                                mon_decimal_point,
-                                units.rem,
-                                cs_end_space,
-                                cs_end);
-            }
-            else
-            {
-                div_t billions = div ( millions.quot, 1000 );
-                g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                    "%s%s%s%d%s%03d%s%03d%s%03d%s%0",
-                                                    number.exponent,
-                                                    "d%s%s" );
-                result = g_strdup_printf ( format, 
-                                cs_start,
-                                cs_start_space,
-                                sign,
-                                billions.quot,
-                                mon_thousands_sep,
-                                billions.rem,
-                                mon_thousands_sep,
-                                millions.rem,
-                                mon_thousands_sep,
-                                thousands.rem,
-                                mon_decimal_point,
-                                units.rem,
-                                cs_end_space,
-                                cs_end );
-            }
-        }
-        g_free ( mon_thousands_sep );
-    }
+
+    g_free ( temp );
+
     return result;
 }
 
 
-/**
- * Return the real in a formatted string with an optional currency
- * symbol, according to the locale regarding decimal separator,
- * thousands separator and positive or negative sign.
- * 
- * \param number		Number to format.
- * \param currency_number 	the currency we want to adapt the number, 0 for no adaptation
- * \param show_symbol 		TRUE to add the currency symbol in the string
- *
- * \return		A newly allocated string of the number (this
- *			function will never return NULL) 
- */
-gchar *gsb_real_format_string ( gsb_real number,
-                        gint currency_number,
-                        gboolean show_symbol )
-{
-    struct lconv * conv = localeconv ( );
-    gint floating_point;
-
-    const gchar *currency_symbol = (currency_number && show_symbol)
-                                   ? gsb_data_currency_get_code_or_isocode (currency_number)
-                                   : NULL;
-
-    /* First of all if number = 0 I return 0 with the symbol of the currency if necessary */
-    if (number.mantissa == 0)
-    {
-        if (currency_symbol && conv -> p_cs_precedes)
-            return g_strdup_printf ( "%s %s", currency_symbol, "0" );
-        else if (currency_symbol && ! conv -> p_cs_precedes)
-            return g_strdup_printf ( "%s %s", "0", currency_symbol );
-        else
-            return g_strdup ("0");
-    }
-    else if ( (number.exponent < 0)
-    || (number.exponent > sizeofarray ( gsb_real_power_10 ) )
-    || (number.mantissa == error_real.mantissa) )
-        return g_strdup ( "###ERR###" );
-
-    /* first we need to adapt the exponent to the currency */
-    /* if the exponent of the real is not the same of the currency, need to adapt it */
-    floating_point = gsb_data_currency_get_floating_point ( currency_number );
-    if ( currency_number && number.exponent != floating_point )
-        number = gsb_real_adjust_exponent ( number, floating_point );
-
-    return gsb_real_raw_format_string ( number, localeconv(), currency_symbol );
-}
-
-
 /**
  * get a real number from a string
  * the string can be formatted :
@@ -309,20 +170,9 @@ gchar *gsb_real_format_string ( gsb_real number,
  * */
 gsb_real gsb_real_get_from_string ( const gchar *string )
 {
-    struct lconv *conv = localeconv ( );
-    gchar *mon_thousands_sep;
-    gchar *mon_decimal_point;
     gsb_real result;
 
-    mon_thousands_sep = g_locale_to_utf8 (
-                             conv->mon_thousands_sep, -1, NULL, NULL, NULL );
-    mon_decimal_point = g_locale_to_utf8 (
-                             conv->mon_decimal_point, -1, NULL, NULL, NULL );
-
-    result =  gsb_real_raw_get_from_string ( string, mon_thousands_sep, mon_decimal_point );
-
-    g_free ( mon_thousands_sep );
-    g_free ( mon_decimal_point );
+    result =  gsb_real_raw_get_from_string ( string, gsb_thousands_sep, gsb_decimal_point );
 
     return result;
 }
@@ -336,11 +186,13 @@ gsb_real gsb_real_get_from_string ( const gchar *string )
  *
  * \return a gsb_real from the integer
  */
-gsb_real gsb_real_new ( gint mantissa, gint exponent )
+gsb_real gsb_real_new ( gint64 mantissa, gint exponent )
 {
     gsb_real number = null_real;
+
     number.mantissa = mantissa;
     number.exponent = exponent;
+
     return number;
 }
 
@@ -378,13 +230,12 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
     gint8 sign = 0;
     gint8 dot_position = -1;
     const gchar *p = string;
+    gboolean success = FALSE;
 
     if ( !string)
         return error_real;
 
-    mts_len = mon_thousands_sep
-                       ? strlen ( mon_thousands_sep )
-                       : 0;
+    mts_len = mon_thousands_sep ? strlen ( mon_thousands_sep ) : 0;
     mdp_len = mon_decimal_point ? strlen ( mon_decimal_point ) : 0;
 
     if ( mon_thousands_sep )
@@ -396,9 +247,9 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
     }
 
     decimal_chars = g_strconcat(default_decimal_char_dot,
-             default_decimal_char_comma,
-             mon_decimal_point,
-             NULL);
+                                default_decimal_char_comma,
+                                mon_decimal_point,
+                                NULL);
     space_chars = g_strconcat(" ", mon_thousands_sep, NULL);
 
     for ( ; ; )
@@ -407,55 +258,72 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
         {
             mantissa *= 10;
             mantissa += ( *p - '0' );
-            if ( mantissa > G_MAXLONG )
-                return error_real;
-            if ( sign == 0 ) sign = 1; // no sign found yet ==> positive
+            if ( mantissa > G_MAXINT64 )
+            {
+                break;
+            }
+            if ( sign == 0 ) sign = 1; /* no sign found yet ==> positive */
             ++nb_digits;
             ++p;
         }
-        else if ( *p == 0 ) // terminal zero
+        else if ( *p == 0 ) /* terminal zero */
         {
-			gsb_real result;
-			result.mantissa = sign * mantissa;
-            result.exponent = ( dot_position >= 0 )
-                              ? nb_digits - dot_position
-                              : 0;
-            return result;
+            success = TRUE;
+            break;
         }
         else if ( decimal_chars && strchr ( decimal_chars, *p ) )
         {
-            if ( dot_position >= 0 ) // already found a decimal separator
-                return error_real;
+            if ( dot_position >= 0 ) /* already found a decimal separator */
+            {
+                break;
+            }
             dot_position = nb_digits;
             p = g_utf8_find_next_char ( p, NULL );
         }
         else if ( g_utf8_strchr ( space_chars, -1,  g_utf8_get_char( p ) ) )
         {
-            // just skip spaces and thousands separators
+            /* just skip spaces and thousands separators */
             p = g_utf8_find_next_char ( p, NULL );
         }
         else if ( strchr ( negative_chars, *p ) )
         {
-            if ( sign != 0 ) // sign already set
-                return error_real;
+            if ( sign != 0 ) /* sign already set */
+            {
+                break;
+            }
             sign = -1;
             ++p;
         }
         else if ( strchr ( positive_chars, *p ) )
         {
-            if ( sign != 0 ) // sign already set
-                return error_real;
+            if ( sign != 0 ) /* sign already set */
+            {
+                break;
+            }
             sign = 1;
             ++p;
         }
-        else // unknown char ==> error
+        else /* unknown char ==> error */
         {
-            return error_real;
+            break;
         }
     }
-     /* Free memory */
-     g_free ( decimal_chars );
-     g_free ( space_chars );
+    /* Free memory */
+    g_free ( decimal_chars );
+    g_free ( space_chars );
+    if (success == TRUE)
+    {
+        gsb_real result;
+        result.mantissa = sign * mantissa;
+        result.exponent = ( dot_position >= 0 )
+                          ? nb_digits - dot_position
+                          : 0;
+        return result;
+    }
+    else
+    {
+        return error_real;
+    }
 }
 
 
@@ -472,7 +340,7 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
  *
  * \return the number in the string transformed to gsb_real
  */
-gsb_real gsb_real_import_from_string ( const gchar *string )
+gsb_real gsb_real_safe_real_from_string ( const gchar *string )
 {
     unsigned nb_digits = 0;
     gint64 mantissa = 0;
@@ -482,7 +350,7 @@ gsb_real gsb_real_import_from_string ( const gchar *string )
 
     if ( !string)
         return error_real;
-    if ( g_strstr_len ( string, -1, "###ERR###" ) )
+    if ( g_strstr_len ( string, -1, ERROR_REAL_STRING ) )
         return error_real;
 
     for ( ; ; )
@@ -491,14 +359,14 @@ gsb_real gsb_real_import_from_string ( const gchar *string )
         {
             mantissa *= 10;
             mantissa += ( *p - '0' );
-            if ( mantissa > G_MAXLONG )
+            if ( mantissa > G_MAXINT64 )
                 return error_real;
-            if ( sign == 0 ) sign = 1; // no sign found yet ==> positive
+            if ( sign == 0 ) sign = 1; /* no sign found yet ==> positive */
             ++nb_digits;
             ++p;
-            //~ printf ("mantissa = %lld nb_digits = %d\n", mantissa, nb_digits);
+            /* printf ("mantissa = %lld nb_digits = %d\n", mantissa, nb_digits); */
         }
-        else if ( *p == 0 ) // terminal zero
+        else if ( *p == 0 ) /* terminal zero */
         {
 			gsb_real result;
 			result.mantissa = sign * mantissa;
@@ -508,24 +376,24 @@ gsb_real gsb_real_import_from_string ( const gchar *string )
                 result.exponent = ( dot_position >= 0 )
                               ? nb_digits - dot_position
                               : 0;
-            //~ printf ("result.mantissa = %ld result.exponent = %d\n", result.mantissa, result.exponent);
+            /* printf ("result.mantissa = %ld result.exponent = %d\n", result.mantissa, result.exponent); */
             return result;
         }
         else if ( strchr ( ".", *p ) )
         {
-            if ( dot_position >= 0 ) // already found a decimal separator
+            if ( dot_position >= 0 ) /* already found a decimal separator */
                 return error_real;
             dot_position = nb_digits;
             p = g_utf8_find_next_char ( p, NULL );
         }
         else if ( strchr ( "-", *p ) )
         {
-            if ( sign != 0 ) // sign already set
+            if ( sign != 0 ) /* sign already set */
                 return error_real;
             sign = -1;
             ++p;
         }
-        else // unknown char ==> error
+        else /* unknown char ==> error */
         {
             return error_real;
         }
@@ -602,8 +470,10 @@ gboolean gsb_real_grow_exponent( gsb_real *num, guint target_exponent )
 
     while ( exponent < target_exponent )
     {
-        gint64 new_mantissa = mantissa * 10;
-        if ( ( new_mantissa > G_MAXLONG ) || ( new_mantissa < G_MINLONG ) )
+        gint64 new_mantissa;
+
+        new_mantissa = mantissa * 10;
+        if ( ( new_mantissa > G_MAXINT64 ) || ( new_mantissa < G_MININT64 ) )
         {
             succes = FALSE;
             break;
@@ -630,9 +500,10 @@ gboolean gsb_real_grow_exponent( gsb_real *num, guint target_exponent )
  * */
 gboolean gsb_real_normalize ( gsb_real *number_1, gsb_real *number_2 )
 {
+    gboolean safe_precision = TRUE;
+
     gsb_real_minimize_exponent ( number_1 );
     gsb_real_minimize_exponent ( number_2 );
-    gboolean safe_precision = TRUE;
 
     if ( number_1->exponent < number_2->exponent )
     {
@@ -674,7 +545,7 @@ gboolean gsb_real_normalize ( gsb_real *number_1, gsb_real *number_2 )
  * */
 gsb_real gsb_real_abs ( gsb_real number )
 {
-    number.mantissa = labs (number.mantissa);
+    number.mantissa = llabs (number.mantissa);
     return number;
 }
 
@@ -690,27 +561,46 @@ gsb_real gsb_real_abs ( gsb_real number )
 gsb_real gsb_real_adjust_exponent ( gsb_real number,
                         gint return_exponent )
 {
-    gdouble tmp;
+    gint exponent;
 
     if (return_exponent == -1)
-	return number;
+        return number;
 
-    tmp = number.mantissa;
+    if ( number.exponent == return_exponent )
+        return number;
 
-    while ( number.exponent != return_exponent )
-    {
-	if (number.exponent < return_exponent)
+/*    printf ("\nnumber.mantissa = %"G_GINT64_MODIFIER"d number.exponent = %d return_exponent = %d\n",
+                number.mantissa, number.exponent, return_exponent);
+*/
+    exponent = abs ( number.exponent - return_exponent );
+/*
+    printf ("exponent = %d gsb_real_power_10[exponent] = %ld\n", exponent, gsb_real_power_10[exponent] );
+*/
+	if ( number.exponent < return_exponent )
 	{
-	    tmp = tmp * 10;
-	    number.exponent++;
+        number.mantissa = number.mantissa * gsb_real_power_10[exponent];
+        number.exponent = return_exponent;
 	}
 	else
 	{
-	    tmp = tmp / 10;
-	    number.exponent--;
-	}
+        lldiv_t tmp_num;
+        gint sign;
+
+        sign = ( number.mantissa < 0 ) ? -1 : 1;
+
+        tmp_num = lldiv ( llabs ( number.mantissa ), gsb_real_power_10[exponent] );
+        
+        if ( tmp_num.rem > ( 0.5 * gsb_real_power_10[exponent] ) )
+            number.mantissa = ( tmp_num.quot + 1 ) * sign;
+        else
+            number.mantissa = tmp_num.quot * sign;
+
+        number.exponent = return_exponent;
     }
-    number.mantissa = lrint (tmp);
+/*
+    printf ("number.mantissa = %"G_GINT64_MODIFIER"d number.exponent = %d\n",
+                number.mantissa, number.exponent);
+*/
     return number;
 }
 
@@ -736,7 +626,7 @@ G_MODULE_EXPORT gsb_real gsb_real_add ( gsb_real number_1,
         return error_real;
 
 	mantissa = ( gint64 ) number_1.mantissa + number_2.mantissa;
-    if ( ( mantissa > G_MAXLONG ) || ( mantissa < G_MINLONG ) )
+    if ( ( mantissa > G_MAXINT64 ) || ( mantissa < G_MININT64 ) )
     {
         if ( ! gsb_real_raw_truncate_number (&mantissa, &number_1.exponent ) )
             return error_real;
@@ -801,7 +691,7 @@ gsb_real gsb_real_mul ( gsb_real number_1,
 
     gsb_real_raw_minimize_exponent ( &mantissa, &number_1.exponent );
 
-    if ( ( mantissa > G_MAXLONG ) || ( mantissa < G_MINLONG ) )
+    if ( ( mantissa > G_MAXINT64 ) || ( mantissa < G_MININT64 ) )
     {
         if ( ! gsb_real_raw_truncate_number (&mantissa, &number_1.exponent ) )
             return error_real;
@@ -824,7 +714,7 @@ gsb_real gsb_real_div ( gsb_real number_1,
                         gsb_real number_2 )
 {
     gsb_real number;
-	glong reste;
+	gint64 reste;
 	
 	if ( number_1.mantissa == error_real.mantissa ||
 	     number_2.mantissa == error_real.mantissa ||
@@ -871,8 +761,9 @@ gsb_real gsb_real_double_to_real_add_exponent ( gdouble number, gint exp_add )
     gdouble maxlong;
 	gsb_real real_number = {0, exp_add};
 
-    maxlong = G_MAXLONG / 10;
-    //~ printf ("number initial = %f exp_add = %d\n",number, exp_add);
+    maxlong = G_MAXINT64 / 10;
+/*     printf ("number initial = %f exp_add = %d\n",number, exp_add);  */
+
 	if(exp_add >=9)
 		return null_real;
 
@@ -887,19 +778,21 @@ gsb_real gsb_real_double_to_real_add_exponent ( gdouble number, gint exp_add )
             number = rint (number);
     }
 	decimal = modf ( number, &tmp_double );
-    //~ printf ("number = %f decimal = %f tmp_double = %f\n", number, decimal, tmp_double);
+/*     printf ("number = %f decimal = %f tmp_double = %f\n", number, decimal, tmp_double);  */
+
 	if ( ( ( real_number.exponent == ( 9 - exp_add ) ) ) && ( fabs ( decimal ) >= 0.5 ) )
     {
         if ( tmp_double < 0 )
-		    real_number.mantissa = ((glong) tmp_double ) - 1;
+		    real_number.mantissa = ((gint64) tmp_double ) - 1;
         else
-            real_number.mantissa = ((glong) tmp_double ) + 1;
+            real_number.mantissa = ((gint64) tmp_double ) + 1;
 
         gsb_real_minimize_exponent ( &real_number );
     }
 	else
-        real_number.mantissa = (glong) ( tmp_double );
-    //~ printf ("real_number.mantissa = %ld real_number.exponent = %d\n", real_number.mantissa,real_number.exponent); 
+        real_number.mantissa = (gint64) ( tmp_double );
+/*     printf ("real_number.mantissa = %lld real_number.exponent = %d\n", real_number.mantissa,real_number.exponent);  */
+
     return real_number;
 }
 
@@ -915,28 +808,28 @@ gboolean gsb_real_raw_truncate_number ( gint64 *mantissa, gint *exponent )
     gint64 new_mantissa = *mantissa;
     gint new_exponent = *exponent;
 
-    if ( new_mantissa > G_MAXLONG )
+    if ( new_mantissa > G_MAXINT64 )
     {
         do
         {
             --new_exponent;
             new_mantissa = new_mantissa / 10;
-        } while ( new_mantissa > G_MAXLONG );
+        } while ( new_mantissa > G_MAXINT64 );
     }
-    else if ( new_mantissa < G_MINLONG )
+    else if ( new_mantissa < G_MININT64 )
     {
         do
         {
             --new_exponent;
             new_mantissa = new_mantissa / 10;
-        } while ( new_mantissa < G_MINLONG );
+        } while ( new_mantissa < G_MININT64 );
     }
     else
     {
         return FALSE;
     }
 
-    // exponent must be greater or equal to 0
+    /* exponent must be greater or equal to 0 */
     if (new_exponent < 0)
     {
         return FALSE;
@@ -950,95 +843,26 @@ gboolean gsb_real_raw_truncate_number ( gint64 *mantissa, gint *exponent )
 }
 
 
-/* Function to transform string into gsb_real */
-gsb_real gsb_str_to_real ( const gchar * str )
-{
-	gchar *str2, **numb, **ff, **ss, *err;
-	gchar *sss, *ttt, *f, *s, *a, *b;
-	static gchar *space_chars;
-    static gchar *decimal_chars;
-	int decimals;
-	glong nombre;
-	gsb_real resu;
-	gsb_real null_real = { 0 , 0 };
-	gsb_real error_real = { 0x80000000, 0 };
-	struct lconv *loc;
-
-	loc = localeconv();
-	decimal_chars = g_locale_to_utf8 ( g_strconcat ( ".", loc->mon_decimal_point, NULL ), -1, NULL, NULL, NULL );
-	space_chars =  g_locale_to_utf8 ( g_strconcat ( " ", loc->mon_thousands_sep, NULL ), -1, NULL, NULL, NULL );
-
-	if ( !g_utf8_validate ( str, -1, NULL ) )
-		str2 = g_locale_to_utf8 ( str, -1, NULL, NULL, NULL );
-	else
-		str2 = g_strdup ( str ) ;
-
-	if(!str2 || !g_utf8_strlen( str2 , -1 ))
-		return null_real;
-	numb = g_strsplit_set(str2, decimal_chars, 2);
-	g_free(str2);
-	g_free(decimal_chars);
-	if( !numb[0] || !g_utf8_strlen( numb[0] , -1 ))
-		a = g_strdup ( "0" );
-	else
-		a = g_strdup(numb[0]);
-	if( !numb[1] || !g_utf8_strlen( numb[1], -1 ))
-		b = g_strdup ( "0" );
-	else
-		b = g_strdup(numb[1]);
-	g_strfreev(numb);
-	ff = g_strsplit_set ( a , space_chars, -1);
-	ss = g_strsplit_set ( b , space_chars, -1);
-	g_free(a);
-	g_free(b);
-	g_free(space_chars);
-	f = g_strjoinv ("", ff);
-	s = g_strjoinv ("", ss);
-	g_strfreev ( ff );
-	g_strfreev ( ss );
-	decimals = strlen(s);
-	sss = g_strconcat(f, s, NULL);
-	ttt = g_convert(sss, -1, "ASCII", "UTF8", NULL, NULL, NULL);
-	g_free(f);
-	g_free(s);
-	errno = 0;
-	nombre = strtol(ttt, &err, 10);
-	if(errno == ERANGE)
-	{
-		g_free(err);
-		g_free(sss);
-		return error_real;
-	}
-	g_free(sss);
-	if( *err != '\0' )
-	{
-		return error_real;
-	}
-	if( !nombre )
-	return null_real;
-	while( (! (nombre % 10)) )
-	{
-		nombre /= 10;
-		decimals --;
-	}
-	resu.mantissa = nombre;
-	resu.exponent = decimals;
-	return resu;
-}
-
-
-gchar *gsb_real_save_real_to_string ( gsb_real number, gint default_exponent )
+/**
+ * retourne une chaine représentative d'un nombre avec le point comme séparateur décimal
+ * et pas de separateur de milliers
+ *
+ * The returned string should be freed with g_free() when no longer needed.
+ * */
+gchar *gsb_real_safe_real_to_string ( gsb_real number, gint default_exponent )
 {
+    gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
     gchar format[40];
     gchar *result = NULL;
     const gchar *sign;
     const gchar *mon_decimal_point;
-	ldiv_t units;
+    gint nbre_char;
+    lldiv_t units;
 
-	if ( (number.exponent < 0)
-    || (number.exponent > sizeofarray ( gsb_real_power_10 ) )
+    if ( (number.exponent < 0)
+    || (number.exponent > EXPONENT_MAX )
     || (number.mantissa == error_real.mantissa) )
-      return g_strdup ( "###ERR###" );
+      return g_strdup ( ERROR_REAL_STRING );
 
     if (number.mantissa == 0)
         return g_strdup ("0.00");
@@ -1049,77 +873,178 @@ gchar *gsb_real_save_real_to_string ( gsb_real number, gint default_exponent )
     sign = (number.mantissa < 0) ? "-" : "";
     mon_decimal_point = ".";
 
-    units = ldiv ( labs (number.mantissa), gsb_real_power_10[number.exponent] );
-    if ( units.quot < 1000 )
-    {
-        g_snprintf (format, sizeof(format), "%s%d%s",
-                                           "%s%d%s%0",
-                                           number.exponent,
-                                           "d" );
-        result = g_strdup_printf ( format, 
-                        sign,
-                        units.quot,
-                        mon_decimal_point,
-                        units.rem );
-    }
-    else
-    {
-        div_t thousands = div ( units.quot, 1000 );
-        if ( thousands.quot < 1000 )
-        {
-            g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                "%s%d%03d%s%0",
-                                                number.exponent,
-                                                "d");
-            result = g_strdup_printf ( format, 
+    units = lldiv ( llabs (number.mantissa), gsb_real_power_10[number.exponent] );
+
+    nbre_char = g_sprintf ( buffer, "%.0f", (gdouble) units.quot );
+
+    result = g_strndup ( buffer, nbre_char );
+
+    g_snprintf ( format, sizeof ( format ), "%s%d%s",
+                                            "%s%s%s%0",
+                                            number.exponent,
+                                            "lld" );
+
+    result = g_strdup_printf ( format, 
                             sign,
-                            thousands.quot,
-                            thousands.rem,
+                            result,
                             mon_decimal_point,
                             units.rem );
-        }
-        else
-        {
-            div_t millions = div ( thousands.quot, 1000 );
-            if ( millions.quot < 1000 )
-            {
-                g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                    "%s%d%03d%03d%s%0",
-                                                    number.exponent,
-                                                    "d");
-                result = g_strdup_printf ( format, 
-                                sign,
-                                millions.quot,
-                                millions.rem,
-                                thousands.rem,
-                                mon_decimal_point,
-                                units.rem );
-            }
-            else
-            {
-                div_t billions = div ( millions.quot, 1000 );
-                g_snprintf ( format, sizeof (format), "%s%d%s",
-                                                    "%s%d%03d%03d%03d%s%0",
-                                                    number.exponent,
-                                                    "d" );
-                result = g_strdup_printf ( format, 
-                                sign,
-                                billions.quot,
-                                billions.rem,
-                                millions.rem,
-                                thousands.rem,
-                                mon_decimal_point,
-                                units.rem );
-            }
-        }
+
+/*     printf ("number.mantissa = %lld number.exponent = %d résultat = %s\n",
+ *                         number.mantissa, number.exponent, result );
+ */
+    return result;
+}
+
+
+gdouble gsb_real_real_to_double ( gsb_real number )
+{
+    gdouble result;
+
+    result = number.mantissa;
+
+    while ( number.exponent > 0 )
+    {
+        result /= 10;
+        number.exponent--;
     }
-    //~ printf ("number.mantissa = %ld number.exponent = %d résultat = %s\n",
-                        //~ number.mantissa, number.exponent, result );
 
     return result;
 }
 
 
+/**
+ * ajoute le séparateur des milliers passé en paramètre
+ *
+ * \param string to modify WARNING string is free
+ *
+ * \return a new allocated sring
+ * */
+gchar *gsb_real_add_thousands_sep ( gchar *str_number, const gchar *thousands_sep )
+{
+    gchar *mon_thousands_sep;
+    gchar *result = NULL;
+    gchar *ptr;
+    gchar *dest;
+    gchar *tmp_ptr;
+    gchar **tab_str = NULL;
+    gint nbre_char;
+    gint i = 0;
+    gint j = 0;
+    gint sep = 0;
+    gint longueur;
+
+    if ( thousands_sep == NULL )
+        return str_number;
+
+    nbre_char = strlen ( str_number );
+    str_number = g_strreverse ( str_number );
+    ptr = str_number;
+
+    if ( ( longueur = strlen ( thousands_sep ) ) == 1 )
+        mon_thousands_sep = g_strndup ( thousands_sep, 1 );
+    else
+        mon_thousands_sep = g_strndup ( "&", 1 );
+
+    dest = g_malloc0 ( 128 * sizeof ( gchar ) );
+    tmp_ptr = dest;
+
+    while ( i < nbre_char )
+    {
+        dest[i+sep] = ptr[0];
+
+        ptr++;
+        tmp_ptr++;
+        i++;
+        j++;
+        if ( i < nbre_char && j == 3 )
+        {
+            tmp_ptr = g_stpcpy ( tmp_ptr, mon_thousands_sep );
+            j = 0;
+            sep++;
+        }
+    };
+
+    result = g_strndup ( dest, nbre_char + sep );
+    result = g_strreverse ( result );
+
+    /* on met le bon séparateur si necessaire */
+    if ( longueur > 1 )
+    {
+        tab_str = g_strsplit ( result, "&", 0 );
+        g_free ( result );
+
+        result = g_strjoinv ( thousands_sep, tab_str );
+        g_strfreev ( tab_str );
+    }
+
+    g_free ( str_number );
+    g_free ( dest );
+
+    return result;
+}
+
+
+/**
+ *
+ * The returned string should be freed with g_free() when no longer needed.
+ *
+ *
+ * */
+gchar *gsb_real_get_decimal_point ( void )
+{
+    return g_strdup ( gsb_decimal_point );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void gsb_real_set_decimal_point ( const gchar *decimal_point )
+{
+    if ( gsb_decimal_point && strlen ( gsb_decimal_point ) )
+        g_free ( gsb_decimal_point );
+
+    if ( decimal_point == NULL )
+        gsb_decimal_point = NULL;
+    else
+		gsb_decimal_point = g_strdup ( decimal_point );
+}
+
+
+/**
+ *
+ * The returned string should be freed with g_free() when no longer needed.
+ *
+ *
+ * */
+gchar *gsb_real_get_thousands_sep ( void )
+{
+    return g_strdup ( gsb_thousands_sep );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void gsb_real_set_thousands_sep ( const gchar *thousands_sep )
+{
+    if ( gsb_thousands_sep && strlen ( gsb_thousands_sep ) )
+        g_free ( gsb_thousands_sep );
+
+    if ( thousands_sep == NULL )
+        gsb_thousands_sep = NULL;
+    else
+        gsb_thousands_sep = g_strdup ( thousands_sep );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
