@@ -26,29 +26,35 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_reconcile_config.h"
-#include "./gsb_assistant_reconcile_config.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_reconcile.h"
-#include "./utils_dates.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_transactions_list.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./dialog.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
+#include "dialog.h"
+#include "gsb_assistant_reconcile_config.h"
+#include "gsb_autofunc.h"
+#include "gsb_automem.h"
+#include "gsb_data_account.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_real.h"
+#include "gsb_transactions_list.h"
+#include "navigation.h"
+#include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_dates.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static gboolean gsb_reconcile_config_delete ( GtkWidget *button,
 				       GtkWidget *tree_view );
+static gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gpointer data );
 static gboolean gsb_reconcile_config_find_alone_transactions ( void );
 static gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection, 
 				       GtkWidget *table );
@@ -102,6 +108,17 @@ GtkWidget *gsb_reconcile_config_create ( void )
 
     vbox_pref = new_vbox_with_title_and_icon ( _("Reconciliation"),
 					       "reconciliationlg.png" );
+
+    gsb_automem_radiobutton3_new_with_title ( vbox_pref,
+                        _("Select the end date of reconciliation: "),
+                        _("Start Date + one month"),
+                        _("Today's date"),
+                        NULL,
+                        &etat.reconcile_end_date,
+                        G_CALLBACK ( gsb_reconcile_config_end_date_changed ),
+                        NULL,
+                        GTK_ORIENTATION_HORIZONTAL );
+
     paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE,
 					     _("List of reconciliations") );
 
@@ -177,7 +194,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
     gtk_box_pack_start ( GTK_BOX (hbox), table_selection, FALSE, FALSE, 0 );
 
     /* set the name */
-	label = gtk_label_new (COLON(_("Name")));
+	label = gtk_label_new ( _("Name: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 0, 1,
@@ -191,7 +208,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
 
 	/* set the initial date */
-	label = gtk_label_new (COLON(_("Initial date")));
+	label = gtk_label_new ( _("Initial date: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 1, 2,
@@ -205,7 +222,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
 
     /* set the final date */
-	label = gtk_label_new (COLON(_("Final date")));
+	label = gtk_label_new ( _("Final date: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 2, 3,
@@ -229,7 +246,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
 
 	/* set the initial balance */
-	label = gtk_label_new (COLON(_("Initial balance")));
+	label = gtk_label_new ( _("Initial balance: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 2, 3, 1, 2,
@@ -243,7 +260,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
 
     /* set the final balance */
-	label = gtk_label_new (COLON(_("Final balance")));
+	label = gtk_label_new ( _("Final balance: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 2, 3, 2, 3,
@@ -561,3 +578,24 @@ gboolean gsb_reconcile_config_find_alone_transactions ( void )
     return FALSE;
 }
 
+
+/**
+ *
+ *
+ * */
+gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gpointer data )
+{
+    etat.reconcile_end_date = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
+
+    if ( etat.modification_fichier == 0 )
+        modification_fichier ( TRUE );
+
+    return FALSE;
+}
+
+
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
