@@ -26,18 +26,20 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_reconcile_sort_config.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_payment.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./gsb_data_payment.h"
-#include "./include.h"
-#include "./structures.h"
+#include "gsb_data_account.h"
+#include "gsb_data_payment.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
