@@ -26,25 +26,28 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_scheduler.h"
-#include "./utils_dates.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form_transaction.h"
-#include "./accueil.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_transactions_list.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./gsb_scheduler_list.h"
-#include "./erreur.h"
-#include "./structures.h"
+#include "utils_dates.h"
+#include "gsb_currency.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form_transaction.h"
+#include "accueil.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_transactions_list.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "erreur.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -67,10 +70,6 @@ gint nb_days_before_scheduled;
 /** warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
 gboolean execute_scheduled_of_month;
 
-/** Take into account the planned operations in the calculation of the balances (TRUE default) */
-gboolean balances_with_scheduled;
-
-
 /**
  * set the next date in the scheduled transaction
  * if it's above the limit date, that transaction is deleted
@@ -85,10 +84,6 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 {
     GDate *new_date;
 
-    gchar* tmpstr = g_strdup_printf ("%d", scheduled_number);
-    devel_debug ( tmpstr );
-    g_free ( tmpstr );
-
     g_return_val_if_fail ( g_date_valid (gsb_data_scheduled_get_date (scheduled_number)), TRUE );
 
     /* increase the date of the scheduled_transaction */
@@ -481,8 +476,8 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
     {
 	gint last_day;
 	
-	last_day = g_date_get_days_in_month ( g_date_month (date),
-					      g_date_year (date));
+	last_day = g_date_get_days_in_month ( g_date_get_month (date),
+					      g_date_get_year (date));
 	g_date_set_day (date, last_day);
     }
 
