@@ -21,14 +21,19 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_select_icon.h"
-#include "./dialog.h"
-#include "./utils_str.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "utils_str.h"
+#include "structures.h"
+#include "utils.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -61,6 +66,17 @@ static GtkListStore *store = NULL;
 static gchar * path_icon;
 static gchar * new_icon;
 
+/* variables for account_icon */
+static GSList *list_accounts_icon = NULL;
+
+typedef struct
+{
+    gint account_number;
+    GdkPixbuf *pixbuf;
+}  struct_account_icon;
+
+static struct_account_icon *icon_buffer;
+
 
 enum { 
         PIXBUF_COLUMN,
@@ -69,6 +85,54 @@ enum {
       };
 
 
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_select_icon_init_account_variables ( void )
+{
+    if ( list_accounts_icon )
+    {
+        GSList* tmp_list = list_accounts_icon;
+
+        while ( tmp_list )
+        {
+            struct_account_icon *icon;
+
+            icon = tmp_list -> data;
+            tmp_list = tmp_list -> next;
+            if ( icon -> pixbuf )
+                g_object_unref ( icon -> pixbuf );
+
+            g_free ( icon );
+        }
+        g_slist_free ( list_accounts_icon );
+    }
+    list_accounts_icon = NULL;
+    icon_buffer = NULL;
+
+    return FALSE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_select_icon_init_logo_variables ( void )
+{
+    if ( pixbuf_logo )
+                g_object_unref ( pixbuf_logo );
+    pixbuf_logo = NULL;
+
+    return FALSE;
+}
+
+
 /**
  * crée la boite de dialogue initiale avec le  GtkIconView
  *
@@ -76,7 +140,7 @@ enum {
  *
  * \return le nouveau nom de l'icône ou NULL
  * */
-gchar * gsb_select_icon_create_window ( gchar * name_icon )
+gchar * gsb_select_icon_create_window ( gchar *name_icon )
 {
     GtkWidget *content_area;
     GtkWidget *hbox;
@@ -86,6 +150,12 @@ gchar * gsb_select_icon_create_window ( gchar * name_icon )
 	gint result;
 
     devel_debug ( name_icon );
+
+    if ( new_icon && strlen ( new_icon ) > 0 )
+        g_free ( new_icon );
+
+    new_icon = g_strdup ( name_icon );
+
     path_icon = g_path_get_dirname ( name_icon );
     dialog = gtk_dialog_new_with_buttons ( _("Browse icons"),
                             GTK_WINDOW ( window ),
@@ -127,19 +197,19 @@ gchar * gsb_select_icon_create_window ( gchar * name_icon )
 
     /* gestion des signaux */
     g_signal_connect ( G_OBJECT ( icon_view ), 
-                       "selection-changed", 
-                            G_CALLBACK( gsb_select_icon_selection_changed ), 
-                            NULL );
+                        "selection-changed", 
+                        G_CALLBACK( gsb_select_icon_selection_changed ), 
+                        NULL );
 
     g_signal_connect ( G_OBJECT ( chooser_button ), 
-                            "pressed", 
-                            G_CALLBACK(gsb_select_icon_create_file_chooser), 
-                            NULL );
+                        "clicked", 
+                        G_CALLBACK(gsb_select_icon_create_file_chooser), 
+                        NULL );
 
     g_signal_connect ( G_OBJECT( entry_text ), 
-                       "changed", 
-                            G_CALLBACK( gsb_select_icon_entry_text_changed ), 
-                            NULL );
+                        "changed", 
+                        G_CALLBACK( gsb_select_icon_entry_text_changed ), 
+                        NULL );
 
     gtk_widget_show_all ( dialog );
 
@@ -147,10 +217,10 @@ gchar * gsb_select_icon_create_window ( gchar * name_icon )
     switch (result)
     {
       case GTK_RESPONSE_ACCEPT:
-         devel_debug ( "réponse OK\n" );
+         devel_debug ( "réponse OK" );
          break;
       default:
-         devel_debug ( "réponse Non OK\n" );
+         devel_debug ( "réponse Non OK" );
          if ( new_icon && strlen ( new_icon ) > 0 )
             g_free ( new_icon );
          new_icon = NULL;
@@ -184,9 +254,9 @@ GtkWidget * gsb_select_icon_create_entry_text ( gchar * name_icon )
         devel_debug ( "combo n'existe pas" );
         store = gtk_list_store_new ( 2, G_TYPE_STRING, G_TYPE_INT );
         gtk_list_store_append (store, &iter);
-        if ( g_strcmp0 ( PIXMAPS_DIR, path_icon ) != 0 )
+        if ( g_strcmp0 ( GRISBI_PIXMAPS_DIR, path_icon ) != 0 )
         {
-            gtk_list_store_set (store, &iter, 0, PIXMAPS_DIR, -1);
+            gtk_list_store_set (store, &iter, 0, GRISBI_PIXMAPS_DIR, -1);
             gtk_list_store_prepend (store, &iter);
         }
         gtk_list_store_set (store, &iter, 0, path_icon, -1);
@@ -299,7 +369,10 @@ GtkTreePath * gsb_select_icon_fill_icon_view (  gchar * name_icon )
         g_dir_close ( dir );
     }
     else
+    {
         dialogue_error ( error -> message );
+        g_error_free ( error );
+    }
 
     if ( tree_path == NULL )
         tree_path = gtk_tree_path_new_from_string ( "0" );
@@ -384,8 +457,6 @@ void gsb_select_icon_entry_text_changed ( GtkComboBoxEntry *entry,
                             path, TRUE, 0.5, 0 );
             gtk_widget_set_sensitive (bouton_OK, FALSE );
         }
-        //~ else
-            //~ devel_debug ( "ce n'est pas un répertoire" );
     }
 }
 
@@ -455,13 +526,13 @@ gchar * gsb_select_icon_troncate_name_icon ( gchar *name_icon, gint trunc )
         n--;
         
         tmpstr = g_malloc ( size + n + 1 );
-        //~ devel_debug_int ( n );
-        //~ devel_debug ( name_icon );
+        /* devel_debug_int ( n );
+        devel_debug ( name_icon ); */
         tmpstr = g_utf8_strncpy ( tmpstr, name_icon, trunc );
         do
         {
             end = g_utf8_offset_to_pointer ( name_icon, i * trunc );
-            //~ devel_debug ( end );
+            /* devel_debug ( end ); */
             if ( i < n )
                 ptr = g_utf8_offset_to_pointer ( name_icon, ( i + 1 ) * 10 );
             if ( ptr )
@@ -543,6 +614,7 @@ gchar * gsb_select_icon_create_chaine_base64_from_pixbuf ( GdkPixbuf *pixbuf )
  *
  * \param str_base64
  *
+ * return a new pixbuf
 * */
 GdkPixbuf *gsb_select_icon_create_pixbuf_from_chaine_base64 ( gchar *str_base64 )
 {
@@ -552,29 +624,46 @@ GdkPixbuf *gsb_select_icon_create_pixbuf_from_chaine_base64 ( gchar *str_base64
     GdkPixbuf *pixbuf = NULL;
 
     data = g_base64_decode ( str_base64, &longueur );
-    gdk_pixdata_deserialize( &pixdata, longueur, data, NULL );
-    pixbuf = gdk_pixbuf_from_pixdata( &pixdata, TRUE, NULL );
+    gdk_pixdata_deserialize ( &pixdata, longueur, data, NULL );
+    pixbuf = gdk_pixbuf_from_pixdata ( &pixdata, TRUE, NULL );
+
+    g_free ( data );
 
     return pixbuf;
 }
 
 
+/**
+ *
+ *
+ *
+ *
+ * */
 GdkPixbuf *gsb_select_icon_get_logo_pixbuf ( void )
 {
     return pixbuf_logo;
 }
 
 
+/**
+ * retourne le logo par défaut de grisbi
+ *
+ *
+ * return a new pixbuf
+ * */
 GdkPixbuf *gsb_select_icon_get_default_logo_pixbuf ( void )
 {
     GdkPixbuf *pixbuf = NULL;
     GError *error = NULL;
 
     pixbuf = gdk_pixbuf_new_from_file ( g_build_filename 
-                        (PIXMAPS_DIR, "grisbi-logo.png", NULL), &error );
+                        (GRISBI_PIXMAPS_DIR, "grisbi-logo.png", NULL), &error );
 
     if ( ! pixbuf )
+    {
         devel_debug ( error -> message );
+        g_error_free ( error );
+    }
 
     if ( gdk_pixbuf_get_width (pixbuf) > LOGO_WIDTH ||
 	     gdk_pixbuf_get_height (pixbuf) > LOGO_HEIGHT )
@@ -586,6 +675,12 @@ GdkPixbuf *gsb_select_icon_get_default_logo_pixbuf ( void )
 }
 
 
+/**
+ *
+ *
+ * \param pixbuf
+ *
+ * */
 void gsb_select_icon_set_logo_pixbuf ( GdkPixbuf *pixbuf )
 {
     if ( pixbuf_logo != NULL )
@@ -601,6 +696,13 @@ void gsb_select_icon_set_logo_pixbuf ( GdkPixbuf *pixbuf )
 }
 
 
+/**
+ * redimmensionne le logo
+ *
+ * \param pixbuf à redimmensionner
+ *
+ * return a new pixbuf
+ * */
 GdkPixbuf *gsb_select_icon_resize_logo_pixbuf ( GdkPixbuf *pixbuf )
 {
     GdkPixbuf * tmp;
@@ -627,3 +729,280 @@ GdkPixbuf *gsb_select_icon_resize_logo_pixbuf ( GdkPixbuf *pixbuf )
 
     return tmp;
 }
+
+
+/**
+ * retourne la liste des icones pour les comptes
+ *
+ *
+ * return list_accounts_icon
+ * */
+GSList *gsb_select_icon_list_accounts_icon ( void )
+{
+    return list_accounts_icon;
+}
+
+
+/**
+ * find and return the number of the account which the struct account_icon is the param 
+ * 
+ * \param the struct of the account_icon
+ * 
+ * \return the number of account, -1 if pb
+ * */
+gint gsb_select_icon_get_no_account_by_ptr ( gpointer account_icon_ptr )
+{
+    struct_account_icon *icon;
+
+    if ( !account_icon_ptr )
+        return -1;
+
+    icon = account_icon_ptr;
+    icon_buffer = icon;
+
+    return  icon -> account_number;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GdkPixbuf *gsb_select_icon_get_account_pixbuf ( gint account_number )
+{
+    GSList *list_tmp;
+
+     if ( icon_buffer
+	 &&
+	 icon_buffer -> account_number == account_number )
+        return icon_buffer -> pixbuf;
+
+    list_tmp = list_accounts_icon;
+
+    while ( list_tmp )
+    {
+        struct_account_icon *icon;
+
+        icon = list_tmp -> data;
+
+        if ( icon -> account_number == account_number )
+            return icon -> pixbuf;
+
+        list_tmp = list_tmp -> next;
+    }
+
+    return NULL;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GdkPixbuf *gsb_select_icon_get_account_pixbuf_by_ptr ( gpointer account_icon_ptr )
+{
+    struct_account_icon *icon;
+
+    if ( !account_icon_ptr )
+        return NULL;
+
+    icon = account_icon_ptr;
+    icon_buffer = icon;
+
+    return  icon -> pixbuf;
+}
+
+
+/**
+ * ajoute une nouvelle icone pour le compte passé en paramètre
+ *
+ *
+ * return TRUE if OK else FALSE
+ * */
+gboolean gsb_select_icon_new_account_icon ( gint account_number,
+                        GdkPixbuf *pixbuf )
+{
+    struct_account_icon *icon;
+
+    icon = g_malloc0 ( sizeof ( struct_account_icon ) );
+    icon_buffer = icon;
+
+    if ( !icon )
+    {
+        dialogue_error_memory ();
+        return FALSE;
+    }
+
+    icon -> account_number = account_number;
+    icon -> pixbuf = pixbuf;
+
+    list_accounts_icon = g_slist_prepend ( list_accounts_icon, icon );
+
+    return TRUE;
+}
+
+/**
+ * ajoute une nouvelle icone pour le compte passé en paramètre
+ *
+ * /param la chaine codée de l'icone
+ * return TRUE if OK else FALSE
+ * */
+gboolean gsb_select_icon_new_account_icon_from_file ( gint account_number,
+                        const gchar *filename )
+{
+    struct_account_icon *icon;
+    GdkPixbuf *pixbuf;
+    GError *error = NULL;
+
+    if ( !filename || !strlen ( filename ) )
+        return FALSE;
+    else
+    {
+        if ( !g_file_test ( filename, G_FILE_TEST_EXISTS ) )
+            return FALSE;
+    }
+
+    icon = g_malloc0 ( sizeof ( struct_account_icon ) );
+    icon_buffer = icon;
+
+    if ( !icon )
+    {
+        dialogue_error_memory ();
+
+        return FALSE;
+    }
+
+    icon -> account_number = account_number;
+
+    pixbuf = gdk_pixbuf_new_from_file_at_size ( filename , 32, 32, &error );
+
+    if ( pixbuf )
+    {
+        icon -> pixbuf = pixbuf;
+        list_accounts_icon = g_slist_prepend ( list_accounts_icon, icon );
+
+        return TRUE;
+    }
+    else
+    {
+        gchar* tmp_str;
+
+        tmp_str = g_strconcat( "Erreur de pixbuf : ",
+                        error -> message, " image ",
+                        filename, NULL );
+        devel_debug ( tmp_str );
+        dialogue_error ( tmp_str );
+        g_error_free ( error );
+        g_free ( tmp_str );
+        g_free ( icon );
+
+        return FALSE;
+    }        
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GdkPixbuf *gsb_select_icon_change_account_pixbuf ( gint account_number,
+                        gchar *filename )
+{
+    GSList *list_tmp;
+    GdkPixbuf *pixbuf;
+
+    if ( icon_buffer
+	 &&
+	 icon_buffer -> account_number == account_number )
+    {
+        pixbuf = gdk_pixbuf_new_from_file_at_size ( filename , 32, 32, NULL );
+        if ( pixbuf )
+        {
+            g_object_unref ( icon_buffer -> pixbuf );
+            icon_buffer -> pixbuf = pixbuf;
+
+            return icon_buffer -> pixbuf;
+        }
+        else
+            return NULL;
+    }
+
+    list_tmp = list_accounts_icon;
+
+    while ( list_tmp )
+    {
+        struct_account_icon *icon;
+
+        icon = list_tmp -> data;
+
+        if ( icon -> account_number == account_number )
+        {
+            pixbuf = gdk_pixbuf_new_from_file_at_size ( filename , 32, 32, NULL );
+            if ( pixbuf )
+            {
+                g_object_unref ( icon -> pixbuf );
+                icon -> pixbuf = pixbuf;
+
+                return icon -> pixbuf;
+            }
+            else
+                return NULL;
+        }
+
+        list_tmp = list_tmp -> next;
+    }
+
+    if ( gsb_select_icon_new_account_icon_from_file ( account_number, filename ) )
+        return gsb_select_icon_get_account_pixbuf ( account_number );
+    else
+        return NULL;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_select_icon_remove_account_pixbuf ( gint account_number )
+{
+    GSList *list_tmp;
+
+    list_tmp = list_accounts_icon;
+
+    while ( list_tmp )
+    {
+        struct_account_icon *icon;
+
+        icon = list_tmp -> data;
+
+        if ( icon -> account_number == account_number )
+        {
+            
+            if ( icon -> pixbuf )
+            {
+                g_object_unref ( icon -> pixbuf );
+                list_tmp = g_slist_remove ( list_accounts_icon, icon );
+                g_free ( icon );
+                icon_buffer = NULL;
+
+                return TRUE;
+            }
+        }
+
+        list_tmp = list_tmp -> next;
+    }
+
+    return FALSE;
+}
+
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
