@@ -27,28 +27,29 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "gsb_transactions_list_sort.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_transaction.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./gsb_transactions_list.h"
-#include "./custom_list.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./gsb_real.h"
-#include "./erreur.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_transaction.h"
+#include "navigation.h"
+#include "gsb_real.h"
+#include "gsb_transactions_list.h"
+#include "custom_list.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -93,6 +94,10 @@ static gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_voucher ( gint transaction_number_1,
                         gint transaction_number_2 );
+static gint gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key ( gint transaction_number_1,
+                        gint transaction_number_2 );
+static gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transaction_number_1,
+                        gint transaction_number_2 );
 /*END_STATIC*/
 
 
@@ -437,14 +442,53 @@ gint gsb_transactions_list_sort_by_transaction_date_and_amount ( gint transactio
 }
 
 
+/**
+ * compared by date and by party
+ *
+ * \param none but the local variables transaction_number_1 and transaction_number_2 MUST be set
+ *
+ * \return -1 if amount_2 is above amount_number_1
+ * */
+gint gsb_transactions_list_sort_by_transaction_date_and_party ( gint transaction_number_1,
+                        gint transaction_number_2 )
+{
+    gint return_value;
+    gsb_real amount_1;
+    gsb_real amount_2;
+
+    if ( !gsb_data_transaction_get_date (transaction_number_1) )
+    {
+        return 1;
+    }
+    if ( !gsb_data_transaction_get_date (transaction_number_2) )
+    {
+        return -1;
+    }
+
+    return_value = g_date_compare ( gsb_data_transaction_get_date (transaction_number_1),
+                        gsb_data_transaction_get_date (transaction_number_2));
+
+    if ( return_value == 0 )
+    {
+        /* no difference in the dates, sort by amount of transaction */
+        amount_1 = gsb_data_transaction_get_amount ( transaction_number_1 );
+        amount_2 = gsb_data_transaction_get_amount ( transaction_number_2 );
+        return_value = gsb_transactions_list_sort_by_party ( transaction_number_1,
+                        transaction_number_2 );
+    }
+
+    return return_value;
+}
+
+
 /**
  * used to compare 2 iters and sort the by no of transaction
  * always put the white line below
- * 
+ *
  * \param model the GtkTreeModel
  * \param iter_1
  * \param iter_2
- * 
+ *
  * \return -1 if iter_1 is above iter_2
  * */
 gint gsb_transactions_list_sort_by_no ( gint transaction_number_1,
@@ -457,7 +501,7 @@ gint gsb_transactions_list_sort_by_no ( gint transaction_number_1,
 
 /**
  * used to compare 2 iters and sort the by date first, and no
- * or amount transaction after 
+ * or amount transaction after
  * always put the white line below
  * \param model the GtkTreeModel
  * \param iter_1
@@ -467,11 +511,14 @@ gint gsb_transactions_list_sort_by_no ( gint transaction_number_1,
 gint gsb_transactions_list_sort_by_date ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
-    if ( conf.transactions_list_sort_by_date == 0 )
-        return gsb_transactions_list_sort_by_transaction_date_and_no (
+    if ( conf.transactions_list_secondary_sorting == 1 )
+        return gsb_transactions_list_sort_by_transaction_date_and_amount (
+                        transaction_number_1, transaction_number_2 );
+    else if ( conf.transactions_list_secondary_sorting == 2 )
+        return gsb_transactions_list_sort_by_transaction_date_and_party (
                         transaction_number_1, transaction_number_2 );
     else
-        return gsb_transactions_list_sort_by_transaction_date_and_amount (
+        return gsb_transactions_list_sort_by_transaction_date_and_no (
                         transaction_number_1, transaction_number_2 );
 }
 
@@ -496,11 +543,11 @@ gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
     /* need to work a little more here because value date is not obligatory filled,
      * if we compare 2 transactions and 1 has no value date, set the value date before */
     value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
-    if ( ! value_date_1 && !conf.transactions_list_sort_by_value_date )
+    if ( ! value_date_1 && !conf.transactions_list_primary_sorting )
         value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
 
     value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
-    if ( ! value_date_2 && !conf.transactions_list_sort_by_value_date )
+    if ( ! value_date_2 && !conf.transactions_list_primary_sorting )
         value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
 
     if ( value_date_1 )
@@ -515,13 +562,14 @@ gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
         if (value_date_2)
             return_value = 1;
         else
-            return_value = 0;
+            return gsb_transactions_list_sort_by_date (
+                        transaction_number_1, transaction_number_2 );
     }
 
     if ( return_value )
         return return_value;
     else
-        return gsb_transactions_list_sort_by_date (
+        return gsb_transactions_list_sort_initial_by_secondary_key (
                         transaction_number_1, transaction_number_2 );
 }
 
@@ -538,36 +586,42 @@ gint gsb_transactions_list_sort_by_party ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
+    gint party_number_1;
+    gint party_number_2;
 
-    if ( gsb_data_transaction_get_party_number ( transaction_number_1)== gsb_data_transaction_get_party_number ( transaction_number_2))
-	return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+    party_number_1 = gsb_data_transaction_get_party_number ( transaction_number_1 );
+    party_number_2 = gsb_data_transaction_get_party_number ( transaction_number_2 );
+
+    if (  party_number_1 == party_number_2 )
+	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no (
+                        transaction_number_1, transaction_number_2 );
     else
     {
-	const gchar *temp_1;
-	const gchar *temp_2;
+        const gchar *temp_1;
+        const gchar *temp_2;
 
-	temp_1 = gsb_data_payee_get_name ( gsb_data_transaction_get_party_number ( transaction_number_1),
-					   TRUE );
-	temp_2 = gsb_data_payee_get_name ( gsb_data_transaction_get_party_number ( transaction_number_2),
-					   TRUE );
+        temp_1 = gsb_data_payee_get_name ( party_number_1, TRUE );
+        if ( temp_1 == NULL )
+            return -1;
 
-	/* g_utf8_collate is said not very fast, must try with big big account to check
-	 * if it's enough, for me it's ok (cedric), eventually, change with gsb_strcasecmp */
-	return_value = g_utf8_collate ( g_utf8_casefold ( temp_1 ? temp_1 : "",
-							  -1 ),
-					g_utf8_casefold ( temp_2 ? temp_2 : "",
-							  -1 ));
+        temp_2 = gsb_data_payee_get_name ( party_number_2, TRUE );
+        if ( temp_2 == NULL )
+            return 1;
+
+        /* g_utf8_collate is said not very fast, must try with big big account to check
+         * if it's enough, for me it's ok (cedric), eventually, change with gsb_strcasecmp */
+        return_value = g_utf8_collate ( g_utf8_casefold ( temp_1 ? temp_1 : "", -1 ),
+                        g_utf8_casefold ( temp_2 ? temp_2 : "", -1 ));
     }
 
     if ( return_value )
-	return return_value;
+        return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no (transaction_number_1, transaction_number_2);
+        return gsb_transactions_list_sort_by_transaction_date_and_no (
+                        transaction_number_1, transaction_number_2);
 }
 
 
-
-
 /** used to compare 2 iters and sort the by budgetary first, and 
  * by date and no transaction after
  * always put the white line below
@@ -580,40 +634,52 @@ gint gsb_transactions_list_sort_by_budget ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
+    gint budgetary_number_1;
+    gint budgetary_number_2;
+    gint sub_budgetary_number_1;
+    gint sub_budgetary_number_2;
 
-    if ( gsb_data_transaction_get_budgetary_number ( transaction_number_1) == gsb_data_transaction_get_budgetary_number ( transaction_number_2)
+    budgetary_number_1 = gsb_data_transaction_get_budgetary_number ( transaction_number_1 );
+    budgetary_number_2 = gsb_data_transaction_get_budgetary_number ( transaction_number_2 );
+    sub_budgetary_number_1 = gsb_data_transaction_get_sub_budgetary_number ( transaction_number_1 );
+    sub_budgetary_number_2 = gsb_data_transaction_get_sub_budgetary_number ( transaction_number_2 );
+
+    if ( budgetary_number_1 == budgetary_number_2
 	 &&
-	 gsb_data_transaction_get_sub_budgetary_number ( transaction_number_1)== gsb_data_transaction_get_sub_budgetary_number ( transaction_number_2))
-	return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	 sub_budgetary_number_1 == sub_budgetary_number_2 )
+	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no(
+                        transaction_number_1, transaction_number_2 );
     else
     {
-	const gchar *temp_1;
-	const gchar *temp_2;
+        const gchar *temp_1;
+        const gchar *temp_2;
 
-	temp_1 = gsb_data_budget_get_name ( gsb_data_transaction_get_budgetary_number ( transaction_number_1),
-					    gsb_data_transaction_get_sub_budgetary_number ( transaction_number_1),
-					    NULL );
-	temp_2 = gsb_data_budget_get_name ( gsb_data_transaction_get_budgetary_number ( transaction_number_2),
-					    gsb_data_transaction_get_sub_budgetary_number ( transaction_number_2),
-					    NULL);
+        temp_1 = gsb_data_budget_get_name ( budgetary_number_1,
+                            sub_budgetary_number_1,
+                            NULL );
+        if ( temp_1 == NULL )
+            return -1;
 
-	/* g_utf8_collate is said not very fast, must try with big big account to check
-	 * if it's enough, for me it's ok (cedric), eventually, change with gsb_strcasecmp */
-	return_value = g_utf8_collate ( g_utf8_casefold ( temp_1 ? temp_1 : "",
-							  -1 ),
-					g_utf8_casefold ( temp_2 ? temp_2 : "",
-							  -1 ));
+        temp_2 = gsb_data_budget_get_name ( budgetary_number_2,
+                            sub_budgetary_number_2,
+                            NULL);
+        if ( temp_2 == NULL )
+            return 1;
+
+        /* g_utf8_collate is said not very fast, must try with big big account to check
+         * if it's enough, for me it's ok (cedric), eventually, change with gsb_strcasecmp */
+        return_value = g_utf8_collate ( g_utf8_casefold ( temp_1 ? temp_1 : "", -1 ),
+                        g_utf8_casefold ( temp_2 ? temp_2 : "", -1 ) );
     }
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_transaction_date_and_no (
+                        transaction_number_1, transaction_number_2);
 }
 
 
-
-
 /**
  * used to compare 2 iters and sort the by credit amount first, and 
  * by date and no transaction after
@@ -681,13 +747,13 @@ gint gsb_transactions_list_sort_by_amount ( gint transaction_number_1,
     gint return_value;
 
     /* for the amounts, we have to check also the currency */
-    return_value = gsb_real_cmp ( gsb_data_transaction_get_adjusted_amount ( transaction_number_1, -1),
-				  gsb_data_transaction_get_adjusted_amount ( transaction_number_2, -1));
+    return_value = gsb_real_cmp ( gsb_data_transaction_get_adjusted_amount ( transaction_number_2, -1),
+				  gsb_data_transaction_get_adjusted_amount ( transaction_number_1, -1));
 
     if ( return_value )
 	return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	return gsb_transactions_list_sort_by_transaction_date_and_no (transaction_number_1, transaction_number_2);
 }
 
 
@@ -707,7 +773,7 @@ gint gsb_transactions_list_sort_by_type ( gint transaction_number_1,
 
     /* if it's the same type, we sort by the content of the types */
 
-    if ( gsb_data_transaction_get_method_of_payment_number ( transaction_number_1)== gsb_data_transaction_get_method_of_payment_number ( transaction_number_2))
+    if ( gsb_data_transaction_get_method_of_payment_number ( transaction_number_1) == gsb_data_transaction_get_method_of_payment_number ( transaction_number_2))
     {
 	return_value = g_utf8_collate ( g_utf8_casefold ( gsb_data_transaction_get_method_of_payment_content ( transaction_number_1) ? gsb_data_transaction_get_method_of_payment_content ( transaction_number_1) : "",
 							  -1 ),
@@ -1040,7 +1106,140 @@ gint gsb_transactions_list_sort_by_chq ( gint transaction_number_1,
 }
 
 
+/**
+ * Called to sort transactions by key primary and secondary key
+ *
+ * \param model
+ * \param iter_1
+ * \param iter_2
+ *
+ * \return -1 if iter_1 is above iter_2
+ * */
+gint gsb_transactions_list_sort_initial (CustomRecord **a,
+                        CustomRecord **b,
+                        CustomList *custom_list)
+{
+    gint account_number;
+    gint return_value;
+    CustomRecord *record_1 = NULL;
+    CustomRecord *record_2 = NULL;
 
+    account_number = gsb_gui_navigation_get_current_account ();
+    if (account_number == -1)
+    {
+        /* normally cannot happen, except come here at the opening
+         * of grisbi, and must return 0 if we don't want a crash */
+        return 0;
+    }   
+
+    /* i don't know why but sometimes there is a comparison between the 2 same rows... */
+    if (*a == *b)
+        return 0;
+
+    /* first of all, check the archive */
+    return_value = gsb_transactions_list_sort_check_archive ( *a, *b );
+    if (!return_value)
+    {
+        /* check the general tests (white line...) */
+        /* get the records */
+        record_1 = *a;
+        record_2 = *b;
+        return_value = gsb_transactions_list_sort_general_test ( record_1, record_2 );
+    }
+
+    if (return_value)
+    {
+        /* we have already a returned value, but for archive or general test,
+         * the pos of the row need not to change, so must keep the return_value */
+        return return_value;
+    }
+    else
+    {
+        /* get the transaction numbers */
+        gint transaction_number_1;
+        gint transaction_number_2;
+
+        transaction_number_1 = gsb_data_transaction_get_transaction_number (record_1 -> transaction_pointer);
+        transaction_number_2 = gsb_data_transaction_get_transaction_number (record_2 -> transaction_pointer);
+
+        return_value = gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key (
+                        transaction_number_1, transaction_number_2 );
+    }
+
+    return return_value;
+}
+
+
+/**
+ * used to compare 2 iters and sort the by primary key
+ *
+ * always put the white line below
+ * \param model the GtkTreeModel
+ * \param iter_1
+ * \param iter_2
+ * \return -1 if iter_1 is above iter_2
+ * */
+gint gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key ( gint transaction_number_1,
+                        gint transaction_number_2 )
+{
+    gint return_value;
+    const GDate *value_date_1;
+    const GDate *value_date_2;
+
+    /* need to work a little more here because value date is not obligatory filled,
+     * if we compare 2 transactions and 1 has no value date, set the value date before */
+    value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
+    if ( !value_date_1 )
+        value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
+
+    value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
+    if ( !value_date_2 )
+        value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
+
+    if ( value_date_1 )
+    {
+        if (value_date_2)
+            return_value = g_date_compare ( value_date_1, value_date_2);
+        else
+            return_value = -1;
+    }
+    else
+    {
+        if ( value_date_2 )
+            return_value = 1;
+        else
+            return_value = 0;
+    }
+
+    if ( return_value )
+        return return_value;
+    else
+        return gsb_transactions_list_sort_initial_by_secondary_key (
+                        transaction_number_1, transaction_number_2 );
+}
+
+
+/**
+ * used to compare 2 iters and sort the by secondary key:
+ * no or amount or payee_name
+ * always put the white line below
+ * \param model the GtkTreeModel
+ * \param iter_1
+ * \param iter_2
+ * \return -1 if iter_1 is above iter_2
+ * */
+gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transaction_number_1,
+                        gint transaction_number_2 )
+{
+    if ( conf.transactions_list_secondary_sorting == 1 )
+        return gsb_transactions_list_sort_by_amount (
+                        transaction_number_1, transaction_number_2 );
+    else if ( conf.transactions_list_secondary_sorting == 2 )
+        return gsb_transactions_list_sort_by_party (
+                        transaction_number_1, transaction_number_2 );
+    else
+        return transaction_number_1 - transaction_number_2;
+}
 
 
 /* Local Variables: */
