@@ -21,20 +21,22 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "import_csv.h"
-#include "./csv_parse.h"
-#include "./dialog.h"
-#include "./utils_dates.h"
-#include "./gsb_automem.h"
-#include "./utils_str.h"
-#include "./import.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./include.h"
-#include "./import.h"
+#include "csv_parse.h"
+#include "dialog.h"
+#include "utils_dates.h"
+#include "gsb_automem.h"
+#include "utils_str.h"
+#include "import.h"
+#include "utils.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
@@ -505,7 +507,7 @@ gint csv_skip_lines ( gchar ** contents, gint num_lines, gchar * separator )
     GSList * list;
     int i;
 
-    //~ g_print ("Skipping %d lines\n", num_lines );
+    /* g_print ("Skipping %d lines\n", num_lines ); */
 
     for ( i = 0; i < num_lines; i ++ )
     {
@@ -1079,6 +1081,7 @@ gboolean import_enter_csv_preview_page ( GtkWidget * assistant )
     if ( ! g_file_get_contents ( filename, &tmp_str, &size, &error ) )
     {
         g_print ( _("Unable to read file: %s\n"), error -> message);
+        g_error_free ( error );
         return FALSE;
     }
 
@@ -1089,6 +1092,7 @@ gboolean import_enter_csv_preview_page ( GtkWidget * assistant )
 
     if ( contents == NULL )
     {
+        g_error_free ( error );
         error = NULL;
         size = 0;
         bytes_written = 0;
@@ -1103,6 +1107,7 @@ gboolean import_enter_csv_preview_page ( GtkWidget * assistant )
         if ( bytes_written == 0 )
         {
             g_print ( _("Unable to read file: %s\n"), error -> message);
+            g_error_free ( error );
             return FALSE;
         }
     }
@@ -1173,7 +1178,7 @@ gboolean csv_import_csv_account ( GtkWidget * assistant, struct imported_file *
          * earlier. */
         if ( index < CSV_MAX_TOP_LINES && etat.csv_skipped_lines [ index ] )
         {
-            //~ g_print ("Skipping line %d\n", index );
+            /* g_print ("Skipping line %d\n", index ); */
             list = csv_get_next_line ( &contents, separator );
             index++;
             continue;
@@ -1217,19 +1222,19 @@ gboolean csv_import_csv_account ( GtkWidget * assistant, struct imported_file *
                     }
                     else if ( ! field -> parse ( ope, list -> data ) )
                     {
-                        //~ g_print ("%s", "(failed)");
+                        /* g_print ("%s", "(failed)"); */
                     }
                 }
                 else
                     {
-                    //~ g_print ("%s", "(invalid)");
+                    /* g_print ("%s", "(invalid)"); */
                     }
             }
             }
             list = list -> next;
         }
 
-        //~ g_print (">> Appending new transaction %p\n", ope );
+        /* g_print (">> Appending new transaction %p\n", ope ); */
         compte -> operations_importees = g_slist_append ( compte -> operations_importees,
                                   ope );
 
