@@ -5,9 +5,10 @@
 
 
 /* START_DECLARATION */
+GtkTreePath *budgetary_hold_position_get_path ( void );
 gboolean budgetary_hold_position_set_expand ( gboolean expand );
 gboolean budgetary_hold_position_set_path ( GtkTreePath *path );
-gboolean gsb_budget_update_combofix ( void );
+gboolean gsb_budget_update_combofix ( gboolean force );
 GtkWidget *onglet_imputations ( void );
 void remplit_arbre_imputation ( void );
 /* END_DECLARATION */
