@@ -25,53 +25,73 @@
  * we find here the configuration dialog
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "parametres.h"
-#include "./menu.h"
-#include "./utils.h"
-#include "./balance_estimate_config.h"
-#include "./dialog.h"
-#include "./gsb_archive_config.h"
-#include "./gsb_automem.h"
-#include "./gsb_bank.h"
-#include "./gsb_currency_config.h"
-#include "./gsb_currency_link_config.h"
-#include "./gsb_data_account.h"
-#include "./gsb_file.h"
-#include "./gsb_form_config.h"
-#include "./gsb_fyear_config.h"
-#include "./navigation.h"
-#include "./import.h"
-#include "./gsb_payment_method_config.h"
-#include "./gsb_reconcile_config.h"
-#include "./gsb_reconcile_sort_config.h"
-#include "./traitement_variables.h"
-#include "./utils_files.h"
-#include "./accueil.h"
-#include "./affichage_liste.h"
-#include "./affichage.h"
-#include "./tiers_onglet.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./structures.h"
-#include "./fenetre_principale.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "accueil.h"
+#include "affichage.h"
+#include "affichage_liste.h"
+#include "bet_config.h"
+#include "bet_data.h"
+#include "bet_finance_ui.h"
+#include "categories_onglet.h"
+#include "dialog.h"
+#include "fenetre_principale.h"
+#include "gsb_archive_config.h"
+#include "gsb_automem.h"
+#include "gsb_bank.h"
+#include "gsb_currency_config.h"
+#include "gsb_currency_link_config.h"
+#include "gsb_data_account.h"
+#include "gsb_file.h"
+#include "gsb_form_config.h"
+#include "gsb_fyear_config.h"
+#include "gsb_payment_method_config.h"
+#include "gsb_real.h"
+#include "gsb_reconcile_config.h"
+#include "gsb_reconcile_sort_config.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_transactions_list.h"
+#include "import.h"
+#include "imputation_budgetaire.h"
+#include "menu.h"
+#include "navigation.h"
+#include "structures.h"
+#include "tiers_onglet.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "utils.h"
+#include "utils_dates.h"
+#include "utils_files.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static GtkWidget * create_preferences_tree ( );
-static  GtkWidget *gsb_config_scheduler_page ( void );
-static gboolean gsb_config_scheduler_switch_balances_with_scheduled ( void );
+static GtkWidget *create_preferences_tree ( );
+static gboolean gsb_config_onglet_metatree_action_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur );
+static GtkWidget *gsb_config_scheduler_page ( void );
 static gboolean gsb_gui_delete_msg_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
                         GtkTreeModel * model );
 static gboolean gsb_gui_messages_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
                         GtkTreeModel * model );
+static void gsb_localisation_decimal_point_changed ( GtkComboBox *widget, gpointer user_data );
+static gboolean gsb_localisation_format_date_toggle ( GtkToggleButton *togglebutton,
+                        GdkEventButton *event,
+                        gpointer user_data);
+static void gsb_localisation_thousands_sep_changed ( GtkComboBox *widget, gpointer user_data );
+static void gsb_localisation_update_affichage ( gint type_maj );
 static GtkWidget *onglet_delete_messages ( void );
 static GtkWidget *onglet_fichier ( void );
+static GtkWidget *onglet_localisation ( void );
 static GtkWidget *onglet_messages_and_warnings ( void );
 static GtkWidget *onglet_metatree ( void );
 static GtkWidget *onglet_programmes (void);
@@ -85,6 +105,9 @@ static gboolean selectionne_liste_preference ( GtkTreeSelection *selection,
 /*END_STATIC*/
 
 
+/* global "etat" structure shared in the entire program */
+struct gsb_etat_t etat;
+
 GtkWidget *fenetre_preferences = NULL;
 
 static GtkTreeStore *preference_tree_model = NULL;
@@ -94,13 +117,17 @@ static gint width_spin_button = 50;
 
 
 /*START_EXTERN*/
-extern gboolean balances_with_scheduled;
+extern GtkWidget *account_page;
+extern GtkWidget *arbre_categ;
+extern GtkWidget *budgetary_line_tree;
 extern struct conditional_message delete_msg[];
 extern gboolean execute_scheduled_of_month;
 extern struct conditional_message messages[];
+extern gint mise_a_jour_liste_comptes_accueil;
+extern gchar *nom_fichier_comptes;
 extern gint nb_days_before_scheduled;
 extern gint nb_max_derniers_fichiers_ouverts;
-extern gchar *titre_fichier;
+extern GtkWidget *payee_tree;
 extern GtkWidget *window;
 /*END_EXTERN*/
 
@@ -230,6 +257,9 @@ gboolean preferences ( gint page )
 
     devel_debug_int (page);
 
+    if ( gsb_gui_navigation_get_current_page ( ) == - 1 )
+        return FALSE;
+
     /* Create dialog */
     fenetre_preferences = gtk_dialog_new_with_buttons (_("Grisbi preferences"),
                         GTK_WINDOW ( window ),
@@ -323,6 +353,15 @@ gboolean preferences ( gint page )
                         -1);
     gtk_notebook_append_page (preference_frame, gsb_config_scheduler_page (), NULL);
 
+    gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
+    gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
+                        &iter2,
+                        0, _("Localization"),
+                        1, LOCALISATION_PAGE,
+                        2, 400,
+                        -1);
+    gtk_notebook_append_page (preference_frame, onglet_localisation (), NULL);
+
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
     gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
                         &iter2,
@@ -527,7 +566,6 @@ gboolean preferences ( gint page )
     gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG(fenetre_preferences) -> vbox ),
                         hpaned, TRUE, TRUE, 0);
 
-#ifdef ENABLE_BALANCE_ESTIMATE 
     /* balance estimate subtree */
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter, NULL);
     gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
@@ -544,7 +582,7 @@ gboolean preferences ( gint page )
                         1, BET_GENERAL_PAGE,
                         2, 400,
                         -1);
-    gtk_notebook_append_page (preference_frame, bet_config_create_general_page (), NULL);
+    gtk_notebook_append_page (preference_frame, bet_config_general_create_general_page (), NULL);
 
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
     gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
@@ -553,9 +591,7 @@ gboolean preferences ( gint page )
                         1, BET_ACCOUNT_PAGE,
                         2, 400,
                         -1);
-    gtk_notebook_append_page (preference_frame, bet_config_create_account_page (), NULL);
-
-#endif
+    gtk_notebook_append_page (preference_frame, bet_config_account_create_account_page (), NULL);
 
     /* select the page */
     if ( page >= 0 && page < NUM_PREFERENCES_PAGES )
@@ -655,7 +691,8 @@ GtkWidget *onglet_messages_and_warnings ( void )
         GtkTreeIter iter;
 
         if ( g_utf8_collate ( messages[i].name, "account-already-opened" ) == 0 )
-            tmpstr = g_strdup_printf ( _(messages[i] . hint), titre_fichier );
+            tmpstr = g_strdup_printf ( _(messages[i] . hint),
+                        g_path_get_basename ( nom_fichier_comptes ) );
         else if ( g_utf8_collate ( messages[i].name, "development-version" ) == 0 )
             tmpstr = g_strdup_printf ( _(messages[i] . hint), VERSION );
         else if ( g_utf8_collate ( messages[i].name, "gtk_obsolete" ) == 0 )
@@ -855,7 +892,7 @@ GtkWidget *onglet_fichier ( void )
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( COLON(_("Memorise last opened files")) );
+    label = gtk_label_new ( _("Memorise last opened files: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
     button = gsb_automem_spin_button_new ( &(nb_max_derniers_fichiers_ouverts),
@@ -907,7 +944,7 @@ GtkWidget *onglet_fichier ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new ( COLON(_("Backup directory")) );
+    label = gtk_label_new ( _("Backup directory: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0);
 
     /* on passe par une fonction intermédiaire pour pallier à un bug
@@ -929,6 +966,19 @@ GtkWidget *onglet_fichier ( void )
                         dialog );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0);
 
+    /* Config file */
+#if IS_DEVELOPMENT_VERSION == 1
+    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Config file") );
+
+    hbox = gtk_hbox_new ( FALSE, 6);
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0);
+
+    button = gsb_automem_checkbutton_new (_("Use the config file of version stable as model"),
+                        &conf.stable_config_file_model,
+                        NULL, NULL);
+    gtk_box_pack_start ( GTK_BOX (hbox), button, FALSE, FALSE, 0 );
+#endif
+
     gtk_widget_show_all ( vbox_pref );
 
     if ( !gsb_data_account_get_accounts_amount () )
@@ -951,7 +1001,8 @@ gboolean gsb_gui_encryption_toggled ( GtkWidget * checkbox, gpointer data )
 {
     if ( gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (checkbox)))
     {
-    dialog_message ( "encryption-is-irreversible" );
+        dialog_message ( "encryption-is-irreversible" );
+        run.new_crypted_file = TRUE;
     }
 
     return FALSE;
@@ -1004,7 +1055,7 @@ GtkWidget *onglet_programmes (void)
     gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
     gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
 
-    label = gtk_label_new ( COLON(_("Web browser command")));
+    label = gtk_label_new ( _("Web browser command: ") );
     gtk_size_group_add_widget ( size_group, label );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
     gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 0, 1,
@@ -1031,7 +1082,7 @@ GtkWidget *onglet_programmes (void)
     gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
     gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
 
-    label = gtk_label_new ( COLON(_("LaTeX command")));
+    label = gtk_label_new ( _("LaTeX command: ") );
     gtk_size_group_add_widget ( size_group, label );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
     gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 0, 1,
@@ -1039,7 +1090,7 @@ GtkWidget *onglet_programmes (void)
     entry = gsb_automem_entry_new ( &conf.latex_command, NULL, NULL );
     gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
 
-    label = gtk_label_new ( COLON(_("dvips command")));
+    label = gtk_label_new ( _("dvips command: ") );
     gtk_size_group_add_widget ( size_group, label );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
     gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 1, 2,
@@ -1068,7 +1119,7 @@ GtkWidget *onglet_programmes (void)
  * */
 static GtkWidget *gsb_config_scheduler_page ( void )
 {
-    GtkWidget *vbox_pref, *paddingbox;
+    GtkWidget *vbox_pref;
     GtkWidget *hbox;
     GtkWidget *label;
     GtkWidget *entry;
@@ -1088,8 +1139,8 @@ static GtkWidget *gsb_config_scheduler_page ( void )
     hbox = gtk_hbox_new ( FALSE, 0);
     gtk_box_pack_start ( GTK_BOX ( vbox_pref ), hbox, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( SPACIFY ( COLON (
-                        _("Number of days before the warning or the execution"))) );
+    label = gtk_label_new (
+                        _("Number of days before the warning or the execution: ") );
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
     entry = gsb_automem_spin_button_new ( &nb_days_before_scheduled, NULL, NULL );
@@ -1097,49 +1148,10 @@ static GtkWidget *gsb_config_scheduler_page ( void )
 
     gtk_box_pack_start ( GTK_BOX (hbox), entry, FALSE, FALSE, 0 );
 
-    /* Take into account the planned operations in the calculation of balances */
-    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Calculation of balances") );
-
-    hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
-
-    button = gsb_automem_checkbutton_new (
-                        _("Take into account the scheduled operations "
-                          "in the calculation of balances"),
-                        &balances_with_scheduled,
-                        G_CALLBACK ( gsb_config_scheduler_switch_balances_with_scheduled ),
-                        NULL );
-
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
-
     return vbox_pref;
 }
 
 
-gboolean gsb_config_scheduler_switch_balances_with_scheduled ( void )
-{
-    GSList *list_tmp;
-
-    devel_debug ( NULL );
-
-    list_tmp = gsb_data_account_get_list_accounts ();
-
-    while ( list_tmp )
-    {
-        gint account_number;
-
-        account_number = gsb_data_account_get_no_account ( list_tmp -> data );
-        gsb_data_account_set_balances_are_dirty ( account_number );
-
-        /* MAJ HOME_PAGE */
-        gsb_gui_navigation_update_home_page ( );
-
-        list_tmp = list_tmp -> next;
-    }
-    return FALSE;
-}
-
-
 /**
  * create the metatree config page
  *
@@ -1160,36 +1172,86 @@ GtkWidget *onglet_metatree ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), total_currencies, FALSE, FALSE, 0 );
 
     /* tri des opérations */
-    gsb_automem_radiobutton_new_with_title ( vbox_pref,
+    gsb_automem_radiobutton3_new_with_title ( vbox_pref,
                         _("Sort option for transactions"),
                         _("by number"),
-                        _("by date"),
+                        _("by increasing date"),
+                        _("by date descending"),
                         &etat.metatree_sort_transactions,
-                        G_CALLBACK (gsb_config_metatree_sort_transactions), NULL );
+                        G_CALLBACK ( gsb_config_metatree_sort_transactions_changed ),
+                        &etat.metatree_sort_transactions,
+                        GTK_ORIENTATION_VERTICAL );
+
+    gsb_automem_radiobutton3_new_with_title ( vbox_pref,
+						_("Choice of the action for double click of the mouse: "),
+                        _("Expand the line"),
+                        _("Edit the line"),
+                        _("Manage the line"),
+					    &conf.metatree_action_2button_press,
+					    G_CALLBACK ( gsb_config_onglet_metatree_action_changed ),
+					    &conf.metatree_action_2button_press,
+                        GTK_ORIENTATION_VERTICAL );
 
     return vbox_pref;
 }
 
 
-gboolean gsb_config_metatree_sort_transactions ( GtkWidget *checkbutton,
-                        gpointer null )
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur )
 {
+    GtkTreeSelection *selection;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    GtkTreePath *path = NULL;
     gint page_number;
 
+    if ( pointeur )
+    {
+        gint value = 0;
+
+        value = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
+        *pointeur = value;
+    }
+
     page_number = gsb_gui_navigation_get_current_page ( );
 
     switch ( page_number )
     {
 	case GSB_PAYEES_PAGE:
+        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payee_tree ) );
+        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+            path = gtk_tree_model_get_path ( model, &iter );
 		payee_fill_tree ();
+        gtk_tree_path_up ( path );
+        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
+        gtk_tree_path_free ( path );
 	    break;
 
 	case GSB_CATEGORIES_PAGE:
+        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( arbre_categ ) );
+        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+            path = gtk_tree_model_get_path ( model, &iter );
         remplit_arbre_categ ();
+        gtk_tree_path_up ( path );
+        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
+        gtk_tree_path_free ( path );
 	    break;
 
 	case GSB_BUDGETARY_LINES_PAGE:
+        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( budgetary_line_tree ) );
+        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+            path = gtk_tree_model_get_path ( model, &iter );
 		remplit_arbre_imputation ();
+        gtk_tree_path_up ( path );
+        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
+        gtk_tree_path_free ( path );
 	    break;
 
 	default:
@@ -1197,8 +1259,433 @@ gboolean gsb_config_metatree_sort_transactions ( GtkWidget *checkbutton,
 	    break;
     }
 
+    if ( etat.modification_fichier == 0 )
+        modification_fichier ( TRUE );
+
     return FALSE;
 }
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GtkWidget *onglet_localisation ( void )
+{
+    GtkWidget *vbox_pref, *paddingbox;
+
+
+    vbox_pref = new_vbox_with_title_and_icon ( _("Localization"), "locale.png" );
+
+/*    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Choose Language") ); */
+
+    paddingbox = gsb_config_date_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
+
+    paddingbox = gsb_config_number_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
+
+    return vbox_pref;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens )
+{
+    GtkWidget *hbox, *paddingbox;
+    GtkWidget *button_1, *button_2;
+    gchar *format_date;
+
+    button_1 =gtk_radio_button_new_with_label ( NULL, "dd/mm/yyyy" );
+    format_date = g_strdup ( "%d/%m/%Y" );
+    g_object_set_data_full ( G_OBJECT ( button_1 ),
+                        "pointer",
+                        format_date,
+                        g_free );
+
+    button_2 = gtk_radio_button_new_with_label ( gtk_radio_button_get_group (
+                        GTK_RADIO_BUTTON ( button_1 ) ),
+						"mm/dd/yyyy" );
+    format_date = g_strdup ( "%m/%d/%Y" );
+    g_object_set_data_full ( G_OBJECT ( button_2 ),
+                        "pointer",
+                        format_date,
+                        g_free );
+
+    if ( sens == GTK_ORIENTATION_VERTICAL )
+    {
+        paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Choose the date format") );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), button_1, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), button_2, FALSE, FALSE, 0 );
+    }
+    else
+    {
+        paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Date format") );
+        hbox = gtk_hbox_new ( FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox ), button_1, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox ), button_2, FALSE, FALSE, 0 );
+    }
+
+    format_date = gsb_date_get_format_date ( );
+    if ( format_date && strcmp ( format_date, "%m/%d/%Y" ) == 0 )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_2 ), TRUE );
+    g_free ( format_date );
+
+    g_signal_connect ( G_OBJECT ( button_1 ),
+                        "button-release-event",
+                        G_CALLBACK ( gsb_localisation_format_date_toggle ),
+                        GINT_TO_POINTER ( sens ) );
+    g_signal_connect ( G_OBJECT ( button_2 ),
+                        "button-release-event",
+                        G_CALLBACK ( gsb_localisation_format_date_toggle ),
+                        GINT_TO_POINTER ( sens ) );
+
+    return paddingbox;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_localisation_format_date_toggle ( GtkToggleButton *togglebutton,
+                        GdkEventButton *event,
+                        gpointer user_data)
+{
+    const gchar *format_date;
+
+    format_date = g_object_get_data ( G_OBJECT ( togglebutton ), "pointer" );
+    gsb_date_set_format_date ( format_date );
+
+    if ( GPOINTER_TO_INT ( user_data ) == GTK_ORIENTATION_HORIZONTAL )
+        return FALSE;
+
+    gsb_localisation_update_affichage ( 0 );
+
+    return FALSE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+GtkWidget *gsb_config_number_format_chosen ( GtkWidget *parent, gint sens )
+{
+    GtkWidget *hbox, *paddingbox, *label;
+    GtkWidget *dec_hbox, *dec_sep, *thou_hbox, *thou_sep;
+    GtkSizeGroup *size_group;
+    gchar *mon_decimal_point;
+    gchar *mon_thousands_sep;
+
+    size_group = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
+
+    dec_hbox = gtk_hbox_new ( FALSE, 0 );
+    label = gtk_label_new ( _("Decimal point: ") );
+    gtk_misc_set_alignment ( GTK_MISC ( label ), MISC_LEFT, MISC_VERT_CENTER );
+    gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
+    gtk_box_pack_start ( GTK_BOX ( dec_hbox ), label, FALSE, FALSE, 0 );
+
+    dec_sep = gtk_combo_box_entry_new_text ( );
+    gtk_editable_set_editable ( GTK_EDITABLE ( GTK_BIN ( dec_sep ) -> child ), FALSE );
+    gtk_entry_set_width_chars ( GTK_ENTRY ( GTK_BIN ( dec_sep ) -> child ), 5 );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( dec_sep ), "." );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( dec_sep ), "," );
+    gtk_box_pack_start ( GTK_BOX ( dec_hbox ), dec_sep, FALSE, FALSE, 0 );
+
+    thou_hbox = gtk_hbox_new ( FALSE, 0 );
+    label = gtk_label_new (_("Thousands separator: ") );
+    gtk_misc_set_alignment ( GTK_MISC ( label ), MISC_LEFT, MISC_VERT_CENTER );
+    gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
+    gtk_box_pack_start ( GTK_BOX ( thou_hbox ), label, FALSE, FALSE, 0 );
+
+    thou_sep = gtk_combo_box_entry_new_text ( );
+    gtk_editable_set_editable ( GTK_EDITABLE ( GTK_BIN ( thou_sep ) -> child ), FALSE );
+    gtk_entry_set_width_chars ( GTK_ENTRY ( GTK_BIN ( thou_sep ) -> child ), 5 );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( thou_sep ), "' '" );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( thou_sep ), "." );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( thou_sep ), "," );
+    gtk_combo_box_append_text ( GTK_COMBO_BOX ( thou_sep ), "''" );
+
+    gtk_box_pack_start ( GTK_BOX ( thou_hbox ), thou_sep, FALSE, FALSE, 0 );
+
+    if ( sens == GTK_ORIENTATION_VERTICAL )
+    {
+        paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Choose the decimal and thousands separator") );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), dec_hbox, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), thou_hbox, FALSE, FALSE, 0 );
+    }
+    else
+    {
+        paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Decimal and thousands separator") );
+        hbox = gtk_hbox_new ( TRUE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox ), dec_hbox, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox ), thou_hbox, FALSE, FALSE, 0 );
+    }
+
+    mon_decimal_point = gsb_real_get_decimal_point ( );
+    if ( strcmp ( mon_decimal_point, "," ) == 0 )
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( dec_sep ), 1 );
+    else
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( dec_sep ), 0 );
+    g_free ( mon_decimal_point );
+
+    mon_thousands_sep = gsb_real_get_thousands_sep ( );
+    if ( mon_thousands_sep == NULL )
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( thou_sep ), 3 );
+    else if ( strcmp ( mon_thousands_sep, "." ) == 0 )
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( thou_sep ), 1 );
+    else if ( strcmp ( mon_thousands_sep, "," ) == 0 )
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( thou_sep ), 2 );
+    else
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( thou_sep ), 0 );
+
+    if ( mon_thousands_sep )
+        g_free ( mon_thousands_sep );
+
+    g_object_set_data ( G_OBJECT ( dec_sep ), "separator", thou_sep );
+    g_object_set_data ( G_OBJECT ( thou_sep ), "separator", dec_sep );
+
+    g_signal_connect ( G_OBJECT ( dec_sep ),
+                        "changed",
+                        G_CALLBACK ( gsb_localisation_decimal_point_changed ),
+                        GINT_TO_POINTER ( sens ) );
+    g_signal_connect ( G_OBJECT ( thou_sep ),
+                        "changed",
+                        G_CALLBACK ( gsb_localisation_thousands_sep_changed ),
+                        GINT_TO_POINTER ( sens ) );
+
+    return paddingbox;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void gsb_localisation_decimal_point_changed ( GtkComboBox *widget, gpointer user_data )
+{
+    GtkWidget *combo_box;
+    GtkWidget *entry;
+    gchar *str_capital;
+    const gchar *text;
+
+    text = gtk_combo_box_get_active_text ( widget );
+    combo_box = g_object_get_data ( G_OBJECT ( widget ), "separator" );
+
+    if ( g_strcmp0 ( text, "," ) == 0 )
+    {
+        gsb_real_set_decimal_point ( "," );
+
+        if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "," ) == 0 )
+        {
+            gsb_real_set_thousands_sep ( " " );
+            gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 0 );
+        }
+    }
+    else
+    {
+        gsb_real_set_decimal_point ( "." );
+        if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "." ) == 0 )
+        {
+            gsb_real_set_thousands_sep ( "," );
+            gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 2 );
+        }
+    }
+
+    /* reset capital */
+    entry = bet_finance_get_capital_entry ( );
+    str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+                    etat.bet_capital ),
+                    etat.bet_currency,
+                    FALSE );
+
+    gtk_entry_set_text ( GTK_ENTRY ( entry ), str_capital );
+    g_free ( str_capital );
+
+    if ( GPOINTER_TO_INT ( user_data ) == GTK_ORIENTATION_HORIZONTAL )
+        return;
+
+    gsb_localisation_update_affichage ( 1 );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void gsb_localisation_thousands_sep_changed ( GtkComboBox *widget, gpointer user_data )
+{
+    GtkWidget *combo_box;
+    GtkWidget *entry;
+    gchar *str_capital;
+    const gchar *text;
+
+    text = gtk_combo_box_get_active_text ( widget );
+    combo_box = g_object_get_data ( G_OBJECT ( widget ), "separator" );
+    
+    if ( g_strcmp0 ( text, "' '" ) == 0 )
+    {
+        gsb_real_set_thousands_sep ( " " );
+    }
+    else if ( g_strcmp0 ( text, "." ) == 0 )
+    {
+
+        gsb_real_set_thousands_sep ( "." );
+        if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "." ) == 0 )
+        {
+            gsb_real_set_decimal_point ( "," );
+            gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 1 );
+        }
+    }
+    else if ( g_strcmp0 ( text, "," ) == 0 )
+    {
+
+        gsb_real_set_thousands_sep ( "," );
+        if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "," ) == 0 )
+        {
+            gsb_real_set_decimal_point ( "." );
+            gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 0 );
+        }
+    }
+    else
+        gsb_real_set_thousands_sep ( NULL );
+
+    /* reset capital */
+    entry = bet_finance_get_capital_entry ( );
+    str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+                    etat.bet_capital ),
+                    etat.bet_currency,
+                    FALSE );
+
+    gtk_entry_set_text ( GTK_ENTRY ( entry ), str_capital );
+    g_free ( str_capital );
+
+    if ( GPOINTER_TO_INT ( user_data ) == GTK_ORIENTATION_HORIZONTAL )
+        return;
+
+    gsb_localisation_update_affichage ( 1 );
+}
+
+
+/**
+ * met à jour l'affichage suite à modification des données de localisation
+ *
+ *\param type_maj 0 = ELEMENT_DATE 1 =  ELEMENT_CREDIT && ELEMENT_DEBIT
+ *
+ * */
+void gsb_localisation_update_affichage ( gint type_maj )
+{
+    gint current_page;
+
+    current_page = gsb_gui_navigation_get_current_page ( );
+
+    /* update home page */
+    if ( current_page == GSB_HOME_PAGE )
+        mise_a_jour_accueil ( TRUE );
+    else
+        mise_a_jour_liste_comptes_accueil = TRUE;
+
+    /* update sheduled liste */
+    gsb_scheduler_list_fill_list ( gsb_scheduler_list_get_tree_view ( ) );
+    gsb_scheduler_list_set_background_color ( gsb_scheduler_list_get_tree_view ( ) );
+    if ( current_page == GSB_SCHEDULER_PAGE )
+        gsb_scheduler_list_select (-1);
+
+    /* update transaction liste */
+    if ( type_maj == 0 )
+    {
+        transaction_list_update_element ( ELEMENT_DATE );
+    }
+    else
+    {
+        transaction_list_update_element ( ELEMENT_CREDIT );
+        transaction_list_update_element ( ELEMENT_DEBIT );
+        gsb_transactions_list_update_tree_view ( gsb_gui_navigation_get_current_account ( ), FALSE );
+    }
+
+    /* update home page */
+    if ( current_page == GSB_ACCOUNT_PAGE )
+    {
+        gint account_number;
+        gint account_current_page;
+        kind_account kind;
+
+        account_number = gsb_gui_navigation_get_current_account ( );
+        account_current_page = gtk_notebook_get_current_page ( GTK_NOTEBOOK ( account_page ) );
+
+        kind = gsb_data_account_get_kind ( account_number );
+        switch ( kind )
+        {
+            case GSB_TYPE_BANK:
+            case GSB_TYPE_CASH:
+                if ( account_current_page == 1 || account_current_page == 2 )
+                {
+                    gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ALL );
+                    bet_data_update_bet_module ( account_number, -1 );
+                }
+                break;
+            case GSB_TYPE_LIABILITIES:
+                if ( account_current_page == 3 )
+                    bet_finance_ui_update_amortization_tab ( account_number );
+                break;
+            case GSB_TYPE_ASSET:
+                break;
+        }
+    }
+
+    /* update payees, categories and budgetary lines */
+    if ( current_page == GSB_PAYEES_PAGE )
+        payee_fill_tree ( );
+    else if ( current_page == GSB_CATEGORIES_PAGE )
+        remplit_arbre_categ ( );
+    else if ( current_page == GSB_BUDGETARY_LINES_PAGE )
+        remplit_arbre_imputation ( );
+
+    /* update simulator page */
+    if ( current_page == GSB_SIMULATOR_PAGE )
+        bet_finance_switch_simulator_page ( );
+
+}
+
+
+/**
+ *
+ *
+ * */
+gboolean gsb_config_onglet_metatree_action_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur )
+{
+    if ( pointeur )
+    {
+        gint value = 0;
+
+        value = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
+        *pointeur = value;
+        if ( etat.modification_fichier == 0 )
+            modification_fichier ( TRUE );
+    }
+
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
