@@ -10,6 +10,7 @@ enum preference_page  {
     IMPORT_ASSOCIATION_PAGE,
     SOFTWARE_PAGE,
     SCHEDULER_PAGE,
+    LOCALISATION_PAGE,
     MAIN_PAGE,
     FONTS_AND_LOGO_PAGE,
     MESSAGES_AND_WARNINGS_PAGE,
@@ -28,10 +29,8 @@ enum preference_page  {
     BANKS_PAGE,
     FINANCIAL_YEARS_PAGE,
     METHODS_OF_PAYMENT_PAGE,
-#ifdef ENABLE_BALANCE_ESTIMATE
     BET_GENERAL_PAGE,
     BET_ACCOUNT_PAGE,
-#endif
     NUM_PREFERENCES_PAGES
 };
 
@@ -42,8 +41,11 @@ enum preference_page  {
 /*START_DECLARATION*/
 gboolean gsb_config_backup_dir_chosen ( GtkWidget *button,
                         GtkWidget *dialog );
-gboolean gsb_config_metatree_sort_transactions ( GtkWidget *checkbutton,
-                        gpointer null );
+GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens );
+gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur );
+GtkWidget *gsb_config_number_format_chosen ( GtkWidget *parent, gint sens );
 gboolean gsb_gui_encryption_toggled ( GtkWidget * checkbox, gpointer data );
 gboolean gsb_preferences_menu_open ( GtkWidget *menu_item,
                         gpointer page_ptr );
