@@ -19,26 +19,26 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 #include <libxml/parser.h>
 
 /*START_INCLUDE*/
 #include "gnucash.h"
-#include "./../../dialog.h"
-#include "./../../import.h"
-#include "./../../gsb_real.h"
-#include "./../../utils_str.h"
-#include "./../../utils_files.h"
-#include "./../../gsb_data_transaction.h"
-#include "./../../include.h"
-#include "./../../erreur.h"
-#include "./../../gsb_real.h"
-#include "./../../import.h"
+#include "dialog.h"
+#include "gsb_data_transaction.h"
+#include "gsb_real.h"
+#include "import.h"
+#include "utils_str.h"
+#include "utils_files.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 /*START_STATIC*/
@@ -78,13 +78,15 @@ static struct import_format gnucash_format = {
 GSList * gnucash_accounts = NULL;
 
 
+#ifndef ENABLE_STATIC
 /** Module name. */
 G_MODULE_EXPORT const gchar plugin_name[] = "gnucash";
+#endif
 
 
 
 /** Initialization function. */
-G_MODULE_EXPORT extern void gnucash_plugin_register ()
+G_MODULE_EXPORT extern void gnucash_plugin_register ( void )
 {
     devel_debug ("Initializating gnucash plugin");
 
@@ -94,21 +96,13 @@ G_MODULE_EXPORT extern void gnucash_plugin_register ()
 
 
 /** Main function of module. */
-G_MODULE_EXPORT extern gint gnucash_plugin_run ( gchar * file_name, gchar **file_content,
-					  gboolean crypt, gulong length )
+G_MODULE_EXPORT extern gpointer gnucash_plugin_run ( void )
 {
-    return FALSE;
+    return NULL;
 }
 
 
 
-/** Release plugin  */
-G_MODULE_EXPORT extern gboolean gnucash_plugin_release ( )
-{
-    return TRUE;
-}
-
-
 /*****************************************************************/
 
 /* Structures */
@@ -616,11 +610,22 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
   }
 
   tempname = g_strdup_printf ( "gsbgnc%05d", g_random_int_range (0,99999) );
-  tempfile = utf8_fopen ( tempname, "w+x" );
+  tempfile = utf8_fopen ( tempname, "w" );
   if ( ! tempfile )
   {
-      dialogue_error_hint ( _("Grisbi needs to open a temporary file in order to import Gnucash data but file can't be created.  Check that you have permission to do that."),
-			    g_strdup_printf ( _("Error opening temporary file '%s'." ), tempname ) );
+    gchar *tmp_str;
+    gchar *tmp_str_2;
+
+    tmp_str = g_strdup ( _("Grisbi needs to open a temporary file in order to import Gnucash data "
+                        "but file can't be created.\n"
+                        "Check that you have permission to do that.") );
+    tmp_str_2 = g_strdup_printf ( _("Error opening temporary file '%s'." ), tempname );
+
+    dialogue_error_hint ( tmp_str, tmp_str_2 );
+
+    g_free ( tmp_str );
+    g_free ( tmp_str_2 );
+
       return NULL;
   }
 
@@ -665,7 +670,7 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
   doc = xmlParseFile( g_filename_from_utf8 ( tempname, -1, NULL, NULL, NULL ) );
 
   /** Once parsed, the temporary file is removed as it is useless.  */
-  unlink ( tempname );
+  g_unlink ( tempname );
   
   return doc;
 }
@@ -834,7 +839,7 @@ struct struct_ope_importation * new_transaction_from_split ( struct gnucash_spli
 
 gboolean node_strcmp ( xmlNodePtr node, gchar * name )
 {
-  return node -> name && ! strcmp ( node -> name, name );
+  return node -> name && ! strcmp ( ( gchar *) node -> name, name );
 }
 
 
