@@ -19,18 +19,20 @@
 /*                                                                            */
 /* ************************************************************************** */
 
-#include <libofx/libofx.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
+#include <libofx/libofx.h>
+
 /*START_INCLUDE*/
 #include "ofx.h"
-#include "./../../dialog.h"
-#include "./../../import.h"
-#include "./../../gsb_real.h"
-#include "./../../utils_str.h"
-#include "./../../include.h"
-#include "./../../erreur.h"
-#include "./../../import.h"
+#include "dialog.h"
+#include "gsb_real.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
@@ -46,22 +48,25 @@ static GSList * recuperation_donnees_ofx ( GtkWidget * assistant, struct importe
 /*END_STATIC*/
 
 
-static struct import_format ofx_format ={
-    "OFX", 
-    "Open Financial Exchange",	
+static struct import_format ofx_format =
+{
+    "OFX",
+    "Open Financial Exchange",
     "ofx",
     (import_function) recuperation_donnees_ofx,
 };
 
 
 
+#ifndef ENABLE_STATIC
 /** Module name. */
 G_MODULE_EXPORT const gchar plugin_name[] = "ofx";
+#endif
 
 
 
 /** Initialization function. */
-G_MODULE_EXPORT extern void ofx_plugin_register ()
+G_MODULE_EXPORT extern void ofx_plugin_register ( void )
 {
     devel_debug ("Initializating ofx plugin");
     register_import_format ( &ofx_format );
@@ -70,7 +75,7 @@ G_MODULE_EXPORT extern void ofx_plugin_register ()
 
 
 /** Main function of module. */
-G_MODULE_EXPORT extern GSList * ofx_plugin_run ( GtkWidget * assistant, 
+G_MODULE_EXPORT extern gpointer ofx_plugin_run ( GtkWidget * assistant,
 				    struct imported_file * imported )
 {
     return recuperation_donnees_ofx ( assistant, imported );
@@ -78,14 +83,6 @@ G_MODULE_EXPORT extern GSList * ofx_plugin_run ( GtkWidget * assistant,
 
 
 
-/** Release plugin  */
-G_MODULE_EXPORT extern gboolean ofx_plugin_release ( )
-{
-	return TRUE;
-}
-
-
-
 /* on doit mettre le compte en cours d'importation en global pour que
  * la libofx puisse le traiter de plus un fichier ofx peut intégrer
  * plusieurs comptes, donc on crée une liste... */
@@ -112,7 +109,7 @@ int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data);
  *
  *
  */
-GSList * recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file * imported )
+GSList *recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file * imported )
 {
     GSList *liste_tmp;
     gchar *argv[2] = { "", "" };
@@ -125,6 +122,7 @@ GSList * recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file
 
     /* 	la lib ofx ne tient pas compte du 1er argument */
     argv[1] = imported -> name;
+    devel_print_str ( imported -> name );
 
 #ifdef OFX_0_7
     ofx_context = libofx_get_new_context();
@@ -147,28 +145,31 @@ GSList * recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file
 
     if ( !compte_ofx_importation_en_cours )
     {
-	struct struct_compte_importation * account;
-	account = g_malloc0 ( sizeof ( struct struct_compte_importation ));
-	account -> nom_de_compte = unique_imported_name ( _("Invalid OFX file") );
-	account -> filename = g_strdup ( ofx_filename );
-	account -> real_filename = g_strdup (ofx_filename);
-	account -> origine = "OFX";
-	gsb_import_register_account_error ( account );
-	return ( FALSE );
+        struct struct_compte_importation * account;
+
+        account = g_malloc0 ( sizeof ( struct struct_compte_importation ));
+        account -> nom_de_compte = unique_imported_name ( _("Invalid OFX file") );
+        account -> filename = g_strdup ( ofx_filename );
+        account -> real_filename = g_strdup (ofx_filename);
+        account -> origine = "OFX";
+        gsb_import_register_account_error ( account );
+        devel_print_str ( account -> nom_de_compte );
+
+        return ( FALSE );
     }
 
     liste_tmp = liste_comptes_importes_ofx;
 
     while ( liste_tmp )
     {
-	if ( !erreur_import_ofx )
-	{
-	    gsb_import_register_account ( liste_tmp -> data );
-	}
-	else
-	{
-	    gsb_import_register_account_error ( liste_tmp -> data );
-	}
+        if ( !erreur_import_ofx )
+        {
+            gsb_import_register_account ( liste_tmp -> data );
+        }
+        else
+        {
+            gsb_import_register_account_error ( liste_tmp -> data );
+        }
 
 	liste_tmp = liste_tmp -> next;
     }
@@ -384,7 +385,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
     date = g_date_new ();
     if ( data.date_posted_valid )
     {
-	g_date_set_time ( date,
+	g_date_set_time_t ( date,
 			  data.date_posted );
 	if ( g_date_valid ( date ))
 	    ope_import -> date_de_valeur = date;
@@ -394,7 +395,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
 
     if ( data.date_initiated_valid )
     {
-	g_date_set_time ( date,
+	g_date_set_time_t ( date,
 			  data.date_initiated );
 	if ( g_date_valid ( date ))
 	    ope_import -> date = date;
@@ -411,7 +412,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
 	ope_import -> notes = latin2utf8 ( data.memo );
 
     if ( data.check_number_valid )
-	ope_import -> cheque = utils_str_atoi ( data.check_number );
+	ope_import -> cheque = latin2utf8 ( data.check_number );
 
     if ( data.amount_valid )
 	ope_import -> montant = gsb_real_double_to_real (data.amount);
@@ -535,7 +536,7 @@ int ofx_proc_statement_cb(struct OfxStatementData data)
     {
 	date = g_date_new ();
 
-	g_date_set_time ( date,
+	g_date_set_time_t ( date,
 			  data.date_start );
 	if ( g_date_valid ( date ))
 	    compte_ofx_importation_en_cours -> date_depart = date;
@@ -545,7 +546,7 @@ int ofx_proc_statement_cb(struct OfxStatementData data)
     {
 	date = g_date_new ();
 
-	g_date_set_time ( date,
+	g_date_set_time_t ( date,
 			  data.date_end );
 	if ( g_date_valid ( date ))
 	    compte_ofx_importation_en_cours -> date_fin = date;
