@@ -25,20 +25,21 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "print_report.h"
-#include "./dialog.h"
-#include "./gsb_data_print_config.h"
-#include "./utils.h"
-#include "./print_dialog_config.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "gsb_data_print_config.h"
+#include "utils.h"
+#include "print_dialog_config.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
-#if GTK_CHECK_VERSION(2,12,0)
-
 
 /*START_STATIC*/
 static GtkWidget * print_config_show_config ( GtkPrintOperation * operation,
@@ -49,15 +50,15 @@ static gboolean print_config_show_config_apply ( GtkPrintOperation * operation,
 static gboolean print_report_begin ( GtkPrintOperation *operation,
 			      GtkPrintContext *context,
 			      gpointer null );
-static  void print_report_draw_column ( GtkTableChild *child,
+static void print_report_draw_column ( GtkTableChild *child,
 				       gint line_position  );
-static  void print_report_draw_line ( GtkTableChild *child,
+static void print_report_draw_line ( GtkTableChild *child,
 				     gint line_position  );
 static gboolean print_report_draw_page ( GtkPrintOperation *operation,
 				  GtkPrintContext *context,
 				  gint page,
 				  gpointer null );
-static  void print_report_draw_row ( GtkPrintContext *context,
+static void print_report_draw_row ( GtkPrintContext *context,
 				    GtkTableChild *child,
 				    gint line_position,
 				    gint is_title );
@@ -104,7 +105,8 @@ gboolean print_report ( GtkWidget *button,
 			  G_CALLBACK (print_report_draw_page),
 			  _("Fonts"),
 			  G_CALLBACK (print_config_show_config),
-			  G_CALLBACK (print_config_show_config_apply) );
+			  G_CALLBACK (print_config_show_config_apply),
+              NULL );
     return FALSE;
 }
 
@@ -485,9 +487,6 @@ gboolean print_config_show_config_apply ( GtkPrintOperation * operation,
 
 
 
-#endif /* GTK_CHECK_VERSION(2,12,0) */
-
-
 
 /* Local Variables: */
 /* c-basic-offset: 4 */
