@@ -24,50 +24,48 @@
  * print the transactions list
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "print_transactions_list.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_automem.h"
-#include "./gsb_calendar_entry.h"
-#include "./gsb_data_print_config.h"
-#include "./gsb_data_transaction.h"
-#include "./utils.h"
-#include "./print_dialog_config.h"
-#include "./transaction_model.h"
-#include "./custom_list.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./erreur.h"
+#include "gsb_autofunc.h"
+#include "gsb_automem.h"
+#include "gsb_calendar_entry.h"
+#include "gsb_data_print_config.h"
+#include "gsb_data_transaction.h"
+#include "utils.h"
+#include "print_dialog_config.h"
+#include "transaction_model.h"
+#include "custom_list.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
-#if GTK_CHECK_VERSION(2,12,0)
-
 /*START_STATIC*/
-static gboolean print_transactions_list_apply ( GtkPrintOperation * operation,
-					 GtkWidget * widget,
-					 gpointer null );
 static gboolean print_transactions_list_begin ( GtkPrintOperation *operation,
 					 GtkPrintContext *context,
 					 gpointer null );
-static  void print_transactions_list_calculate_columns ( gdouble page_width );
-static  void print_transactions_list_draw_background ( CustomRecord *record,
+static void print_transactions_list_calculate_columns ( gdouble page_width );
+static void print_transactions_list_draw_background ( CustomRecord *record,
 						      gboolean color_bg,
 						      gint line_position );
-static  gint print_transactions_list_draw_column ( gint column_position,
+static gint print_transactions_list_draw_column ( gint column_position,
 						 gint line_position );
-static  gint print_transactions_list_draw_columns_title ( GtkPrintContext *context,
+static gint print_transactions_list_draw_columns_title ( GtkPrintContext *context,
 							 gint line_position);
-static  gint print_transactions_list_draw_line ( gint line_position );
+static gint print_transactions_list_draw_line ( gint line_position );
 static gboolean print_transactions_list_draw_page ( GtkPrintOperation *operation,
 					     GtkPrintContext *context,
 					     gint page,
 					     gpointer null );
-static  gint print_transactions_list_draw_row ( GtkPrintContext *context,
+static gint print_transactions_list_draw_row ( GtkPrintContext *context,
 					      CustomRecord *record,
 					      gint line_position );
-static  gint print_transactions_list_draw_title ( GtkPrintContext *context,
+static gint print_transactions_list_draw_title ( GtkPrintContext *context,
 						 gint line_position );
 static gboolean print_transactions_list_get_visibles_lines ( gint *number_of_archives,
 						      gint *number_of_transactions );
@@ -153,7 +151,7 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 
     entry = gsb_automem_entry_new (&title_string, NULL, NULL);
 
-    check_button = gsb_autofunc_checkbutton_new (_("Print a title : "),
+    check_button = gsb_autofunc_checkbutton_new (_("Print a title: "),
 						 gsb_data_print_config_get_draw_title (),
 						 G_CALLBACK (sens_desensitive_pointeur), entry,
 						 G_CALLBACK (gsb_data_print_config_set_draw_title), 0);
@@ -169,7 +167,7 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
     /* add the dates interval */
     hbox = gtk_hbox_new (FALSE, 10);
 
-    check_button = gsb_autofunc_checkbutton_new (_("Select dates interval : "),
+    check_button = gsb_autofunc_checkbutton_new (_("Select dates interval: "),
 						 gsb_data_print_config_get_draw_interval_dates (),
 						 G_CALLBACK (sens_desensitive_pointeur), hbox,
 						 G_CALLBACK (gsb_data_print_config_set_draw_interval_dates), 0);
@@ -206,6 +204,9 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 			final_date_entry,
 			FALSE, FALSE, 0);
 
+    g_object_set_data ( G_OBJECT ( operation ), "init_date_entry", init_date_entry );
+    g_object_set_data ( G_OBJECT ( operation ), "final_date_entry", final_date_entry );
+
     check_button = gsb_autofunc_checkbutton_new (_("Use value date"),
 						 gsb_data_print_config_get_draw_dates_are_value_dates (),
 						 NULL, NULL,
@@ -217,7 +218,6 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
     if (!gsb_data_print_config_get_draw_interval_dates ())
 	gtk_widget_set_sensitive (hbox, FALSE);
 
-
     /* set up all the checkbuttons */
     check_button = gsb_autofunc_checkbutton_new (_("Draw the lines between transactions"),
 						 gsb_data_print_config_get_draw_lines (),
@@ -341,13 +341,26 @@ gboolean print_transactions_list_apply ( GtkPrintOperation * operation,
 					 gpointer null )
 {
     GtkFontButton * font_button_transactions, * font_button_title;
+    GtkWidget *calendar;
 
-    font_button_transactions = g_object_get_data ( G_OBJECT(operation), "font_transaction_button" );
-    font_button_title = g_object_get_data ( G_OBJECT(operation), "font_title_button" );
-    
-    gsb_data_print_config_set_font_transaction ( pango_font_description_from_string ( gtk_font_button_get_font_name ( font_button_transactions ) ) );
-    gsb_data_print_config_set_font_title ( pango_font_description_from_string ( gtk_font_button_get_font_name ( font_button_title ) ) );
+    font_button_transactions = g_object_get_data ( G_OBJECT ( operation ), "font_transaction_button" );
+    font_button_title = g_object_get_data ( G_OBJECT( operation ), "font_title_button" );
     
+    gsb_data_print_config_set_font_transaction ( pango_font_description_from_string (
+                        gtk_font_button_get_font_name ( font_button_transactions ) ) );
+    gsb_data_print_config_set_font_title ( pango_font_description_from_string (
+                        gtk_font_button_get_font_name ( font_button_title ) ) );
+
+
+    if ( gsb_data_print_config_get_draw_interval_dates () )
+    {
+        calendar = g_object_get_data ( G_OBJECT(operation), "init_date_entry" );
+        draw_initial_date = gsb_calendar_entry_get_date ( calendar );
+
+        calendar = g_object_get_data ( G_OBJECT(operation), "final_date_entry" );
+        draw_final_date = gsb_calendar_entry_get_date ( calendar );
+    }
+
     return FALSE;
 }
 
@@ -368,7 +381,8 @@ gboolean print_transactions_list ( GtkWidget * button,
 			  G_CALLBACK (print_transactions_list_draw_page),
 			  _("Fonts & layout"),
 			  G_CALLBACK (print_transactions_list_layout_config),
-			  G_CALLBACK (print_transactions_list_apply) );
+			  G_CALLBACK (print_transactions_list_apply),
+              NULL );
     return FALSE;
 }
 
@@ -606,51 +620,57 @@ gboolean print_transactions_list_get_visibles_lines ( gint *number_of_archives,
 
     for (i=0 ; i<custom_list -> num_visibles_rows ; i++)
     {
-	CustomRecord *record;
+        CustomRecord *record;
 
-	record = custom_list -> visibles_rows[i];
-	switch (record -> what_is_line)
-	{
-	    case IS_ARCHIVE:
-		if (gsb_data_print_config_get_draw_archives ())
-		    archives_nb++;
-		break;
-	    case IS_TRANSACTION:
-		if (gsb_data_print_config_get_draw_interval_dates () && draw_initial_date && draw_final_date)
-		{
-		    /* we want an interval, so check the transaction */
-		    gint transaction_number;
-		    const GDate *date;
+        record = custom_list -> visibles_rows[i];
+        switch (record -> what_is_line)
+        {
+            case IS_ARCHIVE:
+            if (gsb_data_print_config_get_draw_archives ())
+                archives_nb++;
+            break;
+            case IS_TRANSACTION:
+            if ( gsb_data_print_config_get_draw_interval_dates () && draw_initial_date && draw_final_date )
+            {
+                /* we want an interval, so check the transaction */
+                gint transaction_number;
+                const GDate *date;
 
-		    transaction_number = gsb_data_transaction_get_transaction_number (record -> transaction_pointer);
-		    if (gsb_data_print_config_get_draw_dates_are_value_dates ())
-		    {
-			date = gsb_data_transaction_get_value_date (transaction_number);
+                transaction_number = gsb_data_transaction_get_transaction_number (record -> transaction_pointer);
+                if (gsb_data_print_config_get_draw_dates_are_value_dates ())
+                {
+                    date = gsb_data_transaction_get_value_date (transaction_number);
 
-			/* if no value date, get the date */
-			if (!date)
-			    date = gsb_data_transaction_get_date (transaction_number);
-		    }
-		    else
-			date = gsb_data_transaction_get_date (transaction_number);
+                    /* if no value date, get the date */
+                    if (!date)
+                        date = gsb_data_transaction_get_date (transaction_number);
+                }
+                else
+                    date = gsb_data_transaction_get_date (transaction_number);
 
-		    if (date
-			&&
-			g_date_compare (date,
-					draw_initial_date) >= 0
-			&&
-			g_date_compare (date,
-					draw_final_date) <= 0)
-			transactions_nb++;
-		}
-		else
-		    transactions_nb++;
-		break;
-	}
+                if (date
+                &&
+                g_date_compare (date,
+                        draw_initial_date) >= 0
+                &&
+                g_date_compare (date,
+                        draw_final_date) <= 0)
+                transactions_nb++;
+            }
+            else
+                transactions_nb++;
+
+            break;
+        }
     }
+
     /* before returning the value, transactions_nb is in fact the number of lines of visibles transactions,
-     * so need to divide by the number of lines for 1 transaction, and remove the white line */
-    transactions_nb = (transactions_nb - custom_list -> nb_rows_by_transaction) / custom_list -> nb_rows_by_transaction;
+     * so need to divide by the number of lines for 1 transaction, and remove the white line if necessary */
+    if ( gsb_data_print_config_get_draw_interval_dates () && draw_initial_date && draw_final_date )
+        transactions_nb = ( transactions_nb ) / custom_list -> nb_rows_by_transaction;
+    else
+        transactions_nb = (transactions_nb - custom_list -> nb_rows_by_transaction)
+                        / custom_list -> nb_rows_by_transaction;
 
     *number_of_archives = archives_nb;
     *number_of_transactions = transactions_nb;
@@ -730,7 +750,7 @@ static gint print_transactions_list_draw_columns_title ( GtkPrintContext *contex
 {
     gint column;
 
-    if (!gsb_data_print_config_get_draw_column ())
+    if (!gsb_data_print_config_get_draw_columns_name ())
 	return line_position;
 
     for (column=0 ; column<CUSTOM_MODEL_VISIBLE_COLUMNS ; column++)
@@ -908,8 +928,6 @@ static gint print_transactions_list_draw_row ( GtkPrintContext *context,
     return line_position;
 }
 
-#endif /* GTK_CHECK_VERSION(2,12,0) */
-
 
 
 /* Local Variables: */
