@@ -116,12 +116,19 @@ struct gsb_etat_t
     gint display_message_qif_export_currency;
     gint display_message_ofx_security;
 
-    /* import rules */
+    /* import files */
     gint get_extract_number_for_check;      /* TRUE if Extracting a number and save it in the field No Cheque/Virement */
     gint get_fusion_import_transactions;    /* TRUE if merge transactions imported with transactions found*/
     gint get_categorie_for_payee;           /* TRUE to automatically retrieve the category of the payee if it exists */
     gint get_fyear_by_value_date;           /* TRUE to get the fyear by value date, FALSE by date */
 
+    gchar * csv_separator;                              /** CSV separator to use while parsing a CSV file. */
+    gboolean csv_skipped_lines [ CSV_MAX_TOP_LINES ];   /* Contains a pointer to skipped lines in CSV preview. */
+
+    /* export files */
+    gint export_file_format;                /* EXPORT_QIF or EXPORT_CSV */
+    gboolean export_files_traitement;       /* 0 = traitement individuel, 1 = traitement automatique */
+
     /* combofix configuration */
     gint combofix_mixed_sort;               /* TRUE for no separation between the categories */
     gint combofix_max_item;                 /* maximum number of items we want before showing the popup */
@@ -145,9 +152,6 @@ struct gsb_etat_t
     gint last_tip; 
     gint show_tip; 
 
-    gchar * csv_separator;                              /** CSV separator to use while parsing a CSV file. */
-    gboolean csv_skipped_lines [ CSV_MAX_TOP_LINES ];   /* Contains a pointer to skipped lines in CSV preview. */
-
     /* variables pour les metatree */
     gint metatree_sort_transactions;        /* 1 = sorting by increasing date 2 = Sort by date descending */
     gint add_archive_in_total_balance;      /* Add transactions archived in the totals */
