@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*                      2009 Pierre Biava (grisbi@pierre.biava.name)          */
+/*                      2009-2011 Pierre Biava (grisbi@pierre.biava.name)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -28,38 +28,36 @@
 
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 #include "dialog.h"
 
 /*START_INCLUDE*/
 #include "tiers_onglet.h"
-#include "./dialog.h"
-#include "./metatree.h"
-#include "./gsb_assistant.h"
-#include "./gsb_automem.h"
-#include "./gsb_data_form.h"
-#include "./gsb_data_mix.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./utils_editables.h"
-#include "./gsb_form_widget.h"
-#include "./import.h"
-#include "./gsb_status.h"
-#include "./utils_str.h"
-#include "./gtk_combofix.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./utils_buttons.h"
-#include "./transaction_list.h"
-#include "./gsb_transactions_list.h"
-#include "./gtk_combofix.h"
-#include "./metatree.h"
-#include "./structures.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
-#include "./dialog.h"
-#include "./erreur.h"
+#include "metatree.h"
+#include "gsb_assistant.h"
+#include "gsb_automem.h"
+#include "gsb_data_form.h"
+#include "gsb_data_mix.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "utils_editables.h"
+#include "gsb_form_widget.h"
+#include "import.h"
+#include "gsb_status.h"
+#include "utils_str.h"
+#include "gtk_combofix.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_buttons.h"
+#include "transaction_list.h"
+#include "gsb_transactions_list.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -68,9 +66,9 @@ static void appui_sur_manage_tiers ( void );
 static GtkWidget *creation_barre_outils_tiers ( void );
 static gboolean edit_payee ( GtkTreeView * view );
 static void gsb_assistant_payees_clicked ( GtkButton *button, GtkWidget *assistant );
-static  gboolean gsb_assistant_payees_enter_page_2 ( GtkWidget *assistant );
-static  gboolean gsb_assistant_payees_enter_page_3 ( GtkWidget *assistant );
-static  gboolean gsb_assistant_payees_enter_page_finish ( GtkWidget *assistant );
+static gboolean gsb_assistant_payees_enter_page_2 ( GtkWidget *assistant );
+static gboolean gsb_assistant_payees_enter_page_3 ( GtkWidget *assistant );
+static gboolean gsb_assistant_payees_enter_page_finish ( GtkWidget *assistant );
 static void gsb_assistant_payees_entry_changed ( GtkEditable *editable,
                         GtkWidget *assistant );
 static void gsb_assistant_payees_modifie_operations ( GSList *sup_payees,
@@ -79,9 +77,9 @@ static void gsb_assistant_payees_modifie_operations ( GSList *sup_payees,
                         gboolean save_notes,
                         gboolean extract_num,
                         gboolean is_transaction );
-static  GtkWidget *gsb_assistant_payees_page_2 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_payees_page_3 ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_payees_page_finish ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_payees_page_2 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_payees_page_3 ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_payees_page_finish ( GtkWidget *assistant );
 static gboolean gsb_assistant_payees_select_func (GtkTreeModel *model,
                         GtkTreePath *path,
                         GtkTreeIter *iter,
@@ -92,6 +90,9 @@ static void gsb_assistant_payees_toggled ( GtkCellRendererToggle *cell,
 static gint gsb_assistant_payees_valide_model_recherche ( const gchar *needle );
 static gboolean payee_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * path,
                         GtkSelectionData * selection_data );
+static gboolean payee_list_button_press ( GtkWidget *tree_view,
+                        GdkEventButton *ev,
+                        gpointer null );
 static gboolean payee_remove_unused ( GtkWidget *button,
                         gpointer null );
 static void payee_tree_update_transactions ( GtkTreeModel * model,
@@ -114,6 +115,7 @@ struct metatree_hold_position *payee_hold_position;
 struct conditional_message *overwrite_payee;
 
 /*START_EXTERN*/
+extern GdkColor couleur_selection;
 extern GSList *liste_associations_tiers;
 extern MetatreeInterface * payee_interface;
 extern GtkWidget *window;
@@ -175,6 +177,10 @@ GtkWidget *onglet_tiers ( void )
 
     /* We create the gtktreeview and model early so that they can be referenced. */
     payee_tree = gtk_tree_view_new();
+
+    /* set the color of selected row */
+    gtk_widget_modify_base ( payee_tree, GTK_STATE_SELECTED, &couleur_selection );
+
     payee_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
 
     /* on y ajoute la barre d'outils */
@@ -249,10 +255,20 @@ GtkWidget *onglet_tiers ( void )
     gtk_widget_show ( payee_tree );
 
     /* Connect to signals */
-    g_signal_connect ( G_OBJECT(payee_tree), "row-expanded",
-		       G_CALLBACK(division_column_expanded), NULL );
-    g_signal_connect( G_OBJECT(payee_tree), "row-activated",
-		      G_CALLBACK(division_activated), NULL);
+    g_signal_connect ( G_OBJECT ( payee_tree ),
+                        "row-expanded",
+                        G_CALLBACK ( division_column_expanded ),
+                        NULL );
+
+    g_signal_connect ( G_OBJECT ( payee_tree ),
+                        "row-activated",
+                        G_CALLBACK ( division_activated ),
+                        NULL );
+
+    g_signal_connect ( G_OBJECT ( payee_tree ),
+                        "button-press-event",
+                        G_CALLBACK ( payee_list_button_press ),
+                        NULL );
 
     dst_iface = GTK_TREE_DRAG_DEST_GET_IFACE (payee_tree_model);
     if ( dst_iface )
@@ -314,7 +330,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 					       G_CALLBACK(appui_sur_ajout_payee),
 					       payee_tree_model );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Create a new payee")));
+				  _("Create a new payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -323,7 +339,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 					   payee_tree );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL (payee_tree_model), button, "selection" );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Delete selected payee")));
+				  _("Delete selected payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -332,7 +348,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 					   payee_tree );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL (payee_tree_model), button, "selection" );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Edit selected payee")));
+				  _("Edit selected payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     button = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
@@ -341,7 +357,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 						G_CALLBACK(popup_payee_view_mode_menu),
 						NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Change view mode")));
+				  _("Change view mode"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
 	button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
@@ -349,7 +365,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 						G_CALLBACK( appui_sur_manage_tiers ),
 						NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Manage the payees")));
+				  _("Manage the payees"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     button = gsb_automem_stock_button_new ( etat.display_toolbar,
@@ -357,7 +373,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
 					   G_CALLBACK(payee_remove_unused),
 					   NULL );
     gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  SPACIFY(_("Remove orphan payees")));
+				  _("Remove orphan payees"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     gtk_widget_show_all ( handlebox );
@@ -872,21 +888,21 @@ void appui_sur_manage_tiers ( void )
                         "check_option_2" ) ) );
 
         /* on ajoute la nouvelle association à la liste des assoc */
+        assoc = g_malloc ( sizeof ( struct struct_payee_asso ) );
+        assoc -> payee_number = new_payee_number;
+        assoc -> search_str = g_strdup ( str_cherche );
+        if ( !g_slist_find_custom ( liste_associations_tiers,
+                    assoc,
+                    (GCompareFunc) gsb_import_associations_cmp_assoc ) )
+        {
+            liste_associations_tiers = g_slist_insert_sorted (
+                    liste_associations_tiers,
+                    assoc,
+                    (GCompareFunc) gsb_import_associations_cmp_assoc );
+        }
+
         if ( nb_removed > 1 )
         {
-            assoc = g_malloc ( sizeof ( struct struct_payee_asso ) );
-            assoc -> payee_number = new_payee_number;
-            assoc -> search_str = g_strdup ( str_cherche );
-            if ( !g_slist_find_custom ( liste_associations_tiers,
-                        assoc,
-                        (GCompareFunc) gsb_import_associations_cmp_assoc ) )
-            {
-                liste_associations_tiers = g_slist_insert_sorted (
-                        liste_associations_tiers,
-                        assoc,
-                        (GCompareFunc) gsb_import_associations_cmp_assoc );
-            }
-
             tmp_list = gsb_data_transaction_get_complete_transactions_list ( );
             while ( tmp_list )
             {
@@ -996,14 +1012,12 @@ static GtkWidget *gsb_assistant_payees_page_2 ( GtkWidget *assistant )
 	g_free ( texte );
 	gtk_box_pack_start ( GTK_BOX(paddingbox), label, FALSE, FALSE, 6 );
 
-    entry = gtk_combofix_new_complex ( gsb_data_payee_get_name_and_report_list());
+    entry = gtk_combofix_new ( gsb_data_payee_get_name_and_report_list ( ) );
     gtk_combofix_set_force_text ( GTK_COMBOFIX (entry),FALSE );
     gtk_combofix_set_max_items ( GTK_COMBOFIX (entry),
                         etat.combofix_max_item );
     gtk_combofix_set_case_sensitive ( GTK_COMBOFIX (entry),
                         etat.combofix_case_sensitive );
-    //~ gtk_combofix_set_enter_function ( GTK_COMBOFIX (entry),
-					      //~ FALSE );
     gtk_box_pack_start ( GTK_BOX(paddingbox), entry, FALSE, FALSE, 6 );
     g_object_set_data ( G_OBJECT (assistant), "payee", entry );
     paddingbox = new_paddingbox_with_title ( page, TRUE, _("Enter the new payee"));
@@ -1144,7 +1158,7 @@ static GtkWidget *gsb_assistant_payees_page_3 ( GtkWidget *assistant )
 
     gtk_box_pack_start ( GTK_BOX (page), table, FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( _("Total number of payees :") );
+    label = gtk_label_new ( _("Total number of payees: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0 );
     gtk_table_attach ( GTK_TABLE ( table ), label,
 		       0, 1, 0, 1,
@@ -1161,7 +1175,7 @@ static GtkWidget *gsb_assistant_payees_page_3 ( GtkWidget *assistant )
     g_object_set_data ( G_OBJECT (assistant), "nbre_tiers_total", label );
 
     /* ajoute le nombre de tiers sélectionnés */
-    label = gtk_label_new ( _("Number of selected payees :") );
+    label = gtk_label_new ( _("Number of selected payees: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0 );
     gtk_table_attach ( GTK_TABLE ( table ), label,
 		      2, 3, 0, 1,
@@ -1647,6 +1661,61 @@ void gsb_assistant_payees_modifie_operations ( GSList *sup_payees,
         }
     }
 }
+
+
+/**
+ * called when we press a button on the list
+ *
+ * \param tree_view
+ * \param ev
+ *
+ * \return FALSE
+ * */
+gboolean payee_list_button_press ( GtkWidget *tree_view,
+                        GdkEventButton *ev,
+                        gpointer null )
+{
+    if ( ev -> type == GDK_2BUTTON_PRESS )
+    {
+        GtkTreeSelection *selection;
+        GtkTreeModel *model;
+        GtkTreeIter iter;
+        GtkTreePath *path = NULL;
+        enum meta_tree_row_type type_division;
+
+        type_division = metatree_get_row_type_from_tree_view ( tree_view );
+        if ( type_division == META_TREE_TRANSACTION )
+            return FALSE;
+
+        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
+        if ( selection && gtk_tree_selection_get_selected (selection, &model, &iter ) )
+            path = gtk_tree_model_get_path  ( model, &iter);
+
+        if ( conf.metatree_action_2button_press == 1 )
+        {
+            edit_payee ( GTK_TREE_VIEW ( tree_view ) );
+
+            gtk_tree_path_free ( path );
+            return TRUE;
+        }
+        else
+        {
+            if ( gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
+                gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
+            else
+                gtk_tree_view_expand_row ( GTK_TREE_VIEW ( tree_view ), path, FALSE );
+
+            gtk_tree_path_free ( path );
+            return FALSE;
+        }
+
+        return TRUE;
+    }
+    else
+        return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
