@@ -30,39 +30,40 @@
  * Grisbi shouldn't work directly on the CustomList except by those files
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "transaction_list.h"
-#include "./custom_list.h"
-#include "./dialog.h"
-#include "./affichage_liste.h"
-#include "./gsb_transactions_list.h"
-#include "./utils_dates.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_transaction.h"
-#include "./navigation.h"
-#include "./gsb_real.h"
-#include "./transaction_list_select.h"
-#include "./transaction_list_sort.h"
-#include "./transaction_model.h"
-#include "./custom_list.h"
-#include "./gsb_transactions_list.h"
-#include "./gsb_data_transaction.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./erreur.h"
-#include "./gsb_real.h"
+#include "affichage_liste.h"
+#include "custom_list.h"
+#include "dialog.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_transaction.h"
+#include "gsb_real.h"
+#include "gsb_transactions_list.h"
+#include "gsb_transactions_list_sort.h"
+#include "navigation.h"
+#include "structures.h"
+#include "transaction_list_select.h"
+#include "transaction_list_sort.h"
+#include "transaction_model.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  void transaction_list_append_child ( gint transaction_number );
-static  CustomRecord *transaction_list_create_record ( gint transaction_number,
+static void transaction_list_append_child ( gint transaction_number );
+static CustomRecord *transaction_list_create_record ( gint transaction_number,
                         gint line_in_transaction );
-static  gboolean transaction_list_update_white_child ( CustomRecord *white_record );
+static gboolean transaction_list_update_white_child ( CustomRecord *white_record );
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -139,7 +140,7 @@ void transaction_list_append_transaction ( gint transaction_number )
     }
 
     /* the transaction is a mother */
-    account_number = gsb_data_transaction_get_account_number ( transaction_number );
+    account_number = gsb_gui_navigation_get_current_account ( );
 
     /* if the transaction is a split, create a white line, we will append it later */
     if ( gsb_data_transaction_get_split_of_transaction ( transaction_number ) )
@@ -216,7 +217,7 @@ void transaction_list_append_transaction ( gint transaction_number )
 	/* we check if the row is visible or not only if we are on an account,
 	 * in other case, the model will be filtered when change account so no need
 	 * to do that here */
-	if ( gsb_gui_navigation_get_current_account ( ) != -1
+	if ( account_number != -1
 	    &&
 	    gsb_transactions_list_transaction_visible ( newrecord[i] -> transaction_pointer,
 							account_number,
@@ -300,10 +301,12 @@ void transaction_list_append_archive (gint archive_store_number)
     gint amount_col;
     CustomList *custom_list;
     gint col_archive;
+    gint element_date = 0;
 
     custom_list = transaction_model_get_model ();
 
-    g_return_if_fail ( custom_list != NULL );
+    if ( custom_list == NULL )
+        return;
 
     /* get the new number of the first row in the complete list of row */
     pos = custom_list->num_rows;
@@ -322,7 +325,10 @@ void transaction_list_append_archive (gint archive_store_number)
 
     archive_number = gsb_data_archive_store_get_archive_number (archive_store_number);
 
-    newrecord -> visible_col[find_element_col (ELEMENT_DATE)] = gsb_format_gdate (
+    if ( find_element_col ( ELEMENT_DATE ) == 0 )
+        element_date = find_element_col_for_archive ( );
+
+    newrecord -> visible_col[element_date] = gsb_format_gdate (
                         gsb_data_archive_get_beginning_date ( archive_number ) );
 
     if ( ( col_archive = find_element_col_for_archive ( ) ) >= 0 )
@@ -380,15 +386,16 @@ gboolean transaction_list_remove_transaction ( gint transaction_number )
 
     custom_list = transaction_model_get_model ();
 
-    g_return_val_if_fail ( custom_list != NULL, FALSE);
+    if ( custom_list == NULL )
+        return FALSE;
 
     /* get the record */
     if (!transaction_model_get_transaction_iter (&iter, transaction_number, 0))
-	return FALSE;
+        return FALSE;
 
     record = iter.user_data;
     if (!record)
-	return FALSE;
+        return FALSE;
 
     /* if selected transaction, remove it */
     if (record == custom_list -> selected_row)
@@ -608,6 +615,7 @@ void transaction_list_filter ( gint account_number )
     gint previous_visible_rows;
     GtkTreeIter iter;
     gint i;
+    gint *neworder;
     CustomList *custom_list;
 
     custom_list = transaction_model_get_model ();
@@ -722,10 +730,10 @@ void transaction_list_filter ( gint account_number )
 		}
 		else
 		    record -> has_expander = FALSE;
-        //~ printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction =%d\n",
-                        //~ gsb_data_transaction_get_transaction_number ( record -> transaction_pointer),
-                        //~ record -> filtered_pos,
-                        //~ record -> line_in_transaction);
+        /* printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction =%d\n",
+                        gsb_data_transaction_get_transaction_number ( record -> transaction_pointer),
+                        record -> filtered_pos,
+                        record -> line_in_transaction); */
 
 		/* the value of the row is set in memory, we update the tree view if necessary */
 		/* if the record was already shown and the position hasn't change, nothing to do */
@@ -771,6 +779,29 @@ void transaction_list_filter ( gint account_number )
 	    gtk_tree_model_row_deleted ( GTK_TREE_MODEL (custom_list),
 					 path );
     gtk_tree_path_free(path);
+
+    /* initial sort of the list */
+    g_qsort_with_data(custom_list->visibles_rows,
+                        custom_list->num_visibles_rows,
+                        sizeof(CustomRecord*),
+                        (GCompareDataFunc) gsb_transactions_list_sort_initial,
+                        custom_list);
+
+    /* let other objects know about the new order */
+    neworder = g_new0(gint, custom_list->num_visibles_rows);
+
+    for (i = 0; i < custom_list->num_visibles_rows; ++i)
+    {
+        neworder[i] = (custom_list->visibles_rows[i])->filtered_pos;
+        (custom_list->visibles_rows[i])->filtered_pos = i;
+    }
+
+    path = gtk_tree_path_new();
+
+    gtk_tree_model_rows_reordered(GTK_TREE_MODEL(custom_list), path, NULL, neworder);
+
+    gtk_tree_path_free(path);
+    g_free(neworder);
 }
 
 
@@ -859,6 +890,7 @@ void transaction_list_set_balances ( void )
     gint line_balance;
     gint nb_rows;
     gint floating_point;
+    gint currency_number;
     gint i;
     GtkTreeIter iter;
     GtkTreePath *path;
@@ -889,8 +921,8 @@ void transaction_list_set_balances ( void )
     /* begin to fill the iter for later */
     iter.stamp = custom_list->stamp;
 
-    floating_point = gsb_data_currency_get_floating_point (
-                        gsb_data_account_get_currency ( account_number ) );
+    currency_number = gsb_data_account_get_currency ( account_number );
+    floating_point = gsb_data_currency_get_floating_point ( currency_number );
 
     /* get the beginning balance */
     current_total = solde_debut_affichage ( account_number, floating_point);
@@ -928,10 +960,9 @@ void transaction_list_set_balances ( void )
         }
 
         /* calculate the new balance */
-        current_total = gsb_real_add ( current_total,
-                           amount);
+        current_total = gsb_real_add ( current_total, amount );
         record -> visible_col[column_balance] = gsb_real_get_string_with_currency ( current_total,
-                                                gsb_data_account_get_currency (account_number), TRUE);
+                                                 currency_number , TRUE);
         if (current_total.mantissa >= 0)
             record -> amount_color = NULL;
         else
@@ -980,6 +1011,9 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
 
     devel_debug_int (transaction_number);
 
+    if ( transaction_number == 0 )
+        return FALSE;
+
     custom_list = transaction_model_get_model ();
 
     g_return_val_if_fail ( custom_list != NULL, FALSE);
@@ -992,10 +1026,10 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
     record = iter.user_data;
     if (!record)
 	return FALSE;
-    //~ printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction = %d\n",
-        //~ transaction_number,
-        //~ record -> filtered_pos,
-        //~ record -> line_in_transaction);
+    /* printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction = %d\n",
+        transaction_number,
+        record -> filtered_pos,
+        record -> line_in_transaction); */
 
     /* if the transaction is a split, we need to check if there are already children,
      * else we add the white line */
@@ -1428,6 +1462,15 @@ gboolean transaction_list_show_toggle_mark ( gboolean show )
     gint i;
     CustomList *custom_list;
 
+    if ( show )
+        /* remet le gtk_tree_view en mode normal */
+        gtk_tree_view_set_fixed_height_mode ( GTK_TREE_VIEW (
+                        gsb_transactions_list_get_tree_view ( ) ), FALSE );
+    else
+        /* remet le gtk_tree_view en mode ligne fixe */
+        gtk_tree_view_set_fixed_height_mode ( GTK_TREE_VIEW (
+                        gsb_transactions_list_get_tree_view ( ) ), TRUE );
+
     custom_list = transaction_model_get_model ();
 
     line_p = find_element_line (ELEMENT_MARK);
@@ -2042,7 +2085,7 @@ void transaction_list_set_color_jour ( gint account_number )
     element_sort = gsb_data_account_get_element_sort ( account_number,
 							     custom_list -> sort_col);
 
-    for (i= custom_list -> num_visibles_rows -1; i >= 0  ; i--)
+    for ( i = custom_list -> num_visibles_rows -1; i >= 0  ; i-- )
     {
         CustomRecord *record;
 
@@ -2069,7 +2112,8 @@ void transaction_list_set_color_jour ( gint account_number )
                     {
                         record -> row_bg = &couleur_jour;
                         i--;
-                        record = custom_list -> visibles_rows[i];
+                        if ( i >= 0 )
+                            record = custom_list -> visibles_rows[i];
                     }
                     /* on se positionne sur la première ligne */
                     record = custom_list -> visibles_rows[0];
