@@ -3,15 +3,13 @@
 
 
 /* START_INCLUDE_H */
-#include "././custom_list.h"
+#include "custom_list.h"
 /* END_INCLUDE_H */
 
 /* START_DECLARATION */
 gboolean transaction_model_get_iter (GtkTreeIter  *iter,
 				     GtkTreePath  *path);
 CustomList *transaction_model_get_model (void);
-GtkTreePath *transaction_model_get_path ( gint transaction_number,
-					  gint line_in_transaction );
 gboolean transaction_model_get_transaction_iter ( GtkTreeIter *iter,
 						  gint transaction_number,
 						  gint line_in_transaction );
