@@ -6,14 +6,17 @@
 
 /* START_DECLARATION */
 GDate *gdate_today ( void );
+GDate *gsb_date_add_one_month ( GDate *date, gboolean free );
 gboolean gsb_date_check_and_complete_entry ( GtkWidget *entry,
                         gboolean set_today );
 gboolean gsb_date_check_entry ( GtkWidget *entry );
 GDate *gsb_date_copy ( const GDate *date );
 void gsb_date_free_last_date ( void );
 gchar *gsb_date_get_compiled_time ( void );
+gchar *gsb_date_get_format_date ( void );
 GDate *gsb_date_get_last_day_of_month ( const GDate *date );
 GDate *gsb_date_get_last_entry_date ( const gchar *string );
+void gsb_date_set_format_date ( const gchar *format_date );
 void gsb_date_set_last_date ( const gchar *date );
 gchar *gsb_date_today ( void );
 GDate *gsb_date_tomorrow ( void );
