@@ -1,7 +1,7 @@
 #ifndef _UTILS_EDITABLES_H
 #define _UTILS_EDITABLES_H (1)
 /* START_INCLUDE_H */
-#include "././gsb_real.h"
+#include "gsb_real.h"
 /* END_INCLUDE_H */
 
 
