@@ -23,21 +23,22 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "utils_files.h"
-#include "./dialog.h"
-#include "./utils_file_selection.h"
-#include "./go-charmap-sel.h"
-#include "./gsb_file.h"
-#include "./utils_str.h"
-#include "./gsb_file_config.h"
-#include "./utils_file_selection.h"
-#include "./go-charmap-sel.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "utils_file_selection.h"
+#include "go-charmap-sel.h"
+#include "gsb_file.h"
+#include "utils_str.h"
+#include "gsb_file_config.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -396,14 +397,12 @@ GtkWidget * my_file_chooser ()
  *
  * \return file descriptor returned by fopen
  */
-G_MODULE_EXPORT FILE* utf8_fopen(const gchar* utf8filename,gchar* mode)
+G_MODULE_EXPORT FILE* utf8_fopen (const gchar *utf8filename, gchar *mode )
 {
 #ifdef _MSC_VER
-	if(!strncmp(mode, "w+x", 3))
-		mode = "w+";
-    return fopen(g_locale_from_utf8(utf8filename, -1, NULL, NULL, NULL),mode);
+    return fopen ( g_locale_from_utf8 ( utf8filename, -1, NULL, NULL, NULL ), mode );
 #else
-	return fopen(g_filename_from_utf8(utf8filename, -1, NULL, NULL, NULL),mode);
+	return fopen ( g_filename_from_utf8 ( utf8filename, -1, NULL, NULL, NULL ), mode );
 #endif
 }
 
@@ -417,12 +416,12 @@ G_MODULE_EXPORT FILE* utf8_fopen(const gchar* utf8filename,gchar* mode)
  *
  * \return remove returned value
  */
-gint utf8_remove(const gchar* utf8filename)
+gint utf8_remove ( const gchar *utf8filename )
 {
 #ifdef _MSC_VER
-    return remove(g_locale_from_utf8(utf8filename, -1, NULL, NULL, NULL));
+    return remove ( g_locale_from_utf8 ( utf8filename, -1, NULL, NULL, NULL ) );
 #else
-    return remove(g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL));
+    return remove ( g_filename_from_utf8 ( utf8filename,-1,NULL,NULL,NULL ) );
 #endif
 }
 
@@ -432,9 +431,9 @@ gint utf8_remove(const gchar* utf8filename)
  *
  * \param filename Filename to sanitize.
  */
-gchar * safe_file_name ( gchar* filename )
+gchar *safe_file_name ( gchar *filename )
 {
-    return g_strdelimit ( my_strdup(filename), G_DIR_SEPARATOR_S, '_' );
+    return g_strdelimit ( my_strdup ( filename ), G_DIR_SEPARATOR_S, '_' );
 }
 
 
@@ -445,7 +444,7 @@ gchar * safe_file_name ( gchar* filename )
  *
  * \return chooser
  */
-GtkWidget *utils_files_create_file_chooser ( GtkWidget *parent, gchar * titre )
+GtkWidget *utils_files_create_file_chooser ( GtkWidget *parent, gchar *titre )
 {
     GtkWidget *chooser;
     GtkWidget *bouton_cancel, *bouton_OK;
@@ -501,13 +500,13 @@ void utils_files_file_chooser_cancel ( GtkWidget *bouton, GtkWidget *chooser)
  *
  * \return TRUE if ok
  */
-gboolean utils_files_create_XDG_dir (void)
+gboolean utils_files_create_XDG_dir ( void )
 {
 #ifdef _MSC_VER
     int mode = 0;
 #else
     int mode = S_IRUSR | S_IWUSR | S_IXUSR;
-#endif//_MSC_VER
+#endif /*_MSC_VER */
     if ( g_mkdir_with_parents ( C_PATH_CONFIG, mode ) == 0 &&
          g_mkdir_with_parents ( C_PATH_DATA_FILES, mode ) == 0 )
         return TRUE;
@@ -533,7 +532,6 @@ GSList *utils_files_check_UTF8_validity ( const gchar *contents,
     gint long_str = 0;
     gsize size = 0;
     gsize bytes_written = 0;
-    GError * error = NULL;
     gint i = 0;
     gchar *ptr;
 
@@ -564,7 +562,7 @@ GSList *utils_files_check_UTF8_validity ( const gchar *contents,
                 do
                 {
                      tmp_str = g_convert ( string, long_str, "UTF-8", charset_array[i],
-                                &size, &bytes_written, &error );
+                                &size, &bytes_written, NULL );
                     if ( tmp_str )
                     {
                         result = g_malloc0 ( sizeof ( struct struc_check_encoding ) );
@@ -879,6 +877,8 @@ gchar *utils_files_get_ofx_charset ( gchar *contents )
                     }
                     i++;
                 } while ( all_charset_array[i] );
+                /* CHARSET found in OFX file, but no match --> Exit function */
+                    return NULL;
             }
             g_free ( string );
             ptr = ptr_tmp + 1;
