@@ -22,12 +22,17 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 #include <stdlib.h>
 
 /*START_INCLUDE*/
 #include "utils_str.h"
-#include "./gsb_data_report.h"
+#include "gsb_data_report.h"
+#include "gsb_data_currency.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -37,6 +42,7 @@ static gchar * gsb_string_truncate_n ( gchar * string, int n, gboolean hard_trun
 
 
 /*START_EXTERN*/
+extern gsb_real error_real;
 /*END_EXTERN*/
 
 
@@ -64,7 +70,7 @@ gchar *utils_str_itoa ( gint integer )
     
     num = abs(integer);
 
-    // Construct the result in the reverse order from right to left, then reverse it.
+    /* Construct the result in the reverse order from right to left, then reverse it. */
     do
     {
 	result_div = div ( num, 10 );
@@ -73,8 +79,8 @@ gchar *utils_str_itoa ( gint integer )
     }
     while ( ( num = result_div.quot ));
 
-    // Add the sign at the end of the string just before to reverse it to avoid
-    // to have to insert it at the begin just after...
+    /* Add the sign at the end of the string just before to reverse it to avoid
+     to have to insert it at the begin just after... */
     if (integer < 0)
     {
         chaine[i++] = '-';
@@ -167,15 +173,14 @@ gchar *utils_str_reduce_exponant_from_string ( const gchar *amount_string,
  * */
 gchar *utils_str_localise_decimal_point_from_string ( const gchar *string )
 {
-    struct lconv *conv = localeconv ( );
     gchar *ptr_1, *ptr_2;
     gchar *new_str;
     gchar *mon_decimal_point;
     gchar *mon_separateur;
     gchar **tab;
 
-    mon_decimal_point = g_locale_to_utf8 ( conv->mon_decimal_point, -1, NULL, NULL, NULL );
-    mon_separateur = g_locale_to_utf8 ( conv->mon_thousands_sep, -1, NULL, NULL, NULL );
+    mon_decimal_point = gsb_real_get_decimal_point ( );
+    mon_separateur = gsb_real_get_thousands_sep ( );
 
     if ( ( ptr_1 = g_strstr_len ( string, -1, "," ) )
      &&
@@ -205,7 +210,7 @@ gchar *utils_str_localise_decimal_point_from_string ( const gchar *string )
 
     if ( mon_separateur && g_strstr_len ( new_str, -1, mon_separateur ) )
     {
-        tab = g_strsplit ( new_str, " ", 0 );
+        tab = g_strsplit ( new_str, mon_separateur, 0 );
         g_free ( new_str );
         new_str = g_strjoinv ( "", tab );
         g_strfreev ( tab );
@@ -242,77 +247,6 @@ G_MODULE_EXPORT gint utils_str_atoi ( const gchar *chaine )
 }
 
 
-/**
- * Fonction my_strtod (string to decimal)
- * Convertie une chaine de caractères en un nombre
- * Paramètres d'entrée :
- *   - nptr : pointeur sur la chaine de caractères à convertir
- *   - endptr : n'est pas utilisé, alors à quoi peut-il bien servir ?
- * Valeur de retour :
- *   - resultat : le résultat de la conversion
- * Variables locales :
- *   - entier : la partie entière du résultat
- *   - mantisse : la partie décimale du résultat
- *   - invert : le signe du résultat (0 -> positif, 1 -> négatif)
- *   - p, m : pointeurs locaux sur la chaine de caractères à convertir
- * */
-double my_strtod ( const char *nptr, const char **endptr )
-{
-    double entier=0, mantisse=0, resultat=0;
-    int invert = 0;
-    const char * p;
-
-    if (!nptr)
-	return 0;
-
-
-    for ( p = nptr; p < nptr + strlen(nptr); p++ )
-    {
-	if (g_ascii_isspace(*p) || *p == '+' )
-	    continue;
-
-	if (*p == '-')
-	{
-	    invert = 1;
-	    continue;
-	}
-
-	if ( *p == ',' || *p == '.' )
-	{
-	    const char * m;
-	    for ( m = p+1; m <= nptr+strlen(nptr) && 
-		  (g_ascii_isdigit(*m) || g_ascii_isspace(*m)); m++)
-		/* Nothing, just loop */ ;
-	    for ( --m; m > p; m-- )
-	    {
-		if (isdigit(*m))
-		{
-		    mantisse /= 10;
-		    mantisse += (*m - '0');
-		}
-	    }
-	    mantisse /= 10;
-	}
-
-	if (isdigit(*p))
-	{
-	    entier = entier * 10;
-	    entier += (*p - '0');
-	}
-	else
-	{
-	    break;
-	}
-    }
-
-    resultat = entier + mantisse;
-    if ( invert )
-	resultat = - resultat;
-
-    return resultat;
-}
-
-
 /**
  *
  *
@@ -369,10 +303,12 @@ gchar *my_strdelimit ( const gchar *string,
  * */
 gint my_strcmp ( gchar *string_1, gchar *string_2 )
 {
-    if ( string_1
-	 &&
-	 string_2 )
-    {
+    if (!string_1 && string_2)
+	    return 1;
+    if (string_1 && !string_2)
+	    return -1;
+
+
 	if ( g_utf8_validate ( string_1, -1, NULL )
 	     &&
 	     g_utf8_validate ( string_2, -1, NULL ))
@@ -380,20 +316,16 @@ gint my_strcmp ( gchar *string_1, gchar *string_2 )
 	    gint retour;
  	    gchar *new_1, *new_2;
 	    
-	    new_1 = g_utf8_collate_key ( string_1,
-					 -1 );
-	    new_2 = g_utf8_collate_key ( string_2,
-					 -1 );
-	    retour = strcmp ( new_1,
-			      new_2 );
+	    new_1 = g_utf8_collate_key ( string_1, -1 );
+	    new_2 = g_utf8_collate_key ( string_2, -1 );
+	    retour = strcmp ( new_1, new_2 );
+
 	    g_free ( new_1 );
 	    g_free ( new_2 );
 	    return ( retour );
 	}
 	else
-	    return ( strcmp ( string_1,
-			      string_2 ));
-    }
+	    return ( strcmp ( string_1, string_2 ) );
 
     return 0;
 }
@@ -750,21 +682,27 @@ gchar * gsb_string_truncate_n ( gchar * string, int n, gboolean hard_trunc )
 gchar * gsb_string_remplace_string ( gchar *str, gchar *old_str, gchar *new_str )
 {
     gchar *ptr_debut;
-    gint long_old;
-    gchar *chaine;
+    gint long_old, str_len;
+    gchar *chaine, *ret, *tail;
 
     ptr_debut = g_strstr_len ( str, -1, old_str);
     if ( ptr_debut == NULL )
         return g_strdup ( str );
 
-    long_old = g_utf8_strlen ( old_str, -1 );
-    chaine = g_strndup ( str, (ptr_debut - str) );
-    if ( ptr_debut + long_old + 1 )
-        chaine = g_strconcat ( chaine, new_str, ( ptr_debut + long_old + 1 ), NULL );
-    else
-        chaine = g_strconcat ( chaine, new_str, NULL );
+    str_len = strlen ( str );
+    long_old = strlen ( old_str );
 
-    return g_strdup ( chaine );
+    chaine = g_strndup ( str, (ptr_debut - str) );
+
+    tail = ptr_debut + long_old;
+    if ( tail >= str + str_len )
+        ret = g_strconcat ( chaine, new_str, NULL );
+    else
+        ret = g_strconcat ( chaine, new_str, tail, NULL );
+
+    g_free ( chaine );
+
+    return ret;
 }
 
 
@@ -831,9 +769,15 @@ gboolean gsb_string_is_trouve ( const gchar *payee_name, const gchar *needle )
         if ( tab_str[i] && strlen (tab_str[i]) > 0)
         {
             if ( g_strstr_len (payee_name, -1, tab_str[i]))
+            {
+                g_strfreev ( tab_str );
                 return TRUE;
+            }
         }
     }
+
+    g_strfreev ( tab_str );
+
     return FALSE;
 }
 
@@ -916,6 +860,9 @@ gchar *gsb_string_uniform_new_line ( const gchar *chaine, gint nbre_char )
 {
     gchar **tab_str;
 
+    if ( chaine == NULL )
+        return NULL;
+
     if ( g_strstr_len ( chaine, nbre_char, "\r\n" ) )
     {
         tab_str = g_strsplit_set ( chaine, "\r", 0 );
@@ -935,6 +882,189 @@ gchar *gsb_string_uniform_new_line ( const gchar *chaine, gint nbre_char )
 }
 
 
+/**
+ *
+ *
+ *
+ *
+ * */
+gchar *utils_str_dtostr ( gdouble number, gint nbre_decimal, gboolean canonical )
+{
+    gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
+    gchar *str_number;
+    gchar *decimal;
+    gchar *format;
+    gint nbre_char;
+
+    decimal = utils_str_itoa ( nbre_decimal );
+    format = g_strconcat ( "%.", decimal, "f", NULL );
+    nbre_char = g_sprintf ( buffer, format, number );
+    g_free ( decimal );
+    g_free ( format );
+
+    if ( nbre_char > G_ASCII_DTOSTR_BUF_SIZE )
+        return NULL;
+
+    str_number = g_strndup ( buffer, nbre_char );
+
+    if ( canonical && g_strrstr ( str_number, "," ) )
+        str_number = my_strdelimit ( str_number, ",", "." );
+
+    return str_number;
+}
+
+
+/**
+ * fonction de conversion de char à double pour chaine avec un . comme séparateur décimal
+ * et pas de séparateur de milliers
+ *
+ *
+ * */
+gdouble utils_str_safe_strtod ( const gchar *str_number, gchar **endptr )
+{
+    gdouble number;
+
+    if ( str_number == NULL )
+        return 0.0;
+
+    number = g_ascii_strtod ( str_number, endptr);
+
+    return number;
+}
+
+
+/**
+ * fonction de conversion de char à double pour chaine en tenant compte du séparateur décimal
+ * et du séparateur de milliers configurés dans les préférences.
+ *
+ *
+ *
+ * */
+gdouble utils_str_strtod ( const gchar *str_number, gchar **endptr )
+{
+    gdouble number;
+    gsb_real real;
+
+    if ( str_number == NULL )
+        return 0.0;
+
+    real = gsb_real_get_from_string ( str_number );
+
+    number = gsb_real_real_to_double ( real );
+
+    return number;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gint utils_str_get_nbre_motifs ( const gchar *chaine, const gchar *motif )
+{
+    gchar **tab_str;
+    gint nbre_motifs = 0;
+
+    if ( chaine == NULL || motif == NULL )
+        return -1;
+
+    tab_str = g_strsplit ( chaine, motif, 0 );
+    nbre_motifs = g_strv_length ( tab_str ) -1;
+    g_strfreev ( tab_str );
+
+    return nbre_motifs;
+}
+
+
+/**
+ * adapte l'utilisation de : en fonction de la langue de l'utilisateur
+ *
+ *
+ *
+ * */
+gchar *utils_str_incremente_number_from_str ( const gchar *str_number, gint increment )
+{
+    gchar *new_str_number;
+    gchar *prefix = NULL;
+    gint number = 0;
+    gint i = 0;
+
+    if ( str_number && strlen ( str_number ) > 0 )
+    {
+        while ( str_number[i] == '0' )
+        {
+            i++;
+        }
+        if ( i > 0 )
+            prefix = g_strndup ( str_number, i );
+    
+        number = utils_str_atoi ( str_number );
+    }
+
+    number += increment;
+
+    new_str_number = utils_str_itoa ( number );
+
+    if ( prefix && strlen ( prefix ) > 0 )
+    {
+        new_str_number = g_strconcat ( prefix, new_str_number, NULL );
+        g_free ( prefix );
+    }
+
+    return new_str_number;
+}
+
+
+/**
+ * Return the real in a formatted string with an optional currency
+ * symbol, according to the locale regarding decimal separator,
+ * thousands separator and positive or negative sign.
+ *
+ * \param number		Number to format.
+ * \param currency_number 	the currency we want to adapt the number, 0 for no adaptation
+ * \param show_symbol 		TRUE to add the currency symbol in the string
+ *
+ * \return		A newly allocated string of the number (this
+ *			function will never return NULL)
+ */
+gchar *gsb_real_get_string_with_currency ( gsb_real number,
+                        gint currency_number,
+                        gboolean show_symbol )
+{
+    struct lconv *conv = localeconv ();
+    gint floating_point;
+
+    const gchar *currency_symbol = (currency_number && show_symbol)
+                                   ? gsb_data_currency_get_code_or_isocode (currency_number)
+                                   : NULL;
+
+    /* First of all if number = 0 I return 0 with the symbol of the currency if necessary */
+    if (number.mantissa == 0)
+    {
+        if (currency_symbol && conv -> p_cs_precedes)
+            return g_strdup_printf ( "%s %s", currency_symbol, "0" );
+        else if (currency_symbol && ! conv -> p_cs_precedes)
+            return g_strdup_printf ( "%s %s", "0", currency_symbol );
+        else
+            return g_strdup ("0");
+    }
+    else if ( (number.exponent < 0)
+    || (number.exponent > EXPONENT_MAX )
+    || (number.mantissa == error_real.mantissa) )
+        return g_strdup ( ERROR_REAL_STRING );
+
+    /* first we need to adapt the exponent to the currency */
+    /* if the exponent of the real is not the same of the currency, need to adapt it */
+    floating_point = gsb_data_currency_get_floating_point ( currency_number );
+    if ( currency_number && number.exponent != floating_point )
+        number = gsb_real_adjust_exponent ( number, floating_point );
+
+    return gsb_real_raw_format_string ( number, conv, currency_symbol );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
